import { ElementRef, EventEmitter, OnChanges, OnDestroy, OnInit, QueryList, SimpleChanges } from '@angular/core';
import { MatMenuTrigger } from '@angular/material/menu';
import { CellContextMenuEvent, CellEditingStoppedEvent, CellKeyDownEvent, CellValueChangedEvent, ColDef, ColumnApi, GridApi, GridReadyEvent, IsRowSelectable, RowClickedEvent, RowDataChangedEvent, RowDoubleClickedEvent, RowDragEvent, RowEditingStartedEvent, RowNode, RowSelectedEvent } from 'ag-grid-community';
import { Observable, Subscription } from 'rxjs';
import { ButtonHeader, ConfigButtonAction, ConfigButtonAgGrid, ConfigButtonHeader, GetRowStyle, RowSelection } from '../../utils/models/sc-ag-grid.interface';
import { MessageUtilService } from '../../utils/service/message-util.service';
import { ScCellRenderButtonService } from '../cell-render/sc-cell-render-button/sc-cell-render-button.component';
import { ScAgGridButtonHeader } from '../directives/scAgGrid.directive';
export declare class ScAgGridCustomizableComponent implements OnInit, OnChanges, OnDestroy {
    private readonly _scCellRenderButtonService;
    private readonly _messageUtilService;
    viewChildrenButtonHeaders: QueryList<ScAgGridButtonHeader>;
    menuTrigger?: MatMenuTrigger;
    private _scAgGridPagination?;
    buttonAdd?: ElementRef<HTMLButtonElement>;
    get buttonAddElement(): HTMLButtonElement | null;
    idScAgGridCustomizableComponent: string;
    isRowSelectable: IsRowSelectable;
    searchClass: string;
    getRowStyle: GetRowStyle;
    fillSearch: boolean;
    /**
     * @description Cantidad de items que se mostrará por página
     * @default 15
     */
    paginationPageSize: number;
    searchWidth: string;
    /**
     * @description  Opciones de tamaño de página
     * @default [5, 10, 15, 20, 25]
     */
    pageSizeOptions: number[];
    /**
     * @description Si el valor es `true` muestra la paginación
     * @default true
     */
    pagination: boolean;
    /**
     * @description Tipo de selecion en la `grilla`s
     * @default 'simple'
     */
    rowSelection: RowSelection;
    get suppressRowClickSelection(): boolean;
    /**
     * @description Array de columnas que se mostrara en la `grilla`
     * @default undefined
     */
    columnDefs: ColDef[];
    /**
     * @description Array de datos que se mostrara en la `grilla`
     * @default null
     */
    rowData: Observable<any[]>;
    configButtonsAction: ConfigButtonAction;
    get configHeader(): ConfigButtonHeader | null;
    defaultCellRendererActions: string | undefined;
    _configButtonsDefaultAgGrid: ConfigButtonAgGrid[];
    /**
     * @description Si el valor es `true` muestra el `buscador`
     * @default true
     */
    visibleSearch: boolean;
    domLayout: 'normal' | 'autoHeight';
    height: string;
    /**
     * @description Cpnfiguración para el boton `Agregar`
     * @default { visible: true, disabled: false }
     */
    btnAdd: ButtonHeader;
    /**
     * @description Para activar o descativar el drag & drop
     * @default false
     */
    rowDragManaged: boolean;
    /**
     * @description Para activar o descativar las animaciones
     * @default false
     */
    animateRows: boolean;
    useGridCopy: boolean;
    multiSortKey: string;
    showMenuDefault: boolean;
    enableCellTextSelection: boolean;
    suppressRowTransform: boolean;
    enableRangeSelection: boolean;
    noRowsOverlayComponent: string;
    noRowsOverlayComponentParams: {};
    validatePasteCell?: (evtSource: CellKeyDownEvent, evtTarget: CellKeyDownEvent) => Promise<boolean>;
    validatePasteRows?: (evtSource: RowNode[], evtTarget: RowNode[]) => Promise<boolean>;
    /**
     * @description Para agregar componentes internos dentro de la grilla
     */
    set frameworkComponents(value: any);
    /**
     * @description Para poder agregar más objetos al contexto
     */
    set context(value: any);
    onChangeFilter: EventEmitter<string>;
    onAddRow: EventEmitter<GridApi>;
    onGridAddRow: EventEmitter<CellKeyDownEvent>;
    onEditRow: EventEmitter<RowNode>;
    onDeleteRow: EventEmitter<[GridApi, any[]]>;
    onCellKeyDown: EventEmitter<any>;
    onCellStopEditing: EventEmitter<any>;
    onButtonActionAgGrid: EventEmitter<[string, RowNode]>;
    onButtonActionHeader: EventEmitter<[string, any[]]>;
    onGridReady: EventEmitter<[GridApi, ColumnApi]>;
    onGridSelectChange: EventEmitter<any[]>;
    onGridChange: EventEmitter<[GridApi, ColumnApi, RowDataChangedEvent]>;
    onRowDragEnd: EventEmitter<RowDragEvent>;
    onRowEditingStarted: EventEmitter<RowEditingStartedEvent>;
    rowClicked: EventEmitter<RowClickedEvent>;
    rowDoubleClicked: EventEmitter<RowDoubleClickedEvent>;
    onRowSelected: EventEmitter<RowSelectedEvent>;
    cellValueChanged: EventEmitter<CellValueChangedEvent>;
    onCellContextMenu: EventEmitter<CellContextMenuEvent>;
    onPasteMenu: EventEmitter<CellContextMenuEvent>;
    onCopyMenu: EventEmitter<CellContextMenuEvent>;
    afterPasteCell: EventEmitter<[CellKeyDownEvent, CellKeyDownEvent]>;
    beforePasteCell: EventEmitter<[CellKeyDownEvent, CellKeyDownEvent]>;
    afterPasteRows: EventEmitter<[RowNode[], RowNode[]]>;
    beforePasteRows: EventEmitter<[RowNode[], RowNode[]]>;
    columnDefsAndAddCellActions: ColDef[];
    defaultColDef: ColDef;
    _frameworkComponents: {
        scCellRendererButtonComponent: typeof import("../cell-render/sc-cell-render-button/sc-cell-render-button.component").ScCellRendererButtonComponent;
        scCellRenderCheckboxListComponent: typeof import("..").ScCellRenderCheckboxListComponent;
        scCellRenderSelectComponent: typeof import("..").ScCellRenderSelectComponent;
        scCellRenderToggleComponent: typeof import("..").ScCellRenderToggleComponent;
        noRowsOverlayDefault: typeof import("..").NoRowsOverlayDefaultComponent;
    };
    _context: {
        componentParent: any;
    };
    bottomMenu: string;
    leftMenu: string;
    hiddenMenu: boolean;
    copiedCell?: CellKeyDownEvent;
    copiedRow?: RowNode[];
    overlayNoRowsTemplate: string;
    overlayLoadingTemplate: string;
    suppressDragLeaveHidesColumns: boolean;
    suppressScrollOnNewData: boolean;
    suppressPaginationPanel: boolean;
    get ngStyleContainer(): {
        width: string;
        height: string;
    };
    get ngStyleAgGrid(): {
        width: string;
        height: string;
    };
    _subscription$: Subscription;
    progressVisibled: boolean;
    gridApi: GridApi;
    _gridColumnApi: ColumnApi;
    _subscriptionRowData$?: Subscription;
    selectedRows: any[];
    cellContextMenuActual?: CellContextMenuEvent;
    constructor(_scCellRenderButtonService: ScCellRenderButtonService, _messageUtilService: MessageUtilService);
    ngOnInit(): void;
    ngOnChanges(changes: SimpleChanges): void;
    initRowData(): void;
    sizeFitColumnAction(): void;
    initActionButton(): void;
    private _hideFunc;
    private _hideAgGridMenuAction;
    hideHeaderMenuAction(): boolean;
    gridReady(event: GridReadyEvent): void;
    rowDataChanged(event: RowDataChangedEvent): void;
    /**
     * @param event: opcional - Contiene el nodo y la data de la fila actual.
     * @description Se dispara cada vez que la fila es colocada en su nueva posición (Drag & Drop).
     */
    rowDragEndEmit(event: RowDragEvent): void;
    selectionChanged(): void;
    paginationChanged(): void;
    changeFilter(value: string): void;
    onAddRowEmit(): void;
    copyMenu(event: CellContextMenuEvent): void;
    pasteMenu(event: CellContextMenuEvent): void;
    onButtonActionAgGridEmit(rowIndex: number, typeButton: string): void;
    onButtonActionHeaderEmit(typeButton: string): void;
    copy(evt: CellKeyDownEvent): void;
    paste(evt: CellKeyDownEvent): Promise<void>;
    get disabledPasteMenu(): boolean;
    cellKeyDown(evt: CellKeyDownEvent): Promise<void>;
    cellStopEditing(evt: CellEditingStoppedEvent): void;
    onCancel(e: MouseEvent): boolean;
    cellContextMenu(event: CellContextMenuEvent): void;
    ngOnDestroy(): void;
}
export declare function isObjEmpty<T>(object: T): boolean;
