import * as i0 from '@angular/core';
import { Injectable, Inject, EventEmitter, Component, forwardRef, ElementRef, Renderer2, Input, Output, ViewChild, NgModule, ChangeDetectorRef, ViewEncapsulation, Directive, InjectionToken, TemplateRef, ChangeDetectionStrategy, ContentChildren } from '@angular/core';
import { NG_VALUE_ACCESSOR, NG_VALIDATORS, FormsModule, ReactiveFormsModule, FormControl } from '@angular/forms';
import { NgbDateParserFormatter, NgbDatepickerI18n, NgbDate, NgbDatepickerModule, NgbCalendar, NgbTimepickerModule } from '@ng-bootstrap/ng-bootstrap';
import { parse, format, isValid, isAfter, subDays, addDays, parseISO, differenceInDays, getHours, getMinutes, getSeconds, startOfMonth, endOfMonth, formatDistance } from 'date-fns';
import * as toastr_ from 'toastr';
import { CommonModule, DatePipe, DOCUMENT } from '@angular/common';
import { MatIconModule } from '@angular/material/icon';
import { MatTooltipModule } from '@angular/material/tooltip';
import { RouterModule } from '@angular/router';
import { NgxMaskModule } from 'ngx-mask';
import { __awaiter, __decorate, __param } from 'tslib';
import { AutoUnsubscribe } from 'ngx-auto-unsubscribe';
import { isObservable, of, Subject, Subscription } from 'rxjs';
import { shareReplay, debounceTime, map } from 'rxjs/operators';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { NgSelectModule } from '@ng-select/ng-select';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatDialogModule } from '@angular/material/dialog';
import { MatMenuModule } from '@angular/material/menu';
import { MatProgressBarModule } from '@angular/material/progress-bar';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { AgGridModule } from 'ag-grid-angular';
import { Directionality } from '@angular/cdk/bidi';
import { CdkStepper, CdkStepperModule } from '@angular/cdk/stepper';
import { Optional } from 'ag-grid-community';
import { MatButtonModule } from '@angular/material/button';

function toInteger(value) {
    return parseInt(`${value}`, 10);
}
function isNumber(value) {
    return !isNaN(toInteger(value));
}
function padNumber(value) {
    if (isNumber(value)) {
        return `0${value}`.slice(-2);
    }
    else {
        return '';
    }
}
class CustomDatepickerFormat extends NgbDateParserFormatter {
    parse(value) {
        if (value) {
            const dateParts = value.trim().split('-');
            if (dateParts.length === 1 && isNumber(dateParts[0])) {
                return { day: toInteger(dateParts[0]), month: null, year: null };
            }
            else if (dateParts.length === 2 && isNumber(dateParts[0]) && isNumber(dateParts[1])) {
                return { day: toInteger(dateParts[0]), month: toInteger(dateParts[1]), year: null };
            }
            else if (dateParts.length === 3 && isNumber(dateParts[0]) && isNumber(dateParts[1]) && isNumber(dateParts[2])) {
                return { day: toInteger(dateParts[0]), month: toInteger(dateParts[1]), year: toInteger(dateParts[2]) };
            }
        }
        return null;
    }
    format(date) {
        return date ?
            `${isNumber(date.day) ? padNumber(date.day) : ''}/${isNumber(date.month) ? padNumber(date.month) : ''}/${date.year}` :
            '';
    }
}
CustomDatepickerFormat.decorators = [
    { type: Injectable }
];

const I18N_VALUES = {
    'fr': {
        weekdays: ['Lu', 'Ma', 'Mi', 'Jue', 'Vi', 'Sa', 'Do'],
        months: ['Ene', 'Feb', 'Mar', 'Abr', 'May', 'Jun', 'Jul', 'Ago', 'Sep', 'Oct', 'Nov', 'Dic'],
    }
    // other languages you would support
};
// Define a service holding the language. You probably already have one if your app is i18ned. Or you  could also
// use the Angular LOCALE_ID value
class I18n {
    constructor() {
        this.language = 'fr';
    }
}
I18n.decorators = [
    { type: Injectable }
];
// Define custom service providing the months and weekdays translations
class CustomDatepickerI18n extends NgbDatepickerI18n {
    constructor(_i18n) {
        super();
        this._i18n = _i18n;
    }
    getWeekdayShortName(weekday) {
        return I18N_VALUES[this._i18n.language].weekdays[weekday - 1];
    }
    getMonthShortName(month) {
        return I18N_VALUES[this._i18n.language].months[month - 1];
    }
    getMonthFullName(month) {
        return this.getMonthShortName(month);
    }
    getDayAriaLabel(date) {
        return `${date.day}-${date.month}-${date.year}`;
    }
    getWeekdayLabel(weekday) {
        return I18N_VALUES[this._i18n.language].weekdays[weekday - 1];
    }
}
CustomDatepickerI18n.decorators = [
    { type: Injectable }
];
CustomDatepickerI18n.ctorParameters = () => [
    { type: I18n }
];

class DateUtil {
    static now(format = 'DATE') {
        return this.format(new Date(), format);
    }
    static parse(date, format) {
        return parse(date, this.DATE_FORMATS[format], new Date());
    }
    static format(date, format$1) {
        return format(date, this.DATE_FORMATS[format$1]);
    }
    static isValidDatePickerValue(value) {
        return !value || value.length !== 10 ? false : this.isValid(this.parse(value, 'DATE'));
    }
    static isValid(date) {
        return isValid(date);
    }
    static isAfter(date, dateToCompare) {
        return isAfter(this.toDate(date), this.toDate(dateToCompare));
    }
    static subDays(date, days) {
        const newDate = this.toDate(date);
        return subDays(newDate, days);
    }
    static addDays(date, days) {
        const newDate = this.toDate(date);
        return addDays(newDate, days);
    }
    static toStrFormat(date, targetFormat) {
        return this.format(this.toDate(date), targetFormat);
    }
    static toDate(date) {
        if (date instanceof Date) {
            return date;
        }
        const dateFormat = this.getFormat(date);
        const parsedDate = dateFormat == 'ISO' ? parseISO(date) : this.parse(date, dateFormat);
        if (!this.isValid(parsedDate)) {
            throw new Error('Invalid date');
        }
        return parsedDate;
    }
    static diffDays(later, earlier) {
        const laterDate = this.toDate(later);
        const earlierDate = this.toDate(earlier);
        return differenceInDays(laterDate, earlierDate);
    }
    static getYear(date = new Date()) {
        const dateObj = this.toDate(date);
        return dateObj.getUTCFullYear();
    }
    static getMonth(date = new Date()) {
        const dateObj = this.toDate(date);
        return dateObj.getUTCMonth() + 1;
    }
    static getDay(date = new Date()) {
        const dateObj = this.toDate(date);
        return dateObj.getUTCDate();
    }
    static getHours(date = new Date()) {
        const dateObj = this.toDate(date);
        return getHours(dateObj);
    }
    static getMinutes(date = new Date()) {
        const dateObj = this.toDate(date);
        return getMinutes(dateObj);
    }
    static getSeconds(date = new Date()) {
        const dateObj = this.toDate(date);
        return getSeconds(dateObj);
    }
    static startOfMonth(targetFormat = 'DATE') {
        return this.format(startOfMonth(new Date()), targetFormat);
    }
    static endOfMonth(fchIni = new Date(), targetFormat = 'DATE') {
        const date = this.toDate(fchIni);
        return this.format(endOfMonth(date), targetFormat);
    }
    static formatDistance(dateStr) {
        return formatDistance(new Date(), this.toDate(dateStr));
    }
    static getFormat(dateStr) {
        if (this.ISO8601.test(dateStr)) {
            return 'ISO';
        }
        else if (this.dateRegex.test(dateStr)) {
            return 'DATE';
        }
        else if (this.timeRegex.test(dateStr)) {
            return 'TIME';
        }
        else if (this.isoNoSec.test(dateStr)) {
            return 'ISODATETIME_NO_TIMEZONE_NO_SEC';
        }
        else {
            throw new Error('Unknown format');
        }
    }
    static getNgOptionList() {
        return this.MONTHS.map((month, index) => ({
            value: index,
            label: month.charAt(0).toUpperCase() + month.slice(1),
        }));
    }
    static validatorFecha(fch) {
        const datedFch = this.parse(fch, 'DATE');
        const valid = this.isValid(datedFch);
        let errfch = '';
        if (!valid) {
            errfch = 'Fecha no válida';
            if (typeof errfch === 'undefined') {
                return { valid: true, errfch };
            }
        }
        return { valid, errfch };
    }
    ///------------------------------------------------------------------///
    static dateAutoComplete(fecha) {
        let now = new Date();
        let dia;
        let mes;
        let anio;
        switch (fecha.length) {
            case 1:
            case 2:
                dia = fecha.padStart(2, '0');
                mes = (now.getMonth() + 1).toString().padStart(2, '0');
                anio = now.getFullYear();
                break;
            case 3:
            case 4:
                dia = fecha.substring(0, 2);
                mes = fecha.substring(2, 4).padStart(2, '0');
                anio = now.getFullYear();
                break;
            case 6:
                dia = fecha.substring(0, 2);
                mes = fecha.substring(2, 4);
                anio = '20' + fecha.substring(4, 6);
                break;
            case 8:
                dia = fecha.substring(0, 2);
                mes = fecha.substring(2, 4);
                anio = fecha.substring(4);
                break;
            case 10:
                if (this.isValid(fecha)) {
                    let d = this.parse(fecha, 'DATE');
                    dia = d.getDay();
                    mes = d.getMonth() + 1;
                    anio = d.getFullYear();
                }
                break;
        }
        if (typeof dia !== 'undefined' || typeof mes !== 'undefined' || typeof anio !== 'undefined') {
            return this.toStrFormat(new Date(anio, mes - 1, dia), 'DATE');
        }
        else {
            return this.toStrFormat(new Date(), 'DATE');
        }
    }
}
DateUtil.dateRegex = /\d{2}\/\d{2}\/\d{4}/;
DateUtil.timeRegex = /(0?[0-9]|1[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9])/;
DateUtil.ISO8601 = /^(\d{4}-\d{2}-\d{2})(T(0?[0-9]|1[0-9]|2[0-3]):([0-5][0-9]):([0-5][0-9])(\.\d+)?(Z|[+-]\d{2}:\d{2})?)?$/;
DateUtil.isoNoSec = /^\d{4}-\d{2}-\d{2}T\d{2}:\d{2}$/;
DateUtil.DATE_FORMATS = {
    ISO: "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'",
    ISODATE: 'yyyy-MM-dd',
    ISODATETIME_NO_TIMEZONE: "yyyy-MM-dd'T'HH:mm:ss",
    ISODATETIME_NO_TIMEZONE_NO_SEC: "yyyy-MM-dd'T'HH:mm",
    DATE: 'dd/MM/yyyy',
    DATE_GUION: 'dd-MM-yyyy',
    TIME: 'HH:mm:ss',
    DATETIME: 'dd/MM/yyyy HH:mm:ss',
    DATETIME_NO_SEC: 'dd/MM/yyyy hh:mm a',
    ISODATETIME_MAXHOURS: "yyyy-MM-dd'T'23:59:59",
    MASK_24_HOURS: 'HH',
    MASK_12_HOURS: 'hh',
    MIDDAY_INDICATOR: 'a',
};
DateUtil.MONTHS = [
    'enero',
    'febrero',
    'marzo',
    'abril',
    'mayo',
    'junio',
    'julio',
    'agosto',
    'setiembre',
    'octubre',
    'noviembre',
    'diciembre',
];

class SharedComponentsUtil {
    stopByValidator(controls, validatorAlert, label) {
        let validateError = null;
        if (controls != undefined) {
            validateError = controls.errors;
        }
        ;
        let message = "";
        if (validatorAlert && validateError != null) {
            if (validateError.required != undefined) {
                message = `El Campo ${label} es Requerido.`;
            }
            else if (validateError.minlength != undefined) {
                message = `El Campo ${label} requiere ${validateError.minlength.requiredLength} caracteres minimo.`;
            }
            else if (validateError.maxlength != undefined) {
                message = `El Campo ${label} requiere ${validateError.maxlength.requiredLength} caracteres maximo.`;
            }
            else if (validateError.pattern != undefined) {
                message = `El Campo ${label} tiene formato incorrecto.`;
            }
            else if (validateError.customValidator != undefined) {
                message = `${validateError.customValidator.message}`;
            }
            return {
                error: true,
                message: message
            };
        }
        else {
            return {
                error: false,
                message: "Sin errores"
            };
        }
    }
}

const toastr = toastr_;
class MessageUtilService {
    constructor() {
        this.message = '';
    }
    getMessageError(codigo, element = '', message) {
        // tslint:disable: indent
        switch (codigo) {
            case 'A001':
                this.message = `El campo ${element}  es requerido`;
                break;
            case 'A002':
                this.message = `El campo ${element} no cumple con el formato establecido`;
                break;
            case 'A003':
                this.message = `La fecha ingresada no puede ser superior a la fecha del dí­a actual`;
                break;
            case 'A004':
                this.message = `La fecha del documento no puede ser menor a la fecha del ultimo documento ingresado`;
                break;
            case '000046':
                this.message = `${message}`;
                break;
            case 'A005':
                this.message = `No ha ingresado la serie`;
                break;
            case 'A999':
                this.message = `${element}`;
                element = 'Error';
                // return toastr.error(this.message);
                break;
            case '500':
                this.message = `Por favor comuniquese con el soporte del Sistema`;
                break;
            default:
                this.message = element;
                break;
        }
        toastr.options = {
            positionClass: 'toast-bottom-right',
            closeButton: true,
            progressBar: true,
            newestOnTop: true
        };
        toastr['error'](this.message, `<h5 class='text-white'> ${element} </h5>`);
        return toastr;
    }
    getAlertWarning(mensaje) {
        toastr.options = {
            positionClass: 'toast-bottom-right',
            closeButton: true,
            progressBar: true,
            newestOnTop: true
        };
        toastr['warning'](mensaje);
        return toastr;
    }
    getAlertSuccess(mensaje) {
        toastr.options = {
            positionClass: 'toast-bottom-right',
            closeButton: true,
            progressBar: true,
            newestOnTop: true
        };
        toastr['success'](mensaje);
        return toastr;
    }
}
MessageUtilService.ɵprov = i0.ɵɵdefineInjectable({ factory: function MessageUtilService_Factory() { return new MessageUtilService(); }, token: MessageUtilService, providedIn: "root" });
MessageUtilService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
MessageUtilService.ctorParameters = () => [];

class DatePickerService {
    constructor(showLabel = true, autocomplete = "off", noAutoCompleteNull = true, focusInitial = false, validatorMessage = false, tooltipMessage = true, submitted = true, validatorAlert = false) {
        this.showLabel = showLabel;
        this.autocomplete = autocomplete;
        this.noAutoCompleteNull = noAutoCompleteNull;
        this.focusInitial = focusInitial;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.submitted = submitted;
        this.validatorAlert = validatorAlert;
    }
    getShowLabel() {
        return this.showLabel;
    }
    getAutocomplete() {
        return this.autocomplete;
    }
    getNoAutoCompleteNull() {
        return this.noAutoCompleteNull;
    }
    getFocusInitial() {
        return this.focusInitial;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getSubmitted() {
        return this.submitted;
    }
    getValidatorAlert() {
        return this.validatorAlert;
    }
}
DatePickerService.ɵprov = i0.ɵɵdefineInjectable({ factory: function DatePickerService_Factory() { return new DatePickerService(i0.ɵɵinject("DATE_PICKER_SHOW_LABEL"), i0.ɵɵinject("DATE_PICKER_AUTOCOMPLETE"), i0.ɵɵinject("DATE_PICKER_NO_AUTO_COMPLETE_NULL"), i0.ɵɵinject("DATE_PICKER_FOCUS_INITIAL"), i0.ɵɵinject("DATE_PICKER_VALIDATOR_MESSAGE"), i0.ɵɵinject("DATE_PICKER_TOOLTIP_MESSAGE"), i0.ɵɵinject("DATE_PICKER_SUBMITTED"), i0.ɵɵinject("DATE_PICKER_VALIDATOR_ALERT")); }, token: DatePickerService, providedIn: "root" });
DatePickerService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
DatePickerService.ctorParameters = () => [
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_SHOW_LABEL',] }] },
    { type: String, decorators: [{ type: Inject, args: ['DATE_PICKER_AUTOCOMPLETE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_NO_AUTO_COMPLETE_NULL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_FOCUS_INITIAL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_SUBMITTED',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_PICKER_VALIDATOR_ALERT',] }] }
];

// providers: [I18n, { provide: NgbDatepickerI18n, useClass: CustomDatepickerI18n }, { provide: NgbDateParserFormatter, useClass: CustomDatepickerFormat }]
class DatePickerComponent {
    constructor(el, messageUtilService, datePickerService, _render) {
        this.el = el;
        this.messageUtilService = messageUtilService;
        this.datePickerService = datePickerService;
        this._render = _render;
        /**
        * @description Parametro de la visualización del texto superior
        * @default true
        * @type boolean
        */
        this.showLabel = true;
        /**
        * @description Texto superion
        * @default null
        * @type any
        */
        this.label = null;
        /**
        * @description Parametro de autocompletado
        * @default 'off'
        * @type string
        */
        this.autocomplete = 'off';
        /**
        * @description Parametro de control requerido
        * @default false
        * @type boolean
        */
        this.required = false;
        this.noAutoCompleteNull = true;
        this.readonly = false;
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.validatorAlert = false;
        this.submitted = true;
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.invalid = false;
        this.focusInitial = false;
        /**
        * @description Parametro deshabilitar control
        * @default false
        * @type {boolean}
        */
        this.disabled = false;
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.input = new EventEmitter();
        this.onchange = new EventEmitter();
        this.blur = new EventEmitter();
        this.emitValue = '';
        this.sharedComponentsUtil = new SharedComponentsUtil();
        this._tempValue = '';
        this._initValue = false;
        this.onChange = (_) => { };
        this.onValidationChange = () => { };
        this.onTouch = () => { };
        this.focus = () => {
            const invalidControl = this.el.nativeElement.querySelector('[type="text"]');
            invalidControl.focus();
            invalidControl.select();
        };
        this.showLabel = this.datePickerService.getShowLabel();
        this.autocomplete = this.datePickerService.getAutocomplete();
        this.noAutoCompleteNull = this.datePickerService.getNoAutoCompleteNull();
        this.focusInitial = this.datePickerService.getFocusInitial();
        this.validatorMessage = this.datePickerService.getValidatorMessage();
        this.tooltipMessage = this.datePickerService.getTooltipMessage();
        this.submitted = this.datePickerService.getSubmitted();
        this.validatorAlert = this.datePickerService.getValidatorAlert();
    }
    ngOnChanges(changes) {
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    ngOnInit() {
        if (this.minDate) {
            this.minDate = this.strDateToNgbDate(this.minDate);
        }
        if (this.focusInitial == true && this.disabled == false) {
            const invalidControl = this.el.nativeElement.querySelector('[type="text"]');
            invalidControl.focus();
            invalidControl.select();
        }
    }
    onFocus(evt) {
        if (evt) {
            const invalidControl = this.el.nativeElement.querySelector('[type="text"]');
            invalidControl.select();
        }
    }
    writeValue(value) {
        if (value) {
            this.value = this.strDateToNgbDate(value) || '';
            if (value && value instanceof Date) {
                this._tempValue = DateUtil.dateAutoComplete(value);
                if (this.controls) {
                    this._render.setProperty(this.controls, 'value', this._tempValue);
                }
            }
            if (value && typeof value === 'string')
                this._tempValue = value.trim();
        }
        else {
            this.value = '';
            this._tempValue = '';
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    setDisabledState(isDisabled = false) {
        this.disabled = isDisabled;
    }
    validate(control) {
        this.controls = control;
        if (!this._initValue) {
            if (this._tempValue) {
                this._render.setProperty(control, 'value', this._tempValue);
            }
            this._initValue = true;
        }
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    onBlur() {
        this.onTouch();
    }
    onInput(value) {
        this.emitValue = value;
        this.value = value;
        if (this.value instanceof NgbDate) {
            this.emitValue = this.ngbDatetoString(value);
        }
        this.onChange(this.emitValue);
        this.onchange.emit(this.emitValue);
        this.input.emit(this.emitValue);
        this._tempValue = '';
    }
    onKeyUpEnter() {
        this.enterKeyUp();
    }
    onlyNumbers(e) {
        if (!(e.keyCode >= 48 && e.keyCode <= 57) && e.keyCode != 47) {
            e.preventDefault();
            e.stopPropagation();
        }
    }
    strDateToNgbDate(value) {
        const date = DateUtil.parse(value, 'DATE');
        const ngbDate = {
            day: Number(DateUtil.getDay(date)),
            month: Number(DateUtil.getMonth(date)),
            year: Number(DateUtil.getYear(date)),
        };
        // return ngbDate;
        return new NgbDate(ngbDate.year, ngbDate.month, ngbDate.day);
    }
    ngbDatetoString(value) {
        const concatNgbDate = `0${value.day}`.slice(-2) + `0${value.month}`.slice(-2) + value.year;
        return DateUtil.dateAutoComplete(concatNgbDate);
    }
    enterKeyUp() {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    arrowUpKeyUp() {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
    focusOut(value) {
        if (value && value.trim() !== '') {
            if (this._tempValue === value)
                return;
            this.ngbDatepicker.close();
            if (value instanceof NgbDate) {
                if (value !== this.ngbDatetoString(value)) {
                    this.emitValue = this.ngbDatetoString(value);
                }
                else {
                    this.emitValue = value;
                }
            }
            else {
                value = value.replaceAll('/', '');
                if (this.noAutoCompleteNull) {
                    this.value = this.strDateToNgbDate(DateUtil.dateAutoComplete(value));
                    this.emitValue = DateUtil.dateAutoComplete(value);
                }
                else {
                    if (value != '' && value != null) {
                        this.value = this.strDateToNgbDate(DateUtil.dateAutoComplete(value));
                        this.emitValue = DateUtil.dateAutoComplete(value);
                    }
                }
            }
            this.onTouch();
            this.onChange(this.emitValue);
            if (typeof this.emitValue === 'string')
                this._tempValue = this.emitValue;
        }
    }
}
DatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'date-picker',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n<div\r\n  [class.input-icon]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n  [class.right]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n>\r\n  <!-- tooltip-message es el icono de error -->\r\n  <tooltip-message\r\n    [label]=\"label\"\r\n    [controls]=\"controls\"\r\n    [validatorMessage]=\"validatorMessage\"\r\n    [submitted]=\"submitted\"\r\n    [tooltipMessage]=\"tooltipMessage\"\r\n  ></tooltip-message>\r\n  <div class=\"d-flex p-0 group-input-button\">\r\n    <input\r\n      type=\"text\"\r\n      [autocomplete]=\"autocomplete\"\r\n      [class.is-invalid]=\"\r\n        controls?.errors != null &&\r\n        (controls?.dirty || controls?.touched) &&\r\n        submitted\r\n      \"\r\n      [disabled]=\"disabled\"\r\n      [readonly]=\"readonly\"\r\n      (keyup.enter)=\"onKeyUpEnter()\"\r\n      (keyup.ArrowUp)=\"arrowUpKeyUp()\"\r\n      (keypress)=\"onlyNumbers($event)\"\r\n      (input)=\"onInput($any($event.target).value)\"\r\n      (dateSelect)=\"onInput($event)\"\r\n      (focus)=\"onFocus($any($event.target).value)\"\r\n      (focusout)=\"focusOut($any($event.target).value)\"\r\n      (blur)=\"onBlur()\"\r\n      class=\"form-control form-control-sm rounded-left use-input\"\r\n      container=\"body\"\r\n      placeholder=\"dd/mm/yyyy\"\r\n      [minDate]=\"minDate\"\r\n      [maxDate]=\"maxDate\"\r\n      name=\"fecha\"\r\n      ngbDatepicker\r\n      #fecha=\"ngbDatepicker\"\r\n      [(ngModel)]=\"value\"\r\n    />\r\n    <button\r\n      type=\"button\"\r\n      [disabled]=\"disabled || readonly\"\r\n      class=\"btn btn-info p-0 rounded-0 use-button\"\r\n      (click)=\"fecha.toggle()\"\r\n    >\r\n      <!-- <mat-icon class=\"text-white pt-1\" style=\"font-size: 18px;\" [matTooltip]=\"'Calendario'\" matTooltipClass=\"bg-info\">calendar_today</mat-icon> -->\r\n      <i class=\"fa fa-calendar text-white px-1\" aria-hidden=\"true\"></i>\r\n    </button>\r\n  </div>\r\n</div>\r\n<!-- error-message es el mansaje que aparece abajo del componente -->\r\n<error-message\r\n  [label]=\"label\"\r\n  [controls]=\"controls\"\r\n  [validatorMessage]=\"validatorMessage\"\r\n  [submitted]=\"submitted\"\r\n  [tooltipMessage]=\"tooltipMessage\"\r\n></error-message>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => DatePickerComponent),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => DatePickerComponent),
                        multi: true,
                    },
                    I18n,
                    { provide: NgbDatepickerI18n, useClass: CustomDatepickerI18n },
                    { provide: NgbDateParserFormatter, useClass: CustomDatepickerFormat },
                ],
                styles: ["button[disabled]{pointer-events:none}.sumax-label{color:#646c9a!important}.input-icon{position:relative}.input-icon.right>tooltip-message{left:auto;right:8px;float:right}.input-icon>tooltip-message{color:#ccc;position:absolute;margin-top:.3rem;margin-right:2.5em;z-index:3;width:16px;font-size:16px;text-align:center;left:0}.input-icon.right>.form-control{padding-right:33px;padding-left:12px}.was-validated .form-control:invalid:focus,.form-control.is-invalid:focus{border-color:#dc3545;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.was-validated .form-control:invalid,.form-control.is-invalid{background-image:none;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.form-control:focus,.form-control:active{border-color:#007eff;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #007eff1a!important}\n"]
            },] }
];
DatePickerComponent.ctorParameters = () => [
    { type: ElementRef },
    { type: MessageUtilService },
    { type: DatePickerService },
    { type: Renderer2 }
];
DatePickerComponent.propDecorators = {
    showLabel: [{ type: Input }],
    label: [{ type: Input }],
    autocomplete: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    required: [{ type: Input }],
    noAutoCompleteNull: [{ type: Input }],
    readonly: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    validatorAlert: [{ type: Input }],
    submitted: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    minDate: [{ type: Input }],
    maxDate: [{ type: Input }],
    invalid: [{ type: Input }],
    focusInitial: [{ type: Input }],
    disabled: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    input: [{ type: Output }],
    onchange: [{ type: Output }],
    blur: [{ type: Output }],
    ngbDatepicker: [{ type: ViewChild, args: ['fecha',] }]
};

class errorMessageComponent {
    constructor() { }
    ngOnInit() {
    }
}
errorMessageComponent.decorators = [
    { type: Component, args: [{
                selector: 'error-message',
                template: "<!-- VALIDATOR GENERICOS -->\r\n<small *ngIf=\"validatorMessage && controls?.errors?.required && (controls?.dirty || controls?.touched) && submitted\"\r\n\tclass=\"text-danger\">\r\n\tEl campo {{label}} es requerido<br>\r\n</small>\r\n<small *ngIf=\"validatorMessage && controls?.errors?.minlength && (controls?.dirty || controls?.touched) && submitted\"\r\n\tclass=\"text-danger\">\r\n\tEl campo {{label}} requiere {{controls.errors.minlength.requiredLength}} caracteres minimo.<br>\r\n</small>\r\n<small *ngIf=\"validatorMessage && controls?.errors?.maxlength && (controls?.dirty || controls?.touched) && submitted\"\r\n\tclass=\"text-danger\">\r\n\tEl campo {{label}} requiere {{controls.errors.maxlength.requiredLength}} caracteres maximo.<br>\r\n</small>\r\n<small *ngIf=\"validatorMessage && controls?.errors?.pattern && (controls?.dirty || controls?.touched) && submitted\"\r\n\tclass=\"text-danger\">\r\n\tEl campo {{label}} tiene formato incorrecto.<br>\r\n</small>\r\n<small *ngIf=\"validatorMessage && controls?.errors?.min && (controls?.dirty || controls?.touched) && submitted \"\r\n\tclass=\"text-danger\">\r\n\tEl valor minimo del campo {{label}} es: {{controls?.errors?.min.min}}\r\n</small>\r\n<small *ngIf=\"validatorMessage && controls?.errors?.max && (controls?.dirty || controls?.touched) && submitted \"\r\n\tclass=\"text-danger\">\r\n\tEl valor m\u00E1ximo del campo {{label}} es: {{controls?.errors?.max.max}}\r\n</small>\r\n<!-- CUSTOM VALIDATOR  -->\r\n<small *ngIf=\"validatorMessage && controls?.errors?.customValidator && (controls?.dirty || controls?.touched) && submitted\"\r\n\tclass=\"text-danger\">\r\n\t{{ controls.errors?.customValidator.message}}<br>\r\n</small>",
                styles: [""]
            },] }
];
errorMessageComponent.ctorParameters = () => [];
errorMessageComponent.propDecorators = {
    tooltipMessage: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    controls: [{ type: Input }],
    label: [{ type: Input }],
    submitted: [{ type: Input }]
};

class ErrorMessageModule {
}
ErrorMessageModule.decorators = [
    { type: NgModule, args: [{
                declarations: [errorMessageComponent],
                imports: [
                    CommonModule,
                    RouterModule
                ],
                exports: [errorMessageComponent]
            },] }
];

class tooltipMessageComponent {
    constructor() { }
    ngOnInit() {
    }
}
tooltipMessageComponent.decorators = [
    { type: Component, args: [{
                selector: 'tooltip-message',
                template: "<i *ngIf=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n\tclass=\"fa fa-exclamation-circle text-danger mb-2 ml-3\"\r\n\t[matTooltip]=\"(tooltipMessage && submitted && !validatorMessage && controls?.errors?.required && (controls?.dirty || controls?.touched)) ? 'El campo '+ label+ ' es requerido.' \r\n\t\t\t:(tooltipMessage && submitted && !validatorMessage && controls?.errors?.minlength && (controls?.dirty || controls?.touched)) ? 'El campo '+label+ ' requiere '+controls.errors.minlength.requiredLength +' caracteres minimo.'\r\n\t\t\t:(tooltipMessage && submitted && !validatorMessage && controls?.errors?.maxlength && (controls?.dirty || controls?.touched)) ? 'El campo '+label+ ' requiere '+controls.errors.maxlength.requiredLength +' caracteres maximo.'\r\n\t\t\t:(tooltipMessage && submitted && !validatorMessage && controls?.errors?.min && (controls?.dirty || controls?.touched)) ? 'El valor minimo del campo '+label+' es: '+ controls.errors.min.min\r\n\t\t\t:(tooltipMessage && submitted && !validatorMessage && controls?.errors?.max && (controls?.dirty || controls?.touched)) ? 'El valor m\u00E1ximo del campo '+label+' es: '+ controls.errors.max.max\r\n\t\t\t:(tooltipMessage && submitted && !validatorMessage && controls?.errors?.pattern && (controls?.dirty || controls?.touched)) ? 'El campo '+label+' tiene formato incorrecto.'\r\n\t\t\t:(tooltipMessage && submitted && !validatorMessage && controls?.errors?.customValidator && (controls?.dirty || controls?.touched)) ? controls.errors.customValidator.message : null\"\r\n\tmatTooltipClass=\"bg-danger\"></i>\r\n\r\n\r\n\t",
                styles: [""]
            },] }
];
tooltipMessageComponent.ctorParameters = () => [];
tooltipMessageComponent.propDecorators = {
    tooltipMessage: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    controls: [{ type: Input }],
    label: [{ type: Input }],
    submitted: [{ type: Input }]
};

class TooltipMessageModule {
}
TooltipMessageModule.decorators = [
    { type: NgModule, args: [{
                declarations: [tooltipMessageComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    MatIconModule,
                    MatTooltipModule
                ],
                exports: [tooltipMessageComponent]
            },] }
];

class DatePicker {
}

class DatePickerModule {
    static forRoot(datePicker = new DatePicker()) {
        return {
            ngModule: DatePickerModule,
            providers: [
                { provide: 'DATE_PICKER_SHOW_LABEL', useValue: datePicker.showLabel },
                { provide: 'DATE_PICKER_AUTOCOMPLETE', useValue: datePicker.autocomplete },
                { provide: 'DATE_PICKER_NO_AUTO_COMPLETE_NULL', useValue: datePicker.noAutoCompleteNull },
                { provide: 'DATE_PICKER_FOCUS_INITIAL', useValue: datePicker.focusInitial },
                { provide: 'DATE_PICKER_VALIDATOR_MESSAGE', useValue: datePicker.validatorMessage },
                { provide: 'DATE_PICKER_TOOLTIP_MESSAGE', useValue: datePicker.tooltipMessage },
                { provide: 'DATE_PICKER_SUBMITTED', useValue: datePicker.submitted },
                { provide: 'DATE_PICKER_VALIDATOR_ALERT', useValue: datePicker.validatorAlert },
                DatePickerService
            ]
        };
    }
}
DatePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DatePickerComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    MatIconModule,
                    MatTooltipModule,
                    NgbDatepickerModule
                ],
                exports: [DatePickerComponent]
            },] }
];

class DateTimeModel {
    constructor(init) {
        Object.assign(this, init);
    }
    static fromLocalString(dateString) {
        const date = new Date(dateString);
        const isValidDate = !isNaN(date.valueOf());
        if (!dateString || !isValidDate) {
            return null;
        }
        return new DateTimeModel({
            year: date.getFullYear(),
            month: date.getMonth() + 1,
            day: date.getDate(),
            hour: date.getHours(),
            minute: date.getMinutes(),
            second: date.getSeconds(),
            timeZoneOffset: date.getTimezoneOffset()
        });
    }
    isInteger(value) {
        return typeof value === 'number' && isFinite(value) && Math.floor(value) === value;
    }
    toString() {
        if (this.isInteger(this.year) && this.isInteger(this.month) && this.isInteger(this.day)) {
            const year = this.year.toString().padStart(2, '0');
            const month = this.month.toString().padStart(2, '0');
            const day = this.day.toString().padStart(2, '0');
            if (!this.hour) {
                this.hour = 0;
            }
            if (!this.minute) {
                this.minute = 0;
            }
            if (!this.second) {
                this.second = 0;
            }
            if (!this.timeZoneOffset) {
                this.timeZoneOffset = new Date().getTimezoneOffset();
            }
            const hour = this.hour.toString().padStart(2, '0');
            const minute = this.minute.toString().padStart(2, '0');
            const second = this.second.toString().padStart(2, '0');
            const tzo = -this.timeZoneOffset;
            const dif = tzo >= 0 ? '+' : '-';
            const pad = (num) => {
                const norm = Math.floor(Math.abs(num));
                return (norm < 10 ? '0' : '') + norm;
            };
            const isoString = `${pad(year)}-${pad(month)}-${pad(day)}T${pad(hour)}:${pad(minute)}:${pad(second)}${dif}${pad(tzo / 60)}:${pad(tzo % 60)}`;
            return isoString;
        }
        return null;
    }
}

class DateTimePickerEditableService {
    constructor(showLabel = true, openWhenFocus = false, goNextWhenSelect = false, validatorMessage = false, tooltipMessage = true, submitted = true, format = 12, clearable = true, autoCompleteHours = false) {
        this.showLabel = showLabel;
        this.openWhenFocus = openWhenFocus;
        this.goNextWhenSelect = goNextWhenSelect;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.submitted = submitted;
        this.format = format;
        this.clearable = clearable;
        this.autoCompleteHours = autoCompleteHours;
    }
    getShowLabel() {
        return this.showLabel;
    }
    getOpenWhenFocus() {
        return this.openWhenFocus;
    }
    getGoNextWhenSelect() {
        return this.goNextWhenSelect;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getSubmitted() {
        return this.submitted;
    }
    getFormat() {
        return this.format;
    }
    getClearable() {
        return this.clearable;
    }
    getAutoCompleteHours() {
        return this.autoCompleteHours;
    }
}
DateTimePickerEditableService.ɵprov = i0.ɵɵdefineInjectable({ factory: function DateTimePickerEditableService_Factory() { return new DateTimePickerEditableService(i0.ɵɵinject("DATE_TIME_PICKER_SHOW_LABEL"), i0.ɵɵinject("DATE_TIME_PICKER_OPEN_WHEN_FOCUS"), i0.ɵɵinject("DATE_TIME_PICKER_GO_NEXT_WHEN_SELECT"), i0.ɵɵinject("DATE_TIME_PICKER_VALIDATOR_MESSAGE"), i0.ɵɵinject("DATE_TIME_PICKER_TOOLTIP_MESSAGE"), i0.ɵɵinject("DATE_TIME_PICKER_SUBMITTED"), i0.ɵɵinject("DATE_TIME_PICKER_FORMART"), i0.ɵɵinject("DATE_TIME_PICKER_CLEARABLE"), i0.ɵɵinject("DATE_TIME_PICKER_AUTOCOMPLETE_HOURS")); }, token: DateTimePickerEditableService, providedIn: "root" });
DateTimePickerEditableService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
DateTimePickerEditableService.ctorParameters = () => [
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_SHOW_LABEL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_OPEN_WHEN_FOCUS',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_GO_NEXT_WHEN_SELECT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_SUBMITTED',] }] },
    { type: undefined, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_FORMART',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_CLEARABLE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_AUTOCOMPLETE_HOURS',] }] }
];

const MASK_12_HOURS = 'dd/mm/yyyy --:-- --';
const MASK_24_HOURS = 'dd/mm/yyyy --:--';
class DateTimePickerMaterialComponent {
    constructor(datePipe, calendar, dateTimePickerEditableService, cdrf) {
        this.datePipe = datePipe;
        this.calendar = calendar;
        this.dateTimePickerEditableService = dateTimePickerEditableService;
        this.cdrf = cdrf;
        /**
        * @description Texto superion
        * @default null
        * @type any
        */
        this.label = '';
        /**
        * @description Parametro de la visualización del texto superior
        * @default true
        * @type boolean
        */
        this.showLabel = true;
        this.readonly = false;
        /**
        * @description Parametro de control requerido
        * @default false
        * @type boolean
        */
        this.required = false;
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.submitted = true;
        /**
        * @description Parametro de formato de fecha: 12 | 14
        * @default 24
        * @type 12 | 14
        */
        this.format = 24;
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.openWhenFocus = false;
        this.goNextWhenSelect = false;
        /**
        * @description Parametro para mostrar el botón de eliminar
        * @default false
        * @type boolean
        */
        this.clearable = true;
        /**
        * @description Parametro de autocompletado:
        * True: autocompleta con la hora ó minuto actual
        * False: autocompleta con 00:00
        * @default false
        * @type boolean
        */
        this.autoCompleteHours = false;
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.onChange = (_) => { };
        this.onTouch = () => { };
        this.onValidationChange = () => { };
        this.disabled = false;
        this.contador = 0;
        this.position = 0;
        this.dateTimeControl = new FormControl('dd/mm/yyyy --:-- --');
        this.hoursControl = new FormControl({
            hour: null,
            minute: null,
        });
        this.dateControl = new FormControl({
            year: null,
            month: null,
            day: null,
        });
        this.today = this.calendar.getToday();
        this.showLabel = this.dateTimePickerEditableService.getShowLabel();
        this.openWhenFocus = this.dateTimePickerEditableService.getOpenWhenFocus();
        this.goNextWhenSelect =
            this.dateTimePickerEditableService.getGoNextWhenSelect();
        this.validatorMessage =
            this.dateTimePickerEditableService.getValidatorMessage();
        this.tooltipMessage =
            this.dateTimePickerEditableService.getTooltipMessage();
        this.submitted = this.dateTimePickerEditableService.getSubmitted();
        this.format = this.dateTimePickerEditableService.getFormat();
        this.clearable = this.dateTimePickerEditableService.getClearable();
        this.autoCompleteHours = this.dateTimePickerEditableService.getAutoCompleteHours();
    }
    get stringFormat() {
        return this.format === 12 ? 'dd/MM/yyyy hh:mm a' : 'dd/MM/yyyy HH:mm';
    }
    ngOnInit() {
        this.hoursChange();
        const timeout = setTimeout(() => {
            this.dateChange();
            clearTimeout(timeout);
            if (!this.clearable)
                this.btnClean.nativeElement.style.visibility = "hidden";
        }, 100);
        if (this.format == 12) {
            this.dateTimeControl.setValue(MASK_12_HOURS);
        }
        else {
            this.dateTimeControl.setValue(MASK_24_HOURS);
        }
    }
    ngOnChanges(changes) {
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    focus() {
        this.inputDateTime.nativeElement.focus();
        const timeout = setTimeout(() => {
            if (!this.disabled)
                this.inputDateTime.nativeElement.setSelectionRange(0, 2);
            clearTimeout(timeout);
        }, 100);
        if (!this.readonly && this.openWhenFocus) {
            this.ngbDatepicker.open();
        }
    }
    focusOut(event) {
        if (event.target.ariaLabel == 'Minutes') {
            this.ngbDatepicker.close();
            if (this.goNextWhenSelect) {
                this.goNext();
            }
        }
    }
    focusOutInput() {
        const value = this.dateTimeControl.value;
        if ((value != MASK_12_HOURS && this.format == 12) ||
            (value != MASK_24_HOURS && this.format == 24)) {
            const dia = value.substring(0, 2);
            const mes = value.substring(3, 5);
            const anio = value.substring(6, 10);
            const hora = value.substring(11, 13);
            const minutos = value.substring(14, 16);
            if (isNaN(Number(dia)) ||
                dia == '00' ||
                isNaN(Number(mes)) ||
                mes == '00' ||
                isNaN(Number(anio)) ||
                anio == '0000' ||
                isNaN(Number(hora)) ||
                isNaN(Number(minutos))) {
                this.dateControl.setValue({
                    year: isNaN(Number(anio)) || anio == '0000'
                        ? this.today.year
                        : Number(anio),
                    month: isNaN(Number(mes)) || mes == '00'
                        ? this.today.month
                        : Number(mes),
                    day: isNaN(Number(dia)) || dia == '00' ? this.today.day : Number(dia),
                }, { emitEvent: false });
                let hour = this.hoursControl.value.hour;
                if (isNaN(Number(hora)))
                    hour = this.autoCompleteHours ? DateUtil.getHours(DateUtil.now()) : 0;
                let minute = this.hoursControl.value.minute;
                if (isNaN(Number(minutos)))
                    minute = this.autoCompleteHours ? DateUtil.getMinutes(DateUtil.now()) : 0;
                this.hoursControl.setValue({
                    hour,
                    minute,
                }, { emitEvent: false });
                const input = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
                try {
                    this.dateTimeControl.setValue(this.datePipe.transform(input, this.stringFormat));
                }
                finally {
                    this.onEmit();
                }
            }
        }
        this.contador = 0;
    }
    onFocus(input) {
        if (input.selectionStart == 0 &&
            (input.selectionEnd == 16 || input.selectionEnd == 19)) {
            input.setSelectionRange(0, 2);
            this.contador = 0;
        }
    }
    onClick(e, input) {
        e.preventDefault();
        if (this.disabled)
            return;
        if (input.selectionStart == 0 ||
            input.selectionStart == 1 ||
            input.selectionStart == 2) {
            const timeout = setTimeout(() => {
                input.setSelectionRange(0, 2);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
        else if (input.selectionStart == 3 ||
            input.selectionStart == 4 ||
            input.selectionStart == 5) {
            const timeout = setTimeout(() => {
                input.setSelectionRange(3, 5);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
        else if (input.selectionStart == 6 ||
            input.selectionStart == 7 ||
            input.selectionStart == 8 ||
            input.selectionStart == 9 ||
            input.selectionStart == 10) {
            const timeout = setTimeout(() => {
                input.setSelectionRange(6, 10);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
        else if (input.selectionStart == 11 ||
            input.selectionStart == 12 ||
            input.selectionStart == 13) {
            const timeout = setTimeout(() => {
                input.setSelectionRange(11, 13);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
        else if (input.selectionStart == 14 ||
            input.selectionStart == 15 ||
            input.selectionStart == 16) {
            const timeout = setTimeout(() => {
                input.setSelectionRange(14, 16);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
        else if (input.selectionStart == 17 ||
            input.selectionStart == 18 ||
            input.selectionStart == 19) {
            const timeout = setTimeout(() => {
                input.setSelectionRange(17, 19);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
        else {
            const timeout = setTimeout(() => {
                input.setSelectionRange(0, 2);
                this.contador = 0;
                clearTimeout(timeout);
            }, 100);
        }
    }
    onBlur() {
        this.onEmit();
    }
    onKeyUp(e) {
        const input = e.target;
        if (this.disabled)
            return;
        if (!isNaN(Number(e.key)) && e.key.trim() != '') {
            //============================= DIA ==================================
            if (input.selectionStart == 0 && input.selectionEnd == 2) {
                const valorActual = this.dateTimeControl.value;
                const diaActual = valorActual.substring(0, 2);
                if (diaActual == 'dd') {
                    const nuevoValor = `${e.key.padStart(2, 0)}${valorActual.substring(2)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { day: Number(this.dateTimeControl.value.substring(0, 2)) }));
                    this.contador++;
                    if (e.key > 3) {
                        this.contador = 0;
                        input.setSelectionRange(3, 5);
                        this.onEmit();
                        return;
                    }
                    else
                        this.onEmit();
                }
                else if (Number(diaActual) <= 3 &&
                    Number(diaActual) > 0 &&
                    this.contador > 0) {
                    const nuevoValor = `${Number(Number(diaActual).toString() + Number(e.key)) > 31
                        ? 31
                        : Number(diaActual).toString() + Number(e.key)}${valorActual.substring(2)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { day: Number(this.dateTimeControl.value.substring(0, 2)) }));
                    this.contador++;
                    this.onEmit();
                    input.setSelectionRange(3, 5);
                    this.contador = 0;
                    return;
                }
                else {
                    const nuevoValor = `${e.key.padStart(2, 0)}${valorActual.substring(2)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { day: Number(this.dateTimeControl.value.substring(0, 2)) }));
                    this.contador++;
                    if (Number(e.key.padStart(2, 0)) > 3 || this.contador > 1) {
                        this.contador = 0;
                        input.setSelectionRange(3, 5);
                        this.onEmit();
                        return;
                    }
                    else
                        this.onEmit();
                }
                this.onEmit();
                input.setSelectionRange(0, 2);
            }
            //============================= MES ==================================
            else if (input.selectionStart == 3 && input.selectionEnd == 5) {
                const valorActual = this.dateTimeControl.value;
                const mesActual = valorActual.substring(3, 5);
                if (mesActual == 'mm') {
                    const nuevoValor = `${valorActual.substring(0, 3)}${e.key.padStart(2, 0)}${valorActual.substring(5)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { month: Number(this.dateTimeControl.value.substring(3, 5)) }));
                    this.contador++;
                    if (e.key > 1) {
                        this.onEmit();
                        input.setSelectionRange(6, 10);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                else if (Number(mesActual) <= 1 &&
                    Number(mesActual) > 0 &&
                    this.contador > 0) {
                    const nuevoValor = `${valorActual.substring(0, 3)}${Number(Number(mesActual).toString() + Number(e.key)) > 12
                        ? 12
                        : Number(mesActual).toString() + Number(e.key)}${valorActual.substring(5)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { month: Number(this.dateTimeControl.value.substring(3, 5)) }));
                    this.contador++;
                    this.onEmit();
                    input.setSelectionRange(6, 10);
                    this.contador = 0;
                    return;
                }
                else {
                    const nuevoValor = `${valorActual.substring(0, 3)}${e.key.padStart(2, 0)}${valorActual.substring(5)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { month: Number(this.dateTimeControl.value.substring(3, 5)) }));
                    this.contador++;
                    if (Number(e.key.padStart(2, 0)) > 1 || this.contador > 1) {
                        this.onEmit();
                        input.setSelectionRange(6, 10);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                this.onEmit();
                input.setSelectionRange(3, 5);
            }
            //============================= AÑO ==================================
            else if (input.selectionStart == 6 && input.selectionEnd == 10) {
                const valorActual = this.dateTimeControl.value;
                const anioActual = valorActual.substring(6, 10);
                if (anioActual == 'yyyy') {
                    const nuevoValor = `${valorActual.substring(0, 6)}${e.key.padStart(4, 0)}${valorActual.substring(10)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: Number(this.dateTimeControl.value.substring(6, 10)) }));
                    this.contador++;
                    if (e.key > 2) {
                        const nuevoValor = `${valorActual.substring(0, 6)}${DateUtil.getYear(DateUtil.now())}${valorActual.substring(10)}`;
                        this.dateTimeControl.setValue(nuevoValor);
                        this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: Number(this.dateTimeControl.value.substring(6, 10)) }));
                        this.onEmit();
                        input.setSelectionRange(11, 13);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                else if (Number(anioActual) <= 2999 && Number(anioActual) > 0) {
                    let nuevoValor;
                    this.contador++;
                    if (Number(anioActual) >= 1000) {
                        nuevoValor = `${valorActual.substring(0, 6)}${Number(e.key)
                            .toString()
                            .padStart(4, '0')}${valorActual.substring(10)}`;
                    }
                    else {
                        nuevoValor = `${valorActual.substring(0, 6)}${(Number(anioActual).toString() + Number(e.key)).padStart(4, '0')}${valorActual.substring(10)}`;
                        this.dateTimeControl.setValue(nuevoValor);
                        this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: Number(this.dateTimeControl.value.substring(6, 10)) }));
                        if (Number(Number(anioActual).toString() + Number(e.key)) > 1000 &&
                            Number(Number(anioActual).toString() + Number(e.key)) < 3000) {
                            this.onEmit();
                            input.setSelectionRange(11, 13);
                            this.contador = 0;
                            return;
                        }
                        else if (Number(Number(anioActual).toString() + Number(e.key)) > 2999) {
                            nuevoValor = `${valorActual.substring(0, 6)}${DateUtil.getYear(DateUtil.now())}${valorActual.substring(10)}`;
                            this.dateTimeControl.setValue(nuevoValor);
                            this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: Number(this.dateTimeControl.value.substring(6, 10)) }));
                            this.onEmit();
                            input.setSelectionRange(11, 13);
                            this.contador = 0;
                            return;
                        }
                    }
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: Number(this.dateTimeControl.value.substring(6, 10)) }));
                }
                else {
                    const nuevoValor = `${valorActual.substring(0, 6)}${e.key.padStart(4, 0)}${valorActual.substring(10)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: Number(this.dateTimeControl.value.substring(6, 10)) }));
                }
                this.contador++;
                this.onEmit();
                input.setSelectionRange(6, 10);
            }
            //============================= HORA =================================
            else if (input.selectionStart == 11 && input.selectionEnd == 13) {
                const valorActual = this.dateTimeControl.value;
                const horaActual = valorActual.substring(11, 13);
                if (horaActual == '--') {
                    const nuevoValor = `${valorActual.substring(0, 11)}${e.key.padStart(2, 0)}${valorActual.substring(13)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    //=========== FORMATO 12 HORAS===========
                    if (this.format == 12)
                        this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour: /[0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value.substring(11))
                                ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH'))
                                : Number(this.dateTimeControl.value.substring(11, 13)), minute: this.dateTimeControl.value.substring(14, 16) == '--'
                                ? 0
                                : this.hoursControl.value.minute }));
                    //=========== FORMATO 24 HORAS===========
                    else
                        this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour: /[0-1][0-9]:[0-6][0-9]/.test(this.dateTimeControl.value.substring(11))
                                ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH'))
                                : Number(this.dateTimeControl.value.substring(11, 13)), minute: this.dateTimeControl.value.substring(14, 16) == '00'
                                ? 0
                                : this.hoursControl.value.minute }));
                    this.contador++;
                    if (e.key > 1 && this.format == 12) {
                        this.onEmit();
                        input.setSelectionRange(14, 16);
                        this.contador = 0;
                        return;
                    }
                    else if (e.key > 2 && this.format == 24) {
                        this.onEmit();
                        input.setSelectionRange(14, 16);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                else if (Number(horaActual) <= 1 &&
                    Number(horaActual) > 0 &&
                    this.contador > 0 &&
                    this.format == 12) {
                    const nuevoValor = `${valorActual.substring(0, 11)}${Number(Number(horaActual).toString() + Number(e.key)) > 12
                        ? 12
                        : Number(horaActual).toString() + Number(e.key)}${valorActual.substring(13)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour: /[0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value.substring(11))
                            ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH'))
                            : Number(this.dateTimeControl.value.substring(11, 13)), minute: this.dateTimeControl.value.substring(14, 16) == '00'
                            ? 0
                            : this.hoursControl.value.minute }));
                    this.contador++;
                    this.onEmit();
                    input.setSelectionRange(14, 16);
                    this.contador = 0;
                    return;
                }
                else if (Number(horaActual) <= 2 &&
                    Number(horaActual) > 0 &&
                    this.contador > 0 &&
                    this.format == 24) {
                    const nuevoValor = `${valorActual.substring(0, 11)}${Number(Number(horaActual).toString() + Number(e.key)) > 24
                        ? 24
                        : Number(horaActual).toString() + Number(e.key)}${valorActual.substring(13)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    let hour;
                    try {
                        hour = /[0-1][0-9]:[0-6][0-9]/.test(this.dateTimeControl.value.substring(11))
                            ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH'))
                            : Number(this.dateTimeControl.value.substring(11, 13));
                    }
                    catch (error) {
                        hour = Number(this.dateTimeControl.value.substring(11, 13));
                    }
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour, minute: this.dateTimeControl.value.substring(14, 16) == '00'
                            ? 0
                            : this.hoursControl.value.minute }));
                    this.contador++;
                    this.onEmit();
                    input.setSelectionRange(14, 16);
                    this.contador = 0;
                    return;
                }
                else {
                    const nuevoValor = `${valorActual.substring(0, 11)}${e.key.padStart(2, 0)}${valorActual.substring(13)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    const regex = this.format == 12
                        ? /[0-1][0-9]:[0-6][0-9] [A,P]M/
                        : /[0-1][0-9]:[0-6][0-9]/;
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour: regex.test(this.dateTimeControl.value.substring(11))
                            ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH'))
                            : Number(this.dateTimeControl.value.substring(11, 13)), minute: this.dateTimeControl.value.substring(14, 16) == '00' ||
                            this.dateTimeControl.value.substring(14, 16) == '--'
                            ? 0
                            : this.hoursControl.value.minute }));
                    this.contador++;
                    if ((Number(e.key.padStart(2, 0)) > 1 || this.contador > 1) &&
                        this.format == 12) {
                        this.onEmit();
                        input.setSelectionRange(14, 16);
                        this.contador = 0;
                        return;
                    }
                    else if ((Number(e.key.padStart(2, 0)) > 2 || this.contador > 1) &&
                        this.format == 24) {
                        this.onEmit();
                        input.setSelectionRange(14, 16);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                this.onEmit();
                input.setSelectionRange(11, 13);
            }
            //============================ MINUTOS ===============================
            else if (input.selectionStart == 14 && input.selectionEnd == 16) {
                const valorActual = this.dateTimeControl.value;
                const minutosActuales = valorActual.substring(14, 16);
                if (minutosActuales == '--') {
                    const nuevoValor = `${valorActual.substring(0, 14)}${e.key.padStart(2, 0)}${valorActual.substring(16)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { minute: /[0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value.substring(11))
                            ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'mm'))
                            : Number(this.dateTimeControl.value.substring(14, 16)) }));
                    this.contador++;
                    if (e.key > 5) {
                        this.onEmit();
                        if (this.format == 12)
                            input.setSelectionRange(17, 19);
                        else
                            input.setSelectionRange(14, 16);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                else if (Number(minutosActuales) <= 5 &&
                    Number(minutosActuales) > 0 &&
                    this.contador > 0) {
                    const nuevoValor = `${valorActual.substring(0, 14)}${Number(Number(minutosActuales).toString() + Number(e.key)) > 59
                        ? 59
                        : Number(minutosActuales).toString() + Number(e.key)}${valorActual.substring(16)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    let minute;
                    const regex = this.format == 12
                        ? /[0-1][0-9]:[0-6][0-9] [A,P]M/
                        : /[0-1][0-9]:[0-6][0-9]/;
                    try {
                        minute = regex.test(this.dateTimeControl.value.substring(11))
                            ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'mm'))
                            : Number(this.dateTimeControl.value.substring(14, 16));
                    }
                    catch (error) {
                        minute = Number(this.dateTimeControl.value.substring(14, 16));
                    }
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { minute }));
                    this.contador++;
                    this.onEmit();
                    if (this.format == 12)
                        input.setSelectionRange(17, 19);
                    else
                        input.setSelectionRange(14, 16);
                    this.contador = 0;
                    return;
                }
                else {
                    const nuevoValor = `${valorActual.substring(0, 14)}${e.key.padStart(2, 0)}${valorActual.substring(16)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { minute: /[0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value.substring(11))
                            ? Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'mm'))
                            : Number(this.dateTimeControl.value.substring(14, 16)) }));
                    this.contador++;
                    if (Number(e.key.padStart(2, 0)) > 5 || this.contador > 1) {
                        this.onEmit();
                        if (this.format == 12)
                            input.setSelectionRange(17, 19);
                        else
                            input.setSelectionRange(14, 16);
                        this.contador = 0;
                        return;
                    }
                    else
                        this.onEmit();
                }
                this.onEmit();
                input.setSelectionRange(14, 16);
            }
        }
        else {
            //======================== EVENTOS TECLADO ===========================
            if (e.key == 'ArrowRight') {
                if (input.selectionStart == 0 && input.selectionEnd == 2) {
                    input.setSelectionRange(3, 5);
                    this.contador = 0;
                }
                else if (input.selectionStart == 3 && input.selectionEnd == 5) {
                    input.setSelectionRange(6, 10);
                    this.contador = 0;
                }
                else if (input.selectionStart == 6 && input.selectionEnd == 10) {
                    input.setSelectionRange(11, 13);
                    this.contador = 0;
                }
                else if (input.selectionStart == 11 && input.selectionEnd == 13) {
                    input.setSelectionRange(14, 16);
                    this.contador = 0;
                }
                else if (input.selectionStart == 14 && input.selectionEnd == 16) {
                    if (this.format == 12)
                        input.setSelectionRange(17, 19);
                    else if (this.format == 24)
                        this.btnOpen.nativeElement.focus();
                    this.contador = 0;
                }
                else if (input.selectionStart == 17 && input.selectionEnd == 19) {
                    this.btnOpen.nativeElement.focus();
                    this.contador = 0;
                }
            }
            else if (e.key == 'ArrowLeft') {
                if (input.selectionStart == 0 && input.selectionEnd == 2) {
                    this.goBack();
                    this.contador = 0;
                }
                else if (input.selectionStart == 3 && input.selectionEnd == 5) {
                    input.setSelectionRange(0, 2);
                    this.contador = 0;
                }
                else if (input.selectionStart == 6 && input.selectionEnd == 10) {
                    input.setSelectionRange(3, 5);
                    this.contador = 0;
                }
                else if (input.selectionStart == 11 && input.selectionEnd == 13) {
                    input.setSelectionRange(6, 10);
                    this.contador = 0;
                }
                else if (input.selectionStart == 14 && input.selectionEnd == 16) {
                    input.setSelectionRange(11, 13);
                    this.contador = 0;
                }
                else if (input.selectionStart == 17 && input.selectionEnd == 19) {
                    input.setSelectionRange(14, 16);
                    this.contador = 0;
                }
            }
            else if (e.key.toLowerCase() == 'a') {
                if (input.selectionStart == 17 && input.selectionEnd == 19) {
                    const valorActual = this.dateTimeControl.value;
                    const nuevoValor = `${valorActual.substring(0, 17)}AM`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour: Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH')) }));
                    this.onEmit();
                    input.setSelectionRange(17, 19);
                }
            }
            else if (e.key.toLowerCase() == 'p') {
                if (input.selectionStart == 17 && input.selectionEnd == 19) {
                    const valorActual = this.dateTimeControl.value;
                    const nuevoValor = `${valorActual.substring(0, 17)}PM`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { hour: Number(this.datePipe.transform(`01/01/2020 ${this.dateTimeControl.value.substring(11)}`, 'HH')) }));
                    this.onEmit();
                    input.setSelectionRange(17, 19);
                }
            }
            else if (e.code == 'Space') {
                const valorActual = this.dateTimeControl.value;
                const diaActual = this.today.day.toString();
                const mesActual = this.today.month.toString();
                const anioActual = this.today.year.toString();
                const horaActual = DateUtil.toStrFormat(DateUtil.now(), this.format == 24 ? 'MASK_24_HOURS' : 'MASK_12_HOURS');
                const t = DateUtil.toStrFormat(DateUtil.now(), 'MIDDAY_INDICATOR');
                const minutosActuales = DateUtil.getMinutes(DateUtil.now()).toString().padStart(2, '0');
                if (input.selectionStart == 0 && input.selectionEnd == 2) {
                    const nuevoValor = `${diaActual.padStart(2, '0')}${valorActual.substring(2)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { day: this.today.day }), { emitEvent: false });
                    input.setSelectionRange(3, 5);
                }
                else if (input.selectionStart == 3 && input.selectionEnd == 5) {
                    const nuevoValor = `${valorActual.substring(0, 3)}${mesActual.padStart(2, '0')}${valorActual.substring(5)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { month: this.today.month }), { emitEvent: false });
                    input.setSelectionRange(6, 10);
                }
                else if (input.selectionStart == 6 && input.selectionEnd == 10) {
                    const nuevoValor = `${valorActual.substring(0, 6)}${anioActual.padStart(4, '0')}${valorActual.substring(10)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: this.today.year }), { emitEvent: false });
                    input.setSelectionRange(11, 13);
                }
                else if (input.selectionStart == 11 && input.selectionEnd == 13) {
                    let nuevoValor;
                    if (this.format == 24)
                        nuevoValor = `${valorActual.substring(0, 11)}${horaActual}${valorActual.substring(13)}`;
                    else if (this.format == 12)
                        nuevoValor = `${valorActual.substring(0, 11)}${horaActual}${valorActual.substring(13, 17)}${t.toUpperCase()}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { minute: this.hoursControl.value.minute != null ? this.hoursControl.value.minute : 0, hour: this.format == 12 ? Number(horaActual) : Number(horaActual) + 12 }));
                    console.log(this.hoursControl);
                    input.setSelectionRange(14, 16);
                }
                else if (input.selectionStart == 14 && input.selectionEnd == 16) {
                    const nuevoValor = `${valorActual.substring(0, 14)}${minutosActuales.padStart(2, '0')}${valorActual.substring(16)}`;
                    this.dateTimeControl.setValue(nuevoValor);
                    this.hoursControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), { minute: Number(minutosActuales) }));
                    if (this.format == 12)
                        input.setSelectionRange(17, 19);
                    else
                        input.setSelectionRange(14, 16);
                }
                this.onEmit();
            }
            else if (e.key == 'Enter' || e.key == 'ArrowDown') {
                this.goNext();
            }
            else if (e.key == 'ArrowUp') {
                this.goBack();
            }
            else if (e.key == 'Delete') {
                this.limpiarTodo();
            }
            else if (e.key == 'Backspace') {
                this.limpiar();
            }
        }
    }
    limpiar() {
        if (this.inputDateTime.nativeElement.selectionStart == 0 &&
            this.inputDateTime.nativeElement.selectionEnd == 2) {
            this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { day: null }), { emitEvent: false });
            this.dateTimeControl.setValue(`dd${this.dateTimeControl.value.substring(2)}`);
            this.onChange(null);
            this.onTouch();
            this.inputDateTime.nativeElement.setSelectionRange(0, 2);
            this.contador = 0;
        }
        else if (this.inputDateTime.nativeElement.selectionStart == 3 &&
            this.inputDateTime.nativeElement.selectionEnd == 5) {
            this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { month: null }), { emitEvent: false });
            this.dateTimeControl.setValue(`${this.dateTimeControl.value.substring(0, 3)}mm${this.dateTimeControl.value.substring(5)}`);
            this.onChange(null);
            this.onTouch();
            this.inputDateTime.nativeElement.setSelectionRange(3, 5);
            this.contador = 0;
        }
        else if (this.inputDateTime.nativeElement.selectionStart == 6 &&
            this.inputDateTime.nativeElement.selectionEnd == 10) {
            this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { year: null }), { emitEvent: false });
            this.dateTimeControl.setValue(`${this.dateTimeControl.value.substring(0, 6)}yyyy${this.dateTimeControl.value.substring(10)}`);
            this.onChange(null);
            this.onTouch();
            this.inputDateTime.nativeElement.setSelectionRange(6, 10);
            this.contador = 0;
        }
        else if (this.inputDateTime.nativeElement.selectionStart == 11 &&
            this.inputDateTime.nativeElement.selectionEnd == 13) {
            this.hoursControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { hour: null }), { emitEvent: false });
            this.dateTimeControl.setValue(`${this.dateTimeControl.value.substring(0, 11)}--${this.dateTimeControl.value.substring(13)}`);
            this.onChange(null);
            this.onTouch();
            this.inputDateTime.nativeElement.setSelectionRange(11, 13);
            this.contador = 0;
        }
        else if (this.inputDateTime.nativeElement.selectionStart == 14 &&
            this.inputDateTime.nativeElement.selectionEnd == 16) {
            this.hoursControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), { minute: null }), { emitEvent: false });
            this.dateTimeControl.setValue(`${this.dateTimeControl.value.substring(0, 14)}--${this.dateTimeControl.value.substring(16)}`);
            this.onChange(null);
            this.onTouch();
            this.inputDateTime.nativeElement.setSelectionRange(14, 16);
            this.contador = 0;
        }
    }
    preventDefault(e) {
        e.preventDefault();
        return false;
    }
    writeValue(obj) {
        if (obj != null) {
            this.dateControl.setValue(DateTimeModel.fromLocalString(obj));
            this.hoursControl.setValue({
                hour: this.dateControl.value.hour,
                minute: this.dateControl.value.minute,
                second: this.dateControl.value.second,
            });
            this.dateTimeControl.setValue(this.datePipe.transform(obj, this.stringFormat));
        }
    }
    hoursChange() {
        if (this.format == 12)
            this.hoursControl.valueChanges.subscribe((res) => {
                if (/[0-3][0-9]\/[0-1][0-9]\/[0-9][0-9][0-9][0-9] [0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value) ||
                    /[0-3][0-9]\/[0-1][0-9]\/[0-9][0-9][0-9][0-9]/.test(this.dateTimeControl.value.substring(0, 10))) {
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), res), { emitEvent: false });
                    try {
                        const input = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
                        this.dateTimeControl.setValue(this.datePipe.transform(input, this.stringFormat));
                    }
                    finally {
                        this.onEmit();
                    }
                }
            });
        else if (this.format == 24)
            this.hoursControl.valueChanges.subscribe((res) => {
                if (/[0-3][0-9]\/[0-1][0-9]\/[0-9][0-9][0-9][0-9] [0-1][0-9]:[0-6][0-9]/.test(this.dateTimeControl.value) ||
                    /[0-3][0-9]\/[0-1][0-9]\/[0-9][0-9][0-9][0-9]/.test(this.dateTimeControl.value.substring(0, 10))) {
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.dateControl.value), res), { emitEvent: false });
                    try {
                        const input = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
                        this.dateTimeControl.setValue(this.datePipe.transform(input, this.stringFormat));
                    }
                    catch (error) {
                        /* console.error(error) */
                    }
                    finally {
                        this.onEmit();
                    }
                }
            });
    }
    dateChange() {
        if (this.format == 12)
            this.dateControl.valueChanges.subscribe((res) => {
                if (/[0-3][0-9]\/[0-1][0-9]\/[0-9][0-9][0-9][0-9] [0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value) ||
                    /[0-1][0-9]:[0-6][0-9]/.test(this.dateTimeControl.value.substring(11, 16))) {
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), res), { emitEvent: false });
                    try {
                        const input = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
                        this.dateTimeControl.setValue(this.datePipe.transform(input, this.stringFormat));
                    }
                    catch (error) {
                    }
                    finally {
                        this.onEmit();
                    }
                }
            });
        else if (this.format == 24)
            this.dateControl.valueChanges.subscribe((res) => {
                if (/[0-3][0-9]\/[0-1][0-9]\/[0-9][0-9][0-9][0-9] [0-1][0-9]:[0-6][0-9] [A,P]M/.test(this.dateTimeControl.value) ||
                    /[0-1][0-9]:[0-6][0-9]/.test(this.dateTimeControl.value.substring(11, 16))) {
                    this.dateControl.setValue(Object.assign(Object.assign({}, this.hoursControl.value), res), { emitEvent: false });
                    try {
                        const input = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
                        this.dateTimeControl.setValue(this.datePipe.transform(input, this.stringFormat));
                    }
                    catch (error) {
                    }
                    finally {
                        this.onEmit();
                    }
                }
            });
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
        if (this.disabled)
            this.dateTimeControl.disable();
        else
            this.dateTimeControl.enable();
    }
    validate(control) {
        this.controls = control;
        this.cdrf.detectChanges();
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    onEmit(emitValue = null) {
        try {
            const value = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
            emitValue = this.datePipe.transform(value.toString(), 'yyyy-MM-ddTHH:mm');
        }
        catch (e) { }
        this.onChange(emitValue);
        this.onTouch();
    }
    open(d) {
        if (this.dateTimeControl.value == 'dd/mm/yyyy --:-- --' || this.dateTimeControl.value == 'dd/mm/yyyy --:--') {
            this.hoursControl.setValue({
                hour: new Date().getHours(),
                minute: new Date().getMinutes(),
                second: new Date().getSeconds(),
            });
            this.dateControl.setValue(Object.assign({ year: new Date().getFullYear(), month: new Date().getMonth() + 1, day: new Date().getDate() }, this.hoursControl.value));
            const value = new DateTimeModel(Object.assign(this.dateControl.value, this.hoursControl.value));
            this.dateTimeControl.setValue(this.datePipe.transform(value.toString(), this.stringFormat));
            this.onEmit();
        }
    }
    goNext() {
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    goBack() {
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
    limpiarTodo() {
        this.contador = 0;
        this.hoursControl.setValue({
            hour: null,
            minute: null,
        }, { emitEvent: false });
        this.dateControl.setValue({
            year: null,
            month: null,
            day: null,
        }, { emitEvent: false });
        if (this.format == 12)
            this.dateTimeControl.setValue('dd/mm/yyyy --:-- --');
        else if (this.format == 24)
            this.dateTimeControl.setValue('dd/mm/yyyy --:--');
        this.inputDateTime.nativeElement.setSelectionRange(0, 2);
        this.onChange(null);
        this.onTouch();
    }
}
DateTimePickerMaterialComponent.decorators = [
    { type: Component, args: [{
                selector: 'date-time-picker-editable',
                template: "<div class=\"row\">\r\n  <div class=\"col-12\" style=\"overflow: hidden\">\r\n    <label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n    <input\r\n      type=\"text\"\r\n      class=\"form-control form-control-sm position-absolute\"\r\n      container=\"body\"\r\n      id=\"fakeInput\"\r\n      ngbDatepicker\r\n      [formControl]=\"dateControl\"\r\n      [autoClose]=\"'outside'\"\r\n      [footerTemplate]=\"footerTemplate\"\r\n      #d2=\"ngbDatepicker\"\r\n    />\r\n    <div class=\"input-group w-100\">\r\n      <input\r\n        type=\"text\"\r\n        readonly\r\n        id=\"inputDateTime\"\r\n        #inputDateTime\r\n        style=\"flex: 1\"\r\n        [class.is-invalid]=\"\r\n          controls?.errors != null &&\r\n          (controls?.dirty || controls?.touched) &&\r\n          submitted\r\n        \"\r\n        [disabled]=\"disabled || readonly\"\r\n        class=\"form-control form-control-sm\"\r\n        (blur)=\"onBlur()\"\r\n        (focusout)=\"focusOutInput()\"\r\n        (keyup)=\"onKeyUp($event)\"\r\n        (dblclick)=\"preventDefault($event)\"\r\n        (click)=\"preventDefault($event)\"\r\n        (mouseup)=\"onClick($event, inputDateTime)\"\r\n        [formControl]=\"dateTimeControl\"\r\n      />\r\n      <div class=\"input-group-append\">\r\n        <button\r\n          #btnOpen\r\n          (keyup.ArrowLeft)=\"goBack()\"\r\n          [disabled]=\"disabled || readonly\"\r\n          (keyup.ArrowRight)=\"clearable? btnClean.focus() : goNext()\"\r\n          class=\"btn btn-info p-0 rounded-0 use-button\"\r\n          (click)=\"d2.toggle(); open(d2)\"\r\n          type=\"button\"\r\n        >\r\n          <i aria-hidden=\"true\" class=\"fa fa-calendar text-light px-1\"></i>\r\n        </button>\r\n        <button\r\n          #btnClean\r\n          class=\"btn btn-danger p-0 rounded-0 limpiar\"\r\n          [disabled]=\"disabled || readonly\"\r\n          (click)=\"limpiarTodo()\"\r\n          (keyup.ArrowLeft)=\"btnOpen.focus()\"\r\n          (keyup.ArrowRight)=\"goNext()\"\r\n          type=\"button\"\r\n        >\r\n          <!-- <mat-icon class=\"text-white pt-1\" style=\"font-size: 18px;\" [matTooltip]=\"'Limpiar'\" matTooltipClass=\"bg-danger\">close</mat-icon> -->\r\n          <i aria-hidden=\"true\" class=\"fa fa-times px-1 text-light\"></i>\r\n        </button>\r\n      </div>\r\n      <div class=\"position-absolute container-tooltipmessage\">\r\n        <tooltip-message\r\n          [label]=\"label\"\r\n          [controls]=\"controls\"\r\n          [validatorMessage]=\"validatorMessage\"\r\n          [tooltipMessage]=\"tooltipMessage\"\r\n          [submitted]=\"submitted\"\r\n        ></tooltip-message>\r\n      </div>\r\n    </div>\r\n    <error-message\r\n      [label]=\"label\"\r\n      [controls]=\"controls\"\r\n      [validatorMessage]=\"validatorMessage\"\r\n      [tooltipMessage]=\"tooltipMessage\"\r\n      [submitted]=\"submitted\"\r\n    ></error-message>\r\n    <ng-template #footerTemplate>\r\n      <ngb-timepicker\r\n        [formControl]=\"hoursControl\"\r\n        [meridian]=\"format == 12 ? true : false\"\r\n        (focusout)=\"focusOut($event)\"\r\n      ></ngb-timepicker>\r\n    </ng-template>\r\n  </div>\r\n</div>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        multi: true,
                        useExisting: DateTimePickerMaterialComponent,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => DateTimePickerMaterialComponent),
                        multi: true,
                    },
                    I18n,
                    { provide: NgbDatepickerI18n, useClass: CustomDatepickerI18n },
                    { provide: NgbDateParserFormatter, useClass: CustomDatepickerFormat },
                ],
                styles: ["#fakeInput{position:relative;visibility:hidden;padding:0;height:0}#inputDateTime{-webkit-touch-callout:none;-webkit-user-select:none;user-select:none}.form-control:focus,.form-control:active{border-color:#007eff;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #007eff1a!important}ngb-timepicker fieldset{width:230px!important}.container-tooltipmessage{width:16px;height:100%;display:flex;align-items:center;z-index:1000;right:68px;top:1px}.was-validated .form-control:invalid:focus,.form-control.is-invalid:focus{border-color:#dc3545;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.was-validated .form-control:invalid,.form-control.is-invalid{background-image:none;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}\n"]
            },] }
];
DateTimePickerMaterialComponent.ctorParameters = () => [
    { type: DatePipe },
    { type: NgbCalendar },
    { type: DateTimePickerEditableService },
    { type: ChangeDetectorRef }
];
DateTimePickerMaterialComponent.propDecorators = {
    inputDateTime: [{ type: ViewChild, args: ['inputDateTime',] }],
    btnOpen: [{ type: ViewChild, args: ['btnOpen',] }],
    btnClean: [{ type: ViewChild, args: ['btnClean',] }],
    ngbDatepicker: [{ type: ViewChild, args: ['d2',] }],
    label: [{ type: Input }],
    showLabel: [{ type: Input }],
    readonly: [{ type: Input }],
    required: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    submitted: [{ type: Input }],
    format: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    openWhenFocus: [{ type: Input }],
    goNextWhenSelect: [{ type: Input }],
    clearable: [{ type: Input }],
    autoCompleteHours: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    disabled: [{ type: Input }]
};

class DateTimePickerEditable {
}

class DateTimePickerEditableModule {
    static forRoot(dateTimePicker = new DateTimePickerEditable()) {
        return {
            ngModule: DateTimePickerEditableModule,
            providers: [
                {
                    provide: 'DATE_TIME_PICKER_SHOW_LABEL',
                    useValue: dateTimePicker.showLabel,
                },
                {
                    provide: 'DATE_TIME_PICKER_OPEN_WHEN_FOCUS',
                    useValue: dateTimePicker.openWhenFocus,
                },
                {
                    provide: 'DATE_TIME_PICKER_GO_NEXT_WHEN_SELECT',
                    useValue: dateTimePicker.goNextWhenSelect,
                },
                {
                    provide: 'DATE_TIME_PICKER_VALIDATOR_MESSAGE',
                    useValue: dateTimePicker.validatorMessage,
                },
                {
                    provide: 'DATE_TIME_PICKER_TOOLTIP_MESSAGE',
                    useValue: dateTimePicker.tooltipMessage,
                },
                {
                    provide: 'DATE_TIME_PICKER_SUBMITTED',
                    useValue: dateTimePicker.submitted,
                },
                {
                    provide: 'DATE_TIME_PICKER_FORMART',
                    useValue: dateTimePicker.format,
                },
                {
                    provide: 'DATE_TIME_PICKER_CLEARABLE',
                    useValue: dateTimePicker.clearable,
                },
                {
                    provide: 'DATE_TIME_PICKER_AUTOCOMPLETE_HOURS',
                    useValue: dateTimePicker.autoCompleteHours,
                },
                DateTimePickerEditableService,
            ],
        };
    }
}
DateTimePickerEditableModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DateTimePickerMaterialComponent],
                imports: [
                    CommonModule,
                    NgbTimepickerModule,
                    NgbDatepickerModule,
                    ReactiveFormsModule,
                    TooltipMessageModule,
                    MatTooltipModule,
                    ErrorMessageModule,
                ],
                exports: [DateTimePickerMaterialComponent],
            },] }
];

class DateTimePickerService {
    constructor(inputDatetimeFormat = 'dd/MM/yyyy HH:mm', showLabel = true, openWhenFocus = false, goNextWhenSelect = false, validatorMessage = false, tooltipMessage = true, submitted = true) {
        this.inputDatetimeFormat = inputDatetimeFormat;
        this.showLabel = showLabel;
        this.openWhenFocus = openWhenFocus;
        this.goNextWhenSelect = goNextWhenSelect;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.submitted = submitted;
    }
    getInputDatetimeFormat() {
        return this.inputDatetimeFormat;
    }
    getShowLabel() {
        return this.showLabel;
    }
    getOpenWhenFocus() {
        return this.openWhenFocus;
    }
    getGoNextWhenSelect() {
        return this.goNextWhenSelect;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getSubmitted() {
        return this.submitted;
    }
}
DateTimePickerService.ɵprov = i0.ɵɵdefineInjectable({ factory: function DateTimePickerService_Factory() { return new DateTimePickerService(i0.ɵɵinject("DATE_TIME_PICKER_INPUT_DATE_TIME_FORMAT"), i0.ɵɵinject("DATE_TIME_PICKER_SHOW_LABEL"), i0.ɵɵinject("DATE_TIME_PICKER_OPEN_WHEN_FOCUS"), i0.ɵɵinject("DATE_TIME_PICKER_GO_NEXT_WHEN_SELECT"), i0.ɵɵinject("DATE_TIME_PICKER_VALIDATOR_MESSAGE"), i0.ɵɵinject("DATE_TIME_PICKER_TOOLTIP_MESSAGE"), i0.ɵɵinject("DATE_TIME_PICKER_SUBMITTED")); }, token: DateTimePickerService, providedIn: "root" });
DateTimePickerService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
DateTimePickerService.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_INPUT_DATE_TIME_FORMAT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_SHOW_LABEL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_OPEN_WHEN_FOCUS',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_GO_NEXT_WHEN_SELECT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['DATE_TIME_PICKER_SUBMITTED',] }] }
];

class DateTimePickerComponent {
    constructor(calendar, datePipe, dateTimePickerService, _render) {
        this.calendar = calendar;
        this.datePipe = datePipe;
        this.dateTimePickerService = dateTimePickerService;
        this._render = _render;
        /**
      * @description Formato de la fecha:
      * 'dd/MM/yyyy HH:mm' - 'dd/MM/yyyy HH:mm:ss' - 'M/d/yyyy H:mm:ss'
      * @default 'dd/MM/yyyy HH:mm'
      * @type {string}
      */
        this.inputDatetimeFormat = 'dd/MM/yyyy HH:mm'; // 'M/d/yyyy H:mm:ss'
        /**
      * @description Texto superion
      * @default null
      * @type any
      */
        this.label = '';
        /**
      * @description Parametro de la visualización del texto superior
      * @default true
      * @type boolean
      */
        this.showLabel = true;
        this.readonly = false;
        /**
      * @description Parametro de control requerido
      * @default false
      * @type boolean
      */
        this.required = false;
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.submitted = true;
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.openWhenFocus = false;
        this.goNextWhenSelect = false;
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.today = this.calendar.getToday();
        this.date = this.today;
        this.time = {
            hour: new Date().getHours(),
            minute: new Date().getMinutes(),
            second: new Date().getSeconds(),
        };
        this.input = new DateTimeModel(Object.assign(this.date, this.time));
        this.isDisabled = false;
        this._tempValue = null;
        this._initValue = false;
        this.onChange = (_) => { };
        this.onValidationChange = () => { };
        this.onTouch = () => { };
        this.focus = () => {
            this.btnOpen.nativeElement.focus();
            if (!this.readonly && this.openWhenFocus) {
                this.ngbDatepicker.open();
            }
        };
        this.inputDatetimeFormat =
            this.dateTimePickerService.getInputDatetimeFormat();
        this.showLabel = this.dateTimePickerService.getShowLabel();
        this.openWhenFocus = this.dateTimePickerService.getOpenWhenFocus();
        this.goNextWhenSelect = this.dateTimePickerService.getGoNextWhenSelect();
        this.validatorMessage = this.dateTimePickerService.getValidatorMessage();
        this.tooltipMessage = this.dateTimePickerService.getTooltipMessage();
        this.submitted = this.dateTimePickerService.getSubmitted();
    }
    ngOnChanges(changes) {
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    ngOnInit() { }
    // onDateSelect(evt: any) {
    //this.ngbDatepicker.close();
    // if (this.goNextWhenSelect) {
    // 	this.goNext();
    // }
    //console.log(evt);
    // }
    focusOut(event) {
        if (event.target.ariaLabel == 'Minutes') {
            this.ngbDatepicker.close();
            if (this.goNextWhenSelect) {
                this.goNext();
            }
        }
    }
    onModelDateChange(evt) {
        this.input = new DateTimeModel(Object.assign(this.date, this.time));
        const emitValue = this.datePipe.transform(this.input, 'yyyy-MM-ddTHH:mm');
        this.onTouch();
        this.onChange(emitValue);
    }
    limpiar() {
        this.date = null;
        this.time = { minute: 0, hour: 0, second: 0 };
        this.input = null;
        this.onTouch();
        this.onChange(null);
    }
    writeValue(newModel) {
        // this.input = new DateTimeModel(Object.assign(this.date, this.time));
        if (newModel) {
            // this.input = Object.assign(!this.input, DateTimeModel.fromLocalString(newModel));
            if (!this.input) {
                this.input = DateTimeModel.fromLocalString(newModel);
            }
            else {
                this.input = Object.assign(this.input, DateTimeModel.fromLocalString(newModel));
            }
            this.date = this.input;
            this.time = {
                hour: this.input.hour,
                minute: this.input.minute,
                second: this.input.second,
            };
            this._tempValue = this.datePipe.transform(this.input, 'yyyy-MM-ddTHH:mm');
            // this.onTouch();
            if (this.controls) {
                this._render.setProperty(this.controls, 'value', this._tempValue);
            }
        }
        else {
            // Agregue el limpiar para que cargue vacio si se le setea vacio o null
            this.limpiar();
            // this.input = new DateTimeModel();
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    setDisabledState(isDisabled) {
        this.isDisabled = isDisabled;
    }
    validate(control) {
        this.controls = control;
        if (!this._initValue) {
            if (this._tempValue) {
                this._render.setProperty(control, 'value', this._tempValue);
            }
            this._initValue = true;
        }
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    open(d) {
        if (this.input === null) {
            this.date = this.today;
            this.time = {
                hour: new Date().getHours(),
                minute: new Date().getMinutes(),
                second: new Date().getSeconds(),
            };
            this.input = new DateTimeModel(Object.assign(this.date, this.time));
            const emitValue = this.datePipe.transform(this.input, 'yyyy-MM-ddTHH:mm');
            this.onTouch();
            this.onChange(emitValue);
        }
        //abrir el datetime
        d.open();
    }
    goNext() {
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    goBack() {
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
}
DateTimePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'date-time-picker',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n<div\r\n  [class.input-icon]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n  [class.right]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n>\r\n  <!-- tooltip-message es el icono de error -->\r\n\r\n  <tooltip-message\r\n    [label]=\"label\"\r\n    [controls]=\"controls\"\r\n    [validatorMessage]=\"validatorMessage\"\r\n    [tooltipMessage]=\"tooltipMessage\"\r\n    [submitted]=\"submitted\"\r\n  ></tooltip-message>\r\n  <div class=\"input-group mr-2\">\r\n    <input\r\n      name=\"input\"\r\n      type=\"text\"\r\n      class=\"form-control form-control-sm\"\r\n      [disabled]=\"true\"\r\n      [ngModel]=\"input | date: inputDatetimeFormat\"\r\n    />\r\n    <input\r\n      class=\"form-control form-control-sm\"\r\n      container=\"body\"\r\n      [readonly]=\"true\"\r\n      placeholder=\"dd/mm/yyyy\"\r\n      name=\"dp\"\r\n      [(ngModel)]=\"date\"\r\n      (ngModelChange)=\"onModelDateChange($event)\"\r\n      [autoClose]=\"'outside'\"\r\n      ngbDatepicker\r\n      [footerTemplate]=\"footerTemplate\"\r\n      #d=\"ngbDatepicker\"\r\n    />\r\n    <!-- (dateSelect)=\"onDateSelect($event)\" -->\r\n    <div class=\"input-group-append\">\r\n      <button\r\n        #btnOpen\r\n        class=\"btn btn-info p-0 rounded-0\"\r\n        [disabled]=\"isDisabled || readonly\"\r\n        (click)=\"open(d)\"\r\n        (keyup.ArrowLeft)=\"goBack()\"\r\n        (keyup.ArrowRight)=\"btnClean.focus()\"\r\n        type=\"button\"\r\n      >\r\n        <!-- <mat-icon class=\"text-white pt-1\" style=\"font-size: 18px;\" [matTooltip]=\"'Calendario'\" matTooltipClass=\"bg-info\">calendar_today</mat-icon> -->\r\n        <i aria-hidden=\"true\" class=\"fa fa-calendar text-light px-1\"></i>\r\n      </button>\r\n      <button\r\n        #btnClean\r\n        class=\"btn btn-danger p-0 rounded-0 limpiar\"\r\n        [disabled]=\"isDisabled || readonly\"\r\n        (click)=\"limpiar()\"\r\n        (keyup.ArrowLeft)=\"btnOpen.focus()\"\r\n        (keyup.ArrowRight)=\"goNext()\"\r\n        type=\"button\"\r\n      >\r\n        <!-- <mat-icon class=\"text-white pt-1\" style=\"font-size: 18px;\" [matTooltip]=\"'Limpiar'\" matTooltipClass=\"bg-danger\">close</mat-icon> -->\r\n        <i aria-hidden=\"true\" class=\"fa fa-times px-1 text-light\"></i>\r\n      </button>\r\n    </div>\r\n  </div>\r\n</div>\r\n\r\n<ng-template #footerTemplate>\r\n  <hr class=\"my-0\" />\r\n  <ngb-timepicker\r\n    #tp\r\n    [(ngModel)]=\"time\"\r\n    name=\"timepicker\"\r\n    (ngModelChange)=\"onModelDateChange($event)\"\r\n    (focusout)=\"focusOut($event)\"\r\n  >\r\n  </ngb-timepicker>\r\n</ng-template>\r\n<!-- error-message es el mansaje que aparece abajo del componente -->\r\n<error-message\r\n  [label]=\"label\"\r\n  [controls]=\"controls\"\r\n  [validatorMessage]=\"validatorMessage\"\r\n  [tooltipMessage]=\"tooltipMessage\"\r\n  [submitted]=\"submitted\"\r\n></error-message>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => DateTimePickerComponent),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => DateTimePickerComponent),
                        multi: true,
                    },
                    I18n,
                    { provide: NgbDatepickerI18n, useClass: CustomDatepickerI18n },
                    { provide: NgbDateParserFormatter, useClass: CustomDatepickerFormat },
                ],
                styles: [".sumax-label{color:#646c9a!important}button[disabled]{pointer-events:none}.input-group i{color:#212529}.input-group input:nth-child(1){position:absolute;width:100%}.input-group input:nth-child(2){position:relative;visibility:hidden}.input-group .input-group-append{background-color:#fff;z-index:1;border-left:1px solid #e2e5ec}.form-control[readonly]{background-color:#f7f8fa;opacity:1}.input-icon{position:relative}.input-icon.right>tooltip-message{left:auto;right:8px;float:right}.input-icon>tooltip-message{color:#ccc;position:absolute;margin-top:.3rem;margin-right:4.5em;z-index:3;width:16px;font-size:16px;text-align:center;left:0}.input-icon.right>.form-control{padding-right:33px;padding-left:12px}.was-validated .form-control:invalid:focus,.form-control.is-invalid:focus{border-color:#dc3545;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.was-validated .form-control:invalid,.form-control.is-invalid{background-image:none;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.form-control:focus,.form-control:active{border-color:#007eff;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #007eff1a!important}\n"]
            },] }
];
DateTimePickerComponent.ctorParameters = () => [
    { type: NgbCalendar },
    { type: DatePipe },
    { type: DateTimePickerService },
    { type: Renderer2 }
];
DateTimePickerComponent.propDecorators = {
    inputDatetimeFormat: [{ type: Input }],
    label: [{ type: Input }],
    showLabel: [{ type: Input }],
    readonly: [{ type: Input }],
    required: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    submitted: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    openWhenFocus: [{ type: Input }],
    goNextWhenSelect: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    ngbDatepicker: [{ type: ViewChild, args: ['d',] }],
    timePicker: [{ type: ViewChild, args: ['tp',] }],
    btnOpen: [{ type: ViewChild, args: ['btnOpen',] }],
    btnClean: [{ type: ViewChild, args: ['btnClean',] }]
};

class DateTimePicker {
}

class DateTimePickerModule {
    static forRoot(dateTimePicker = new DateTimePicker()) {
        return {
            ngModule: DateTimePickerModule,
            providers: [
                { provide: 'DATE_TIME_PICKER_INPUT_DATE_TIME_FORMAT', useValue: dateTimePicker.inputDatetimeFormat },
                { provide: 'DATE_TIME_PICKER_SHOW_LABEL', useValue: dateTimePicker.showLabel },
                { provide: 'DATE_TIME_PICKER_OPEN_WHEN_FOCUS', useValue: dateTimePicker.openWhenFocus },
                { provide: 'DATE_TIME_PICKER_GO_NEXT_WHEN_SELECT', useValue: dateTimePicker.goNextWhenSelect },
                { provide: 'DATE_TIME_PICKER_VALIDATOR_MESSAGE', useValue: dateTimePicker.validatorMessage },
                { provide: 'DATE_TIME_PICKER_TOOLTIP_MESSAGE', useValue: dateTimePicker.tooltipMessage },
                { provide: 'DATE_TIME_PICKER_SUBMITTED', useValue: dateTimePicker.submitted },
                DateTimePickerService
            ]
        };
    }
}
DateTimePickerModule.decorators = [
    { type: NgModule, args: [{
                declarations: [DateTimePickerComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    NgbDatepickerModule,
                    MatIconModule,
                    MatTooltipModule,
                    NgbTimepickerModule
                ],
                exports: [DateTimePickerComponent],
                providers: [
                    DatePipe
                ]
            },] }
];

class InputNumberService {
    constructor(decimals = -1, formatCero = false, btnEnable = false, bold = false, validatorMessage = false, tooltipMessage = true, submitted = true, validatorAlert = false) {
        this.decimals = decimals;
        this.formatCero = formatCero;
        this.btnEnable = btnEnable;
        this.bold = bold;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.submitted = submitted;
        this.validatorAlert = validatorAlert;
    }
    getDecimals() {
        return this.decimals;
    }
    getFormatCero() {
        return this.formatCero;
    }
    getBtnEnable() {
        return this.btnEnable;
    }
    getBold() {
        return this.bold;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getSubmitted() {
        return this.submitted;
    }
    getValidatorAlert() {
        return this.validatorAlert;
    }
}
InputNumberService.ɵprov = i0.ɵɵdefineInjectable({ factory: function InputNumberService_Factory() { return new InputNumberService(i0.ɵɵinject("INPUT_NUMBER_DECIMALS"), i0.ɵɵinject("INPUT_NUMBER_FORMAT_CERO"), i0.ɵɵinject("INPUT_NUMBER_BTN_ENABLE"), i0.ɵɵinject("INPUT_NUMBER_BOLD"), i0.ɵɵinject("INPUT_NUMBER_VALIDATOR_MESSAGE"), i0.ɵɵinject("INPUT_NUMBER_TOOLTIP_MESSAGE"), i0.ɵɵinject("INPUT_NUMBER_SUBMITTED"), i0.ɵɵinject("INPUT_NUMBER_VALIDATOR_ALERT")); }, token: InputNumberService, providedIn: "root" });
InputNumberService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
InputNumberService.ctorParameters = () => [
    { type: Number, decorators: [{ type: Inject, args: ['INPUT_NUMBER_DECIMALS',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_FORMAT_CERO',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_BTN_ENABLE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_BOLD',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_SUBMITTED',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_NUMBER_VALIDATOR_ALERT',] }] }
];

class InputNumberComponent {
    constructor(messageUtilService, inputNumberService, _render) {
        this.messageUtilService = messageUtilService;
        this.inputNumberService = inputNumberService;
        this._render = _render;
        this.showLabel = true;
        this.label = null;
        this.btnEnable = false;
        this.autocomplete = 'cc-csc';
        this.bold = false;
        this.decimals = -1;
        this.formatCero = false;
        this.maxLength = null;
        this.required = false;
        this.disabled = false;
        this.readonly = false;
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.submitted = true;
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.validatorAlert = false;
        this.setNgClass = '';
        this.placeholder = '';
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.change = new EventEmitter();
        this.onchange = new EventEmitter();
        this.blur = new EventEmitter();
        this.onfocus = new EventEmitter();
        this.onfocusout = new EventEmitter();
        this.sharedComponentsUtil = new SharedComponentsUtil();
        this.format = 'separator';
        this._initValue = false;
        this.onChange = (_) => { };
        this.onValidationChange = () => { };
        this.onTouch = () => { };
        this.focus = () => {
            this.inputText.nativeElement.focus();
            this.inputText.nativeElement.select();
        };
        this.decimals = this.inputNumberService.getDecimals();
        this.formatCero = this.inputNumberService.getFormatCero();
        this.btnEnable = this.inputNumberService.getBtnEnable();
        this.bold = this.inputNumberService.getBold();
        this.validatorMessage = this.inputNumberService.getValidatorMessage();
        this.tooltipMessage = this.inputNumberService.getTooltipMessage();
        this.submitted = this.inputNumberService.getSubmitted();
        this.validatorAlert = this.inputNumberService.getValidatorAlert();
    }
    ngOnChanges(changes) {
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    ngOnInit() {
        if (this.decimals != -1) {
            this.format = 'separator' + '.' + this.decimals.toString();
        }
        else {
            this.format = 'separator';
        }
    }
    ngAfterViewInit() { }
    onBlur(value) {
        this.onTouch();
        if ((value == '' || value == null) && this.formatCero) {
            value = 0;
        }
        const newValue = this.formatNumber(value);
        if (this.value !== newValue) {
            this.value = newValue;
            this.onChange(this.emitValue(newValue));
        }
        // if (newValue) {
        this.onValidationChange();
        this.blur.emit(this.emitValue(newValue));
        // }
    }
    onFocus(evt) {
        this.inputText.nativeElement.select();
        this.onfocus.emit(evt);
    }
    onInput(evt) {
        this.onTouch();
        this.onChange(this.emitValue(evt));
        this.onValidationChange();
        this.change.emit(this.emitValue(evt));
        this.onchange.emit(this.emitValue(evt));
    }
    writeValue(value) {
        if (value != null) {
            this.value = this.formatNumber(value);
            if (this.value === 'NaN') {
                if (this.controls) {
                    this._render.setProperty(this.controls, 'value', null);
                }
                throw new Error('Not a number');
            }
            if (this.controls) {
                this._render.setProperty(this.controls, 'value', Number(this.value));
            }
        }
        else {
            this.value = null;
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    validate(control) {
        this.controls = control;
        if (!this._initValue) {
            if (this.value === 'NaN') {
                this._render.setProperty(this.controls, 'value', null);
                throw new Error('Not a number');
            }
            if (this.value !== null) {
                this._render.setProperty(this.controls, 'value', Number(this.value));
            }
            this._initValue = true;
        }
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    formatNumber(value) {
        if (value != null) {
            value = value.toString();
        }
        if (this.decimals != null && value != null && value != '') {
            if (this.decimals > 0) {
                return Number(value.replaceAll(',', '')).toFixed(this.decimals);
            }
            else {
                return Number(value.replaceAll(',', '')).toFixed();
            }
        }
        else {
            if (value != null && value != '') {
                return Number(value.replaceAll(',', ''));
            }
            else {
                return null;
            }
        }
    }
    emitValue(value) {
        if (value != null && value != '') {
            if (this.decimals != null) {
                if (this.decimals > 0) {
                    return Number(Number(value.replaceAll(',', '')).toFixed(this.decimals));
                }
                else {
                    return Number(Number(value.replaceAll(',', '')).toFixed());
                }
            }
            else {
                return Number(value.replaceAll(',', ''));
            }
        }
        else {
            return null;
        }
    }
    enterKeyUp() {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    arrowUpKeyUp() {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
    onFocusOut(evt) {
        this.onfocusout.emit(evt);
        if (this.btnEnable) {
            this.disabled = true;
        }
    }
    clickEnable() {
        this.disabled = false;
        this.readonly = false;
        setTimeout(() => {
            this.focus();
        }, 150);
    }
}
InputNumberComponent.decorators = [
    { type: Component, args: [{
                selector: 'input-number',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n<div [class.input-icon]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n\t[class.right]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\">\r\n\t<tooltip-message [label]=\"label\" [controls]=\"controls\" [validatorMessage]=\"validatorMessage\"\r\n\t\t[tooltipMessage]=\"tooltipMessage\" [submitted]=\"submitted\"></tooltip-message>\r\n\t<div class=\"d-flex\">\r\n\t\t<div class=\"w-100\">\r\n\t\t\t<input #inputText type=\"text\" class=\"form-control form-control-sm text-right\"\r\n\t\t\t\t[class.is-invalid]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n\t\t\t\t[(ngModel)]=\"value\" [disabled]=\"disabled\" [readonly]=\"readonly\" [mask]=\"format\" thousandSeparator=\",\" [allowNegativeNumbers]=\"true\"\r\n\t\t\t\t(blur)=\"onBlur($any($event.target).value)\" (input)=\"onInput($any($event.target).value)\"\r\n\t\t\t\t(focusout)=\"onFocusOut($any($event.target).value)\" [autocomplete]=\"autocomplete\" [placeholder]=\"placeholder\"\r\n\t\t\t\t(focus)=\"onFocus($any($event.target).value)\" [attr.maxLength]=\"maxLength\" (keyup.enter)=\" enterKeyUp()\"\r\n\t\t\t\t(keyup.ArrowUp)=\" arrowUpKeyUp()\" [ngClass]=\"setNgClass\" [class.bold]=\"bold\">\r\n\t\t</div>\r\n\t\t<div class=\"bd-highlight\" *ngIf=\"btnEnable\">\r\n\t\t\t<button type=\"button\" class=\"btn btn-info p-0 rounded-0 h-100\" (click)=\"clickEnable()\">\r\n\t\t\t\t<i class=\"fa fa-check text-white px-1\" [matTooltip]=\"'Habilitar'\"\r\n\t\t\t\t\tmatTooltipClass=\"bg-info\"></i></button>\r\n\t\t</div>\r\n\t\t<ng-content select=\"[more-buttons]\"></ng-content>\r\n\t</div>\r\n</div>\r\n<error-message [label]=\"label\" [controls]=\"controls\" [validatorMessage]=\"validatorMessage\"\r\n\t[tooltipMessage]=\"tooltipMessage\" [submitted]=\"submitted\"></error-message>",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => InputNumberComponent),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => InputNumberComponent),
                        multi: true,
                    },
                ],
                styles: [".sumax-label{color:#646c9a!important}.input-icon{position:relative}.input-icon.right>tooltip-message{left:auto;right:8px;float:right}.input-icon>tooltip-message{color:#ccc;position:absolute;margin-top:.3rem;margin-right:1em;z-index:3;width:16px;font-size:16px;text-align:center;left:0}.input-icon.right>.form-control{padding-right:33px;padding-left:12px}.bold{color:#000;font-weight:bold}.was-validated .form-control:invalid:focus,.form-control.is-invalid:focus{border-color:#dc3545;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.was-validated .form-control:invalid,.form-control.is-invalid{background-image:none;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.form-control:focus,.form-control:active{border-color:#007eff;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #007eff1a!important}\n"]
            },] }
];
InputNumberComponent.ctorParameters = () => [
    { type: MessageUtilService },
    { type: InputNumberService },
    { type: Renderer2 }
];
InputNumberComponent.propDecorators = {
    showLabel: [{ type: Input }],
    label: [{ type: Input }],
    btnEnable: [{ type: Input }],
    autocomplete: [{ type: Input }],
    bold: [{ type: Input }],
    decimals: [{ type: Input }],
    formatCero: [{ type: Input }],
    maxLength: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    required: [{ type: Input }],
    disabled: [{ type: Input }],
    readonly: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    submitted: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    validatorAlert: [{ type: Input }],
    setNgClass: [{ type: Input }],
    placeholder: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    change: [{ type: Output }],
    onchange: [{ type: Output }],
    blur: [{ type: Output }],
    onfocus: [{ type: Output }],
    onfocusout: [{ type: Output }],
    inputText: [{ type: ViewChild, args: ['inputText',] }]
};

class InputNumber {
}

const maskConfig$1 = {
    validation: false,
};
class InputNumberModule {
    static forRoot(inputNumber = new InputNumber()) {
        return {
            ngModule: InputNumberModule,
            providers: [
                { provide: 'INPUT_NUMBER_DECIMALS', useValue: inputNumber.decimals },
                { provide: 'INPUT_NUMBER_FORMAT_CERO', useValue: inputNumber.formatCero },
                { provide: 'INPUT_NUMBER_BTN_ENABLE', useValue: inputNumber.btnEnable },
                { provide: 'INPUT_NUMBER_BOLD', useValue: inputNumber.bold },
                { provide: 'INPUT_NUMBER_VALIDATOR_MESSAGE', useValue: inputNumber.validatorMessage },
                { provide: 'INPUT_NUMBER_TOOLTIP_MESSAGE', useValue: inputNumber.tooltipMessage },
                { provide: 'INPUT_NUMBER_SUBMITTED', useValue: inputNumber.submitted },
                { provide: 'INPUT_NUMBER_VALIDATOR_ALERT', useValue: inputNumber.validatorAlert },
                InputNumberService
            ]
        };
    }
}
InputNumberModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputNumberComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    MatTooltipModule,
                    NgxMaskModule.forRoot(maskConfig$1)
                ],
                exports: [InputNumberComponent]
            },] }
];

class InputTextService {
    constructor(format = 'M', showLabel = true, btnEnable = false, bold = false, textRight = false, validatorMessage = false, tooltipMessage = true, submitted = true, validatorAlert = false) {
        this.format = format;
        this.showLabel = showLabel;
        this.btnEnable = btnEnable;
        this.bold = bold;
        this.textRight = textRight;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.submitted = submitted;
        this.validatorAlert = validatorAlert;
    }
    getFormat() {
        return this.format;
    }
    getShowLabel() {
        return this.showLabel;
    }
    getBtnEnable() {
        return this.btnEnable;
    }
    getBold() {
        return this.bold;
    }
    getTextRight() {
        return this.textRight;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getSubmitted() {
        return this.submitted;
    }
    getValidatorAlert() {
        return this.validatorAlert;
    }
}
InputTextService.ɵprov = i0.ɵɵdefineInjectable({ factory: function InputTextService_Factory() { return new InputTextService(i0.ɵɵinject("INPUT_TEXT_FORMAT"), i0.ɵɵinject("INPUT_TEXT_SHOW_LABEL"), i0.ɵɵinject("INPUT_TEXT_BTN_ENABLE"), i0.ɵɵinject("INPUT_TEXT_BOLD"), i0.ɵɵinject("INPUT_TEXT_TEXT_RIGHT"), i0.ɵɵinject("INPUT_TEXT_VALIDATOR_MESSAGE"), i0.ɵɵinject("INPUT_TEXT_TOOLTIP_MESSAGE"), i0.ɵɵinject("INPUT_TEXT_SUBMITTED"), i0.ɵɵinject("INPUT_TEXT_VALIDATOR_ALERT")); }, token: InputTextService, providedIn: "root" });
InputTextService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
InputTextService.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: ['INPUT_TEXT_FORMAT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_SHOW_LABEL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_BTN_ENABLE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_BOLD',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_TEXT_RIGHT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_SUBMITTED',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['INPUT_TEXT_VALIDATOR_ALERT',] }] }
];

class InputTextComponent {
    constructor(messageUtilService, inputTextService, _render) {
        this.messageUtilService = messageUtilService;
        this.inputTextService = inputTextService;
        this._render = _render;
        this.format = 'M';
        this.type = 'text';
        this.showLabel = true;
        this.label = '';
        this.btnEnable = false;
        this.autocomplete = 'cc-csc';
        this.bold = false;
        this.inputMask = null;
        this.showMaskTyped = false;
        this.required = false;
        this.textRight = false;
        this.disabled = false;
        this.readonly = false;
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.maxLength = null;
        this.submitted = true;
        this.validatorAlert = false;
        this.setNgClass = '';
        this.patterns = '';
        this.placeholder = '';
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.change = new EventEmitter();
        this.blur = new EventEmitter();
        this.onfocus = new EventEmitter();
        this.onchange = new EventEmitter();
        this.onfocusout = new EventEmitter();
        this.sharedComponentsUtil = new SharedComponentsUtil();
        this._initValue = false;
        this.showPassword = false;
        this.onChange = (_) => { };
        this.onValidationChange = () => { };
        this.onTouch = () => { };
        this.focus = () => {
            var _a, _b;
            // this.inputText.nativeElement.focus();
            // this.inputText.nativeElement.select();
            (_a = this.nativeElement) === null || _a === void 0 ? void 0 : _a.focus();
            (_b = this.nativeElement) === null || _b === void 0 ? void 0 : _b.select();
        };
        this.format = this.inputTextService.getFormat();
        this.showLabel = this.inputTextService.getShowLabel();
        this.btnEnable = this.inputTextService.getBtnEnable();
        this.bold = this.inputTextService.getBold();
        this.textRight = this.inputTextService.getTextRight();
        this.validatorMessage = this.inputTextService.getValidatorMessage();
        this.tooltipMessage = this.inputTextService.getTooltipMessage();
        this.submitted = this.inputTextService.getSubmitted();
        this.validatorAlert = this.inputTextService.getValidatorAlert();
    }
    ngOnChanges(changes) {
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() { }
    get nativeElement() {
        return this._inputText.nativeElement;
    }
    onBlur(value) {
        // this.value = this.formatInput(value);
        this.onTouch();
        // this.onValidationChange();
        // this.onChange(this.value);
        this.blur.emit(this.formatInput(value));
    }
    onFocus(value) {
        var _a;
        if (value.trim() !== '') {
            (_a = this.nativeElement) === null || _a === void 0 ? void 0 : _a.select();
            this.onfocus.emit(value.trim());
        }
    }
    onInput(value) {
        const newValue = this.formatInput(value);
        this.onTouch();
        this.onChange(newValue);
        this.onValidationChange();
        this.onchange.emit(newValue);
        this.change.emit(newValue);
    }
    writeValue(value) {
        if (value) {
            this.value = this.formatInput(value);
            // this.onChange(value);
            if (this.controls) {
                this._render.setProperty(this.controls, 'value', this.value);
            }
        }
        else {
            this.value = null;
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    validate(control) {
        this.controls = control;
        if (!this._initValue) {
            if (this.value) {
                this._render.setProperty(this.controls, 'value', this.value);
            }
            this._initValue = true;
        }
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    formatInput(value) {
        if (value !== null && value.toString().trim() !== '') {
            const newValue = value.toString().trim();
            if (this.format === 'M')
                return newValue.toUpperCase();
            if (this.format === 'm')
                return newValue.toLowerCase();
        }
        return value;
    }
    enterKeyUp() {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    arrowUpKeyUp() {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
    onFocusOut(evt) {
        this.onfocusout.emit(evt);
        if (this.btnEnable) {
            this.disabled = true;
        }
    }
    clickEnable() {
        this.disabled = false;
        this.readonly = false;
        setTimeout(() => {
            this.focus();
        }, 150);
    }
    clickShowPassword() {
        this.showPassword = !this.showPassword;
    }
}
InputTextComponent.decorators = [
    { type: Component, args: [{
                selector: 'input-text',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n<div\r\n  [class.input-icon]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n  [class.right]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n>\r\n  <div class=\"d-flex\">\r\n    <div class=\"w-100 position-relative\">\r\n      <tooltip-message\r\n        [label]=\"label\"\r\n        [controls]=\"controls\"\r\n        [validatorMessage]=\"validatorMessage\"\r\n        [submitted]=\"submitted\"\r\n        [tooltipMessage]=\"tooltipMessage\"\r\n      ></tooltip-message>\r\n\r\n      <input\r\n        *ngIf=\"inputMask != null\"\r\n        #inputText\r\n        type=\"text\"\r\n        class=\"form-control form-control-sm\"\r\n        [class.text-uppercase]=\"format === 'M'\"\r\n        [class.text-lowercase]=\"format === 'm'\"\r\n        [class.text-right]=\"textRight\"\r\n        [autocomplete]=\"autocomplete\"\r\n        [placeholder]=\"placeholder\"\r\n        [class.is-invalid]=\"\r\n          controls?.errors != null &&\r\n          (controls?.dirty || controls?.touched) &&\r\n          submitted\r\n        \"\r\n        [disabled]=\"disabled\"\r\n        [readonly]=\"readonly\"\r\n        [mask]=\"inputMask\"\r\n        [showMaskTyped]=\"showMaskTyped\"\r\n        [patterns]=\"patterns\"\r\n        (blur)=\"onBlur($any($event.target).value)\"\r\n        (input)=\"onInput($any($event.target).value)\"\r\n        (focusout)=\"onFocusOut($any($event.target).value)\"\r\n        (focus)=\"onFocus($any($event.target).value)\"\r\n        (keyup.enter)=\"enterKeyUp()\"\r\n        (keyup.ArrowUp)=\"arrowUpKeyUp()\"\r\n        [ngClass]=\"setNgClass\"\r\n        [(ngModel)]=\"value\"\r\n        [class.bold]=\"bold\"\r\n      />\r\n      <input\r\n        *ngIf=\"inputMask == null\"\r\n        #inputText\r\n        [type]=\"\r\n          type === 'password' ? (showPassword ? 'text' : 'password') : type\r\n        \"\r\n        class=\"form-control form-control-sm\"\r\n        [class.text-uppercase]=\"format === 'M'\"\r\n        [class.text-lowercase]=\"format === 'm'\"\r\n        [class.text-right]=\"textRight\"\r\n        [autocomplete]=\"autocomplete\"\r\n        [placeholder]=\"placeholder\"\r\n        [class.is-invalid]=\"\r\n          controls?.errors != null &&\r\n          (controls?.dirty || controls?.touched) &&\r\n          submitted\r\n        \"\r\n        [disabled]=\"disabled\"\r\n        [readonly]=\"readonly\"\r\n        [attr.maxLength]=\"maxLength\"\r\n        (blur)=\"onBlur($any($event.target).value)\"\r\n        (input)=\"onInput($any($event.target).value)\"\r\n        (focusout)=\"onFocusOut($any($event.target).value)\"\r\n        (focus)=\"onFocus($any($event.target).value)\"\r\n        (keyup.enter)=\"enterKeyUp()\"\r\n        (keyup.ArrowUp)=\"arrowUpKeyUp()\"\r\n        [ngClass]=\"setNgClass\"\r\n        [(ngModel)]=\"value\"\r\n        [class.bold]=\"bold\"\r\n      />\r\n    </div>\r\n    <div class=\"bd-highlight\" *ngIf=\"type === 'password'\">\r\n      <button\r\n        type=\"button\"\r\n        class=\"btn btn-info p-0 rounded-0 h-100\"\r\n        (click)=\"clickShowPassword()\"\r\n      >\r\n        <i\r\n          [class.fa-eye]=\"showPassword\"\r\n          [class.fa-eye-slash]=\"!showPassword\"\r\n          class=\"far px-1\"\r\n          [matTooltip]=\"!showPassword ? 'Mostrar' : 'Ocultar'\"\r\n          matTooltipClass=\"bg-info\"\r\n        ></i>\r\n      </button>\r\n    </div>\r\n    <div class=\"bd-highlight\" *ngIf=\"btnEnable\">\r\n      <button\r\n        type=\"button\"\r\n        class=\"btn btn-info p-0 rounded-0 h-100\"\r\n        (click)=\"clickEnable()\"\r\n      >\r\n        <i\r\n          class=\"fa fa-check text-white px-1\"\r\n          [matTooltip]=\"'Habilitar'\"\r\n          matTooltipClass=\"bg-info\"\r\n        ></i>\r\n      </button>\r\n    </div>\r\n    <ng-content select=\"[more-buttons]\"></ng-content>\r\n  </div>\r\n</div>\r\n<error-message\r\n  [label]=\"label\"\r\n  [controls]=\"controls\"\r\n  [validatorMessage]=\"validatorMessage\"\r\n  [submitted]=\"submitted\"\r\n  [tooltipMessage]=\"tooltipMessage\"\r\n></error-message>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => InputTextComponent),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => InputTextComponent),
                        multi: true,
                    },
                ],
                styles: [".sumax-label{color:#646c9a!important}.btn-password{position:absolute;right:.3em;top:50%;transform:translateY(-50%);font-size:.8em;border:0;outline:0;border-radius:50%}.input-icon tooltip-message{color:#ccc;position:absolute;z-index:3;font-size:16px;text-align:center;right:.3em;top:50%;transform:translateY(-50%)}.input-icon.right>.form-control{padding-right:33px;padding-left:12px}.bold{color:#000;font-weight:bold}.was-validated .form-control:invalid:focus,.form-control.is-invalid:focus{border-color:#dc3545;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.was-validated .form-control:invalid,.form-control.is-invalid{background-image:none;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.form-control:focus,.form-control:active{border-color:#007eff;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #007eff1a!important}\n"]
            },] }
];
InputTextComponent.ctorParameters = () => [
    { type: MessageUtilService },
    { type: InputTextService },
    { type: Renderer2 }
];
InputTextComponent.propDecorators = {
    format: [{ type: Input }],
    type: [{ type: Input }],
    showLabel: [{ type: Input }],
    label: [{ type: Input }],
    btnEnable: [{ type: Input }],
    autocomplete: [{ type: Input }],
    bold: [{ type: Input }],
    inputMask: [{ type: Input }],
    showMaskTyped: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    required: [{ type: Input }],
    textRight: [{ type: Input }],
    disabled: [{ type: Input }],
    readonly: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    maxLength: [{ type: Input }],
    submitted: [{ type: Input }],
    validatorAlert: [{ type: Input }],
    setNgClass: [{ type: Input }],
    patterns: [{ type: Input }],
    placeholder: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    change: [{ type: Output }],
    blur: [{ type: Output }],
    onfocus: [{ type: Output }],
    onchange: [{ type: Output }],
    onfocusout: [{ type: Output }],
    _inputText: [{ type: ViewChild, args: ['inputText',] }]
};

class InputText {
}

const maskConfig = {
    validation: false,
};
class InputTextModule {
    static forRoot(inputText = new InputText()) {
        return {
            ngModule: InputTextModule,
            providers: [
                { provide: 'INPUT_TEXT_FORMAT', useValue: inputText.format },
                { provide: 'INPUT_TEXT_SHOW_LABEL', useValue: inputText.showLabel },
                { provide: 'INPUT_TEXT_BTN_ENABLE', useValue: inputText.btnEnable },
                { provide: 'INPUT_TEXT_BOLD', useValue: inputText.bold },
                { provide: 'INPUT_TEXT_TEXT_RIGHT', useValue: inputText.textRight },
                { provide: 'INPUT_TEXT_VALIDATOR_MESSAGE', useValue: inputText.validatorMessage },
                { provide: 'INPUT_TEXT_TOOLTIP_MESSAGE', useValue: inputText.tooltipMessage },
                { provide: 'INPUT_TEXT_SUBMITTED', useValue: inputText.submitted },
                { provide: 'INPUT_TEXT_VALIDATOR_ALERT', useValue: inputText.validatorAlert },
                InputTextService
            ]
        };
    }
}
InputTextModule.decorators = [
    { type: NgModule, args: [{
                declarations: [InputTextComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    MatIconModule,
                    MatTooltipModule,
                    NgxMaskModule.forRoot(maskConfig)
                ],
                exports: [InputTextComponent]
            },] }
];

class NgSelectMultipleService {
    constructor(showlimit = 2, Header = true, Footer = true, markFirst = false, openWhenFocus = false, validatorMessage = false, tooltipMessage = true, validatorAlert = false, submitted = true, appendTo = "body", loadingText = "Cargando...", virtualScroll = true) {
        this.showlimit = showlimit;
        this.Header = Header;
        this.Footer = Footer;
        this.markFirst = markFirst;
        this.openWhenFocus = openWhenFocus;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.validatorAlert = validatorAlert;
        this.submitted = submitted;
        this.appendTo = appendTo;
        this.loadingText = loadingText;
        this.virtualScroll = virtualScroll;
    }
    getShowlimit() {
        return this.showlimit;
    }
    getHeader() {
        return this.Header;
    }
    getFooter() {
        return this.Footer;
    }
    getMarkFirst() {
        return this.markFirst;
    }
    getOpenWhenFocus() {
        return this.openWhenFocus;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getValidatorAlert() {
        return this.validatorAlert;
    }
    getSubmitted() {
        return this.submitted;
    }
    getAppendTo() {
        return this.appendTo;
    }
    getLoadingText() {
        return this.loadingText;
    }
    getVirtualScroll() {
        return this.virtualScroll;
    }
}
NgSelectMultipleService.ɵprov = i0.ɵɵdefineInjectable({ factory: function NgSelectMultipleService_Factory() { return new NgSelectMultipleService(i0.ɵɵinject("NG_SELECT_MULTIPLE_SHOWLIMIT"), i0.ɵɵinject("NG_SELECT_MULTIPLE_HEADER"), i0.ɵɵinject("NG_SELECT_MULTIPLE_FOOTER"), i0.ɵɵinject("NG_SELECT_MULTIPLE_MARK_FIRST"), i0.ɵɵinject("NG_SELECT_MULTIPLE_OPEN_WHEN_FOCUS"), i0.ɵɵinject("NG_SELECT_MULTIPLE_VALIDATOR_MESSAGE"), i0.ɵɵinject("NG_SELECT_MULTIPLE_TOOLTIP_MESSAGE"), i0.ɵɵinject("NG_SELECT_MULTIPLE_VALIDATOR_ALERT"), i0.ɵɵinject("NG_SELECT_MULTIPLE_SUBMITTED"), i0.ɵɵinject("NG_SELECT_MULTIPLE_APPEND_TO"), i0.ɵɵinject("NG_SELECT_MULTIPLE_LOADING_TEXT"), i0.ɵɵinject("NG_SELECT_MULTIPLE_VIRTUAL_SCROLL")); }, token: NgSelectMultipleService, providedIn: "root" });
NgSelectMultipleService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NgSelectMultipleService.ctorParameters = () => [
    { type: Number, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_SHOWLIMIT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_HEADER',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_FOOTER',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_MARK_FIRST',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_OPEN_WHEN_FOCUS',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_VALIDATOR_ALERT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_SUBMITTED',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_APPEND_TO',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_LOADING_TEXT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_MULTIPLE_VIRTUAL_SCROLL',] }] }
];

var NgSelectMultipleComponent_1;
let NgSelectMultipleComponent = NgSelectMultipleComponent_1 = class NgSelectMultipleComponent {
    constructor(cdrf, messageUtilService, ngSelectMultipleService) {
        this.cdrf = cdrf;
        this.messageUtilService = messageUtilService;
        this.ngSelectMultipleService = ngSelectMultipleService;
        this.onChange = (_) => { };
        this.onTouched = () => { };
        this.onValidationChange = () => { };
        this.showlimit = 2;
        this.showLabel = true;
        this.label = null;
        this.autocomplete = "cc-csc";
        this.Header = true;
        this.Footer = true;
        this.required = false;
        this.disabled = false;
        this.readonly = false;
        this.openWhenFocus = false;
        this.markFirst = false;
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.validatorAlert = false;
        this.submitted = true;
        this.refresh = false;
        this.isForFilter = true;
        this.appendTo = "body";
        this.Language = {
            Selected: 'Seleccionados',
            SelectAll: 'TODOS',
            UnselectAll: 'NINGUNO',
            All: 'TODOS'
        };
        this.virtualScroll = true;
        this.loading = true;
        this.loadingText = "Cargando...";
        //EVENTS
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.change = new EventEmitter();
        this.blur = new EventEmitter();
        this.onfocus = new EventEmitter();
        this.onrefresh = new EventEmitter();
        this.sharedComponentsUtil = new SharedComponentsUtil();
        this.checkedAll = false;
        this.checkedIndeterminate = false;
        this.focus = () => {
            this.ngSelectMultiple.focus();
            if (this.openWhenFocus) {
                this.ngSelectMultiple.open();
            }
        };
        this.close = () => {
            this.ngSelectMultiple.close();
        };
        this.showlimit = this.ngSelectMultipleService.getShowlimit();
        this.Header = this.ngSelectMultipleService.getHeader();
        this.Footer = this.ngSelectMultipleService.getFooter();
        this.validatorMessage = this.ngSelectMultipleService.getValidatorMessage();
        this.tooltipMessage = this.ngSelectMultipleService.getTooltipMessage();
        this.openWhenFocus = this.ngSelectMultipleService.getOpenWhenFocus();
        this.submitted = this.ngSelectMultipleService.getSubmitted();
        this.validatorAlert = this.ngSelectMultipleService.getValidatorAlert();
        this.appendTo = this.ngSelectMultipleService.getAppendTo();
        this.loadingText = this.ngSelectMultipleService.getLoadingText();
        this.markFirst = this.ngSelectMultipleService.getMarkFirst();
        this.virtualScroll = this.ngSelectMultipleService.getVirtualScroll();
    }
    ngOnDestroy() {
    }
    validate(control) {
        this.controls = control;
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    ngOnChanges(changes) {
        if (changes.items) {
            this.loading = true;
            if (isObservable(this.items)) {
                this.carga();
                // this.setAll();
                // this.items$ = this.items.pipe(finalize(() => {
                //   this.loading = false;
                //   this.cdrf.markForCheck();
                // })).subscribe(res => {
                //   this.cdrf.markForCheck();
                // })
            }
            else {
                this.all = this.items;
                this.loading = false;
            }
        }
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    carga() {
        return __awaiter(this, void 0, void 0, function* () {
            this.all = yield new Promise((resolve, reject) => {
                this.items = this.items.pipe(shareReplay({ refCount: true }));
                this.items$ = this.items.subscribe(res => {
                    resolve(res);
                });
            });
            this.loading = false;
        });
    }
    checkIfObservable(items) {
        if (isObservable(items))
            return true;
        else
            return false;
    }
    eventFocus(e) {
        this.onfocus.emit(e);
        if (this.openWhenFocus) {
            this.ngSelectMultiple.open();
        }
    }
    eventBlur(e) {
        this.onTouched();
        this.onValidationChange();
        this.blur.emit(e);
    }
    onRefresh() {
        this.onrefresh.emit();
    }
    ngOnInit() {
        if (isObservable(this.items)) {
            //this.setAll();
        }
        else {
            this.all = this.items;
        }
    }
    setAll() {
        this.items$ = this.items.subscribe(res => {
            this.all = res;
        });
    }
    writeValue(value) {
        if (value) {
            this._value = value;
        }
        else {
            this._value = [];
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    selectAll(e) {
        if (e.checked) {
            this.writeValue(this.all);
            if (this.isForFilter) {
                this.onChange(null);
            }
            else {
                this.onChange(this.all);
            }
        }
        else {
            this.writeValue([]);
            this.onChange([]);
        }
        this.checkedIndeterminate = false;
        this.ngSelectMultiple.focus();
        this.cdrf.markForCheck;
    }
    eventChange(e) {
        if (e.length == this.all.length) {
            this.checkedAll = true;
            this.checkedIndeterminate = false;
        }
        else if (e.length == 0) {
            this.checkedAll = false;
            this.checkedIndeterminate = false;
        }
        else {
            this.checkedAll = false;
            this.checkedIndeterminate = true;
        }
        this.writeValue(e);
        this.onChange(e);
        this.change.emit(e);
    }
    rightKeyUp() {
        this.ngSelectMultiple.close();
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError("000046", "Error", validator.message);
                return;
            }
        }
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    leftKeyUp() {
        this.ngSelectMultiple.close();
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError("000046", "Error", validator.message);
                return;
            }
        }
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
};
NgSelectMultipleComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-select-multiple',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n\r\n<div [class.input-icon]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n[class.refresh]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted && refresh\"\r\n[class.right]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\">\r\n\r\n  <!-- tooltip-message es el icono de error -->\r\n  <tooltip-message [label]=\"label\" [controls]=\"controls\" [validatorMessage]=\"validatorMessage\" [submitted]=\"submitted\"\r\n    [tooltipMessage]=\"tooltipMessage\"></tooltip-message>\r\n<div class=\"d-flex\">\r\n  <div class=\"w-100\">\r\n  <ng-select #ngSelectMultiple [items]=\"$any((checkIfObservable(items)) ? (items | async) : (items))\" [(ngModel)]=\"_value\"\r\n    [readonly]=\"disabled || readonly\" (change)=\"eventChange($event)\" (focus)=\"eventFocus($event)\"\r\n    (blur)=\"eventBlur($event)\" [virtualScroll]=\"virtualScroll\" [multiple]=\"true\" placeholder=\"Seleccionar\"\r\n    [closeOnSelect]=\"false\" [appendTo]=\"appendTo\" [inputAttrs]=\"{'autocomplete': autocomplete}\" [markFirst]=\"markFirst\"\r\n    (keyup.ArrowLeft)=\"leftKeyUp()\" (keyup.ArrowRight)=\"rightKeyUp()\" [loading]=\"loading\" [loadingText]=\"loadingText\" [clearSearchOnAdd]=\"true\"\r\n    [class.ng-select-invalid]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n    [class.ng-select-touched]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\">\r\n\r\n    <ng-template ng-header-tmp *ngIf=\"Header\">\r\n      <mat-checkbox class=\"ng-multiselect-checkbox\" [color]=\"'primary'\" [(ngModel)]=\"checkedAll\"\r\n        [indeterminate]=\"checkedIndeterminate\" (change)=\"selectAll($event)\">\r\n        <span *ngIf=\"!checkedAll\">{{Language.SelectAll}}</span>\r\n        <span *ngIf=\"checkedAll\">{{Language.UnselectAll}}</span>\r\n      </mat-checkbox>\r\n    </ng-template>\r\n\r\n    <ng-template ng-multi-label-tmp let-items=\"items\" let-clear=\"clear\"\r\n    *ngIf=\"$any((checkIfObservable(items)) ? (items | async) : (items))?.length != _value.length\">\r\n      <div class=\"ng-value\" *ngFor=\"let item of items | slice:0:showlimit\">\r\n        <span class=\"ng-value-label\"> {{$any(item).label}}</span>\r\n        <span class=\"ng-value-icon right\" (click)=\"clear(item)\" aria-hidden=\"true\">\u00D7</span>\r\n      </div>\r\n      <div class=\"ng-value\" *ngIf=\"items.length > showlimit\">\r\n        <span class=\"ng-value-label\">+{{items.length - showlimit}}</span>\r\n      </div>\r\n    </ng-template>\r\n\r\n    <ng-template ng-option-tmp let-item=\"item\" let-item$=\"item$\" let-index=\"index\">\r\n\r\n      <mat-checkbox class=\"ng-multiselect-checkbox\" id=\"item-{{index}}\" color=\"primary\" [checked]=\"item$.selected\"\r\n        (click)=\"false\"> <span data-toggle=\"tooltip\" title=\"{{item.label}}\">{{ item.label }}</span>\r\n      </mat-checkbox>\r\n    </ng-template>\r\n\r\n\r\n    <ng-template ng-multi-label-tmp let-items=\"items\" let-clear=\"clear\"\r\n    *ngIf=\"$any((checkIfObservable(items)) ? (items | async) : (items))?.length == _value.length\">\r\n      <div class=\"ng-value\">\r\n        <span class=\"ng-value-label\">{{Language.All}}</span>\r\n      </div>\r\n    </ng-template>\r\n\r\n    <ng-template ng-footer-tmp *ngIf=\"Footer\">\r\n      {{Language.Selected}}: {{_value.length}}\r\n    </ng-template>\r\n\r\n  </ng-select>\r\n  </div>\r\n  <div class=\"bd-highlight\" *ngIf=\"refresh\">\r\n    <button *ngIf=\"refresh\" type=\"button\" [disabled]=\"disabled || readonly\" class=\"btn btn-info p-0 rounded-0 h-100\"\r\n      (click)=\"onRefresh()\">\r\n      <!-- <mat-icon class=\"text-white pt-1\" style=\"font-size: 18px;\" [matTooltip]=\"'Refrescar'\" matTooltipClass=\"bg-info\">refresh</mat-icon> -->\r\n      <i class=\"la la-refresh text-white px-1\" [matTooltip]=\"'Refrescar'\" matTooltipClass=\"bg-info\"></i>\r\n    </button>\r\n  </div>\r\n  <ng-content select=\"[more-buttons]\"></ng-content>\r\n</div>\r\n\r\n</div>\r\n\r\n<!-- error-message es el mansaje que aparece abajo del componente -->\r\n<error-message [label]=\"label\" [controls]=\"controls\" [validatorMessage]=\"validatorMessage\"\r\n  [tooltipMessage]=\"tooltipMessage\" [submitted]=\"submitted\"></error-message>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NgSelectMultipleComponent_1),
                        multi: true
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => NgSelectMultipleComponent_1),
                        multi: true,
                    }
                ],
                styles: [".sumax-label{color:#646c9a!important}.input-icon{position:relative}.refresh>tooltip-message{margin-right:2.6em!important}.input-icon.right>tooltip-message{z-index:4;left:auto;right:8px;float:right}.input-icon>tooltip-message{color:#ccc;position:absolute;margin-top:.3rem;margin-right:1em;z-index:3;width:16px;font-size:16px;text-align:center;left:0}.input-icon.right>.form-control{padding-right:.1rem;padding-left:12px}\n"]
            },] }
];
NgSelectMultipleComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: MessageUtilService },
    { type: NgSelectMultipleService }
];
NgSelectMultipleComponent.propDecorators = {
    ngSelectMultiple: [{ type: ViewChild, args: ['ngSelectMultiple',] }],
    items: [{ type: Input }],
    showlimit: [{ type: Input }],
    showLabel: [{ type: Input }],
    label: [{ type: Input }],
    autocomplete: [{ type: Input }],
    Header: [{ type: Input }],
    Footer: [{ type: Input }],
    required: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    disabled: [{ type: Input }],
    readonly: [{ type: Input }],
    openWhenFocus: [{ type: Input }],
    markFirst: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    validatorAlert: [{ type: Input }],
    submitted: [{ type: Input }],
    refresh: [{ type: Input }],
    isForFilter: [{ type: Input }],
    appendTo: [{ type: Input }],
    Language: [{ type: Input }],
    virtualScroll: [{ type: Input }],
    loading: [{ type: Input }],
    loadingText: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    change: [{ type: Output }],
    blur: [{ type: Output }],
    onfocus: [{ type: Output }],
    onrefresh: [{ type: Output }]
};
NgSelectMultipleComponent = NgSelectMultipleComponent_1 = __decorate([
    AutoUnsubscribe()
], NgSelectMultipleComponent);

class NgSelectMultiple {
}

class NgSelectMultipleModule {
    static forRoot(ngSelectMultiple = new NgSelectMultiple()) {
        return {
            ngModule: NgSelectMultipleModule,
            providers: [
                { provide: 'NG_SELECT_MULTIPLE_SHOWLIMIT', useValue: ngSelectMultiple.showlimit },
                { provide: 'NG_SELECT_MULTIPLE_HEADER', useValue: ngSelectMultiple.Header },
                { provide: 'NG_SELECT_MULTIPLE_FOOTER', useValue: ngSelectMultiple.Footer },
                { provide: 'NG_SELECT_MULTIPLE_VALIDATOR_MESSAGE', useValue: ngSelectMultiple.validatorMessage },
                { provide: 'NG_SELECT_MULTIPLE_TOOLTIP_MESSAGE', useValue: ngSelectMultiple.tooltipMessage },
                { provide: 'NG_SELECT_MULTIPLE_OPEN_WHEN_FOCUS', useValue: ngSelectMultiple.openWhenFocus },
                { provide: 'NG_SELECT_MULTIPLE_SUBMITTED', useValue: ngSelectMultiple.submitted },
                { provide: 'NG_SELECT_MULTIPLE_VALIDATOR_ALERT', useValue: ngSelectMultiple.validatorAlert },
                { provide: 'NG_SELECT_MULTIPLE_APPEND_TO', useValue: ngSelectMultiple.appendTo },
                { provide: 'NG_SELECT_MULTIPLE_LOADING_TEXT', useValue: ngSelectMultiple.loadingText },
                { provide: 'NG_SELECT_MULTIPLE_MARK_FIRST', useValue: ngSelectMultiple.markFirst },
                { provide: 'NG_SELECT_MULTIPLE_VIRTUAL_SCROLL', useValue: ngSelectMultiple.virtualScroll },
                NgSelectMultipleService
            ]
        };
    }
}
NgSelectMultipleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgSelectMultipleComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    NgSelectModule,
                    MatCheckboxModule,
                    MatTooltipModule
                ],
                exports: [NgSelectMultipleComponent]
            },] }
];

class DialogAgGridSearchComponent {
    /** END: Pagination */
    constructor(dialogRef, cdrf, data) {
        this.dialogRef = dialogRef;
        this.cdrf = cdrf;
        this.onSelectRow = new EventEmitter();
        this.rowData = of([]);
        this.columnDefs = [];
        this.columnDefsActions = [];
        this.tittle = '';
        this.txtBuscar = new FormControl('');
        /** BEGIN: Config Ag-Grid */
        this.rowSelection = 'single';
        this.overlayNoRowsTemplate = `<span class="ag-overlay-loading-center border-0 bg-transparent shadow-none">
		No se encontraron registros...
		</span>`;
        this.overlayLoadingTemplate = `<span class="ag-overlay-loading-top d-flex align-items-center border-0 bg-white shadow p-4 text-info" style="height: 20px;">
		<img src="assets/media-demo/loading.gif" height="20" width="25" class="mr-2">
		<strong>Cargando registros</strong>
		</span>`;
        this.pagination = true;
        this.paginationPageSize = 10;
        this.paginas = [];
        this.$subscriptiontxtBuscar = this.txtBuscar.valueChanges.pipe(debounceTime(350)).subscribe(data => {
            this.gridApi.forEachNodeAfterFilter((node) => node.setSelected(false));
            this.gridApi.setQuickFilter(data);
        });
    }
    ngOnInit() {
        this.dialogRef.keydownEvents().subscribe((event) => {
            event.stopPropagation();
            if (event.key === 'Escape') {
                this.closeDialog();
            }
        });
    }
    selectFirstSearch() {
        if (!this.gridApi) {
            return;
        }
        if (this.columnDefsActions.length === 1) {
            return;
        }
        let rowData = [];
        this.gridApi.forEachNode((node) => rowData.push(node.data));
        if (rowData.length === 0) {
            this.btnAceptar.nativeElement.focus();
        }
        // return rowData;
        this.gridApi.forEachNodeAfterFilter((node) => node.rowIndex ? 0 : node.setSelected(true));
        this.gridApi.setFocusedCell(0, this.columnDefsActions[1].field);
    }
    focusLastRow() {
        let lastIndex = -1;
        this.gridApi.forEachNodeAfterFilter((node) => {
            if (node.rowIndex > lastIndex) {
                lastIndex = node.rowIndex;
            }
        });
        if (lastIndex === -1) {
            return;
        }
        this.gridApi.setFocusedCell(lastIndex, this.columnDefsActions[1].field);
    }
    onCellKeyPress(e) {
        let keyPressed = e.event.key;
        if (keyPressed === 'Enter') {
            let rowNode = e.node;
            if (rowNode.selected) {
                this.btnAceptar.nativeElement.focus();
            }
            else {
                rowNode.setSelected(true);
            }
        }
    }
    guardar() {
        this.dialogRef.close(this.gridApi.getSelectedRows());
    }
    closeDialog() {
        this.dialogRef.close([]);
    }
    /** BEGIN: Events Config Ag-Grid */
    onGridReady(gridApi, gridColumnApi) {
        this.columnDefsActions = this.columnDefs.concat([
            {
                headerName: '',
                field: '',
                width: 40,
                minWidth: 40,
                maxWidth: 40,
                checkboxSelection(params) {
                    return params.columnApi.getRowGroupColumns().length === 0;
                },
                pinned: 'left',
                sortable: false,
                lockPosition: true
            }
        ]);
        this.gridApi = gridApi;
        this.gridColumnApi = gridColumnApi;
        this.initRowData();
        this.agGrid.sizeFitColumnAction();
    }
    /** END: Events Config Ag-Grid */
    /** BEGIN: Events de desplazamiento en ag-grid */
    onPaginationChanged() {
        if (!this.gridApi) {
            return;
        }
        if (this.pagination && this.gridApi.paginationGetRowCount() > -1) {
            this.elbPageSize.nativeElement.innerHTML = this.gridApi.paginationGetRowCount();
            this.elbCurrentPage.nativeElement.innerHTML = this.gridApi.paginationGetCurrentPage() + 1;
            this.elbTotalPages.nativeElement.innerHTML = this.gridApi.paginationGetTotalPages();
            // this.elbtLast.nativeElement.setAttribute('disabled', !this.gridApi.paginationIsLastPageFound());
            this.pageFound = this.gridApi.paginationGetTotalPages() < 1;
            this.desde = Math.min(Math.max(1, this.gridApi.paginationGetCurrentPage() - 2), this.gridApi.paginationGetTotalPages() - 2);
            this.hasta = Math.max(Math.min(this.gridApi.paginationGetTotalPages(), this.gridApi.paginationGetCurrentPage() + 2), 5);
            if (this.gridApi.paginationGetTotalPages() > 5) {
                this.paginas = new Array(this.hasta - this.desde + 1).fill(0).map((valor, indice) => indice + this.desde);
            }
            else {
                this.paginas = new Array(this.gridApi.paginationGetTotalPages()).fill(0).map((valor, indice) => indice + 1);
            }
        }
    }
    onBtFirst() {
        this.gridApi.paginationGoToFirstPage();
        this.autoSizeColumns();
    }
    onBtPrevious() {
        this.gridApi.paginationGoToPreviousPage();
        this.autoSizeColumns();
    }
    onBtNext() {
        this.gridApi.paginationGoToNextPage();
        this.autoSizeColumns();
    }
    onBtLast() {
        this.gridApi.paginationGoToLastPage();
        this.autoSizeColumns();
    }
    onPageSizeChanged(evt) {
        this.gridApi.paginationSetPageSize(Number(evt.target.value));
    }
    onGoToPage(page) {
        this.gridApi.paginationGoToPage(page);
    }
    /** END: Events de desplazamiento en ag-grid */
    /** BEGIN: UTILS  */
    initRowData() {
        if (this.rowDataSubscription) {
            this.rowDataSubscription.unsubscribe();
            this.gridApi.setRowData([]);
            this.gridApi.showLoadingOverlay();
        }
        this.rowDataSubscription = this.rowData.subscribe((data) => {
            this.gridApi.setRowData(data);
            if (this.columnDefs.length === 0 && data.length > 0) {
                let columnDefs = [];
                let keys = Object.keys(data[0]);
                keys.forEach(element => {
                    if (typeof data[0][element] !== 'object') {
                        columnDefs.push({ field: element, headerName: element.toUpperCase() });
                    }
                });
                this.columnDefsActions = columnDefs.concat([
                    {
                        headerName: '',
                        field: '',
                        width: 40,
                        minWidth: 40,
                        maxWidth: 40,
                        checkboxSelection(params) {
                            return params.columnApi.getRowGroupColumns().length === 0;
                        },
                        pinned: 'left',
                        sortable: false,
                        lockPosition: true
                    }
                ]);
            }
            this.gridApi.sizeColumnsToFit();
            const colIds = this.gridColumnApi
                .getAllDisplayedColumns()
                .map((col) => col.getColId());
            this.gridColumnApi.autoSizeColumns(colIds);
            this.cdrf.detectChanges();
        });
    }
    autoSizeColumns() {
        const colIds = this.gridColumnApi
            .getAllDisplayedColumns()
            .map((col) => col.getColId());
        this.gridColumnApi.autoSizeColumns(colIds);
    }
}
DialogAgGridSearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'dialog-ag-grid-search',
                template: "<div class=\"row w-100 m-0\">\r\n\t<div class=\"col-12\">\r\n\t\t<div class=\"sumax-dialog-head\">\r\n\t\t\t<div style=\"display: flex;align-items: center;align-content: flex-first;\">\r\n\t\t\t\t<div class=\"mr-3\"><i class=\"fa fa-list\" style=\"font-size: 1.25em !important; color: #646c9a;\"></i></div>\r\n\t\t\t\t<h3 class=\"sumax-dialog-head-title py-1 mr-1\" style=\"line-height: 1.2;\r\n\t\t\t\tfont-family: Soho Gothic Pro;\r\n\t\t\t\t-ms-text-size-adjust: 100%;\r\n\t\t\t\t-webkit-font-smoothing: antialiased;\"><strong>{{ tittle }}</strong></h3>\r\n\t\t\t</div>\r\n\t\t</div>\r\n\t\t<mat-dialog-content class=\"p-3\">\r\n\t\t\t<div class=\"modal-body px-3 py-0\">\r\n\t\t\t\t<sc-ag-grid-customizable\r\n\t\t\t\t#agGrid\r\n\t\t\t\t[columnDefs]=\"columnDefsActions\"\r\n\t\t\t\t[pagination]=\"true\"\r\n\t\t\t\t[btnAdd]=\"{ visible: false, disabled: true }\"\r\n\t\t\t\t(onGridReady)=\"onGridReady($event[0], $event[1])\"\r\n\t\t  >\r\n\t\t  </sc-ag-grid-customizable>\r\n\t\t\t</div>\r\n\t\t</mat-dialog-content>\r\n\t\t<mat-dialog-actions class=\"pl-3\">\r\n\t\t\t<div class=\"row pt-3 pb-3 w-100\" style=\"border-top: 1px solid #ebedf2;\r\n\t\t\tborder-bottom-left-radius: 4px;\r\n\t\t\tborder-bottom-right-radius: 4px;\">\r\n\t\t\t\t<div class=\"col-lg-12 d-flex justify-content-end my-auto\">\r\n\t\t\t\t\t<button style=\"width: 110px;\" #btnAceptar (click)=\"guardar()\" [disabled]=\"agGrid.selectedRows.length <= 0\" (keyup.ArrowUp)=\"focusLastRow()\"\r\n\t\t\t\t\t\t(keyup.ArrowRight)=\"btnCancelar.focus()\"  type=\"button\" class=\"btn btn-sm btn-success mr-3\">Aceptar</button>\r\n\t\t\t\t\t<button style=\"width: 110px;\" #btnCancelar (click)=\"closeDialog()\" (keyup.ArrowUp)=\"focusLastRow()\"\r\n\t\t\t\t\t\t(keyup.ArrowLeft)=\"btnAceptar.focus()\" type=\"button\" class=\"btn btn-sm btn-danger\">Cancelar</button>\r\n\t\t\t\t</div>\r\n\t\t\t</div>\r\n\t\t</mat-dialog-actions>\r\n\t</div>\r\n</div>",
                styles: ["#paginacion{margin:0;padding:0}#paginacion>nav>ul>li>a>i{margin:0;padding:0}#paginacion>nav>ul>li>a{cursor:pointer}#paginacion>nav>ul>li>a,#paginacion>nav>ul>li>span,.totalRegistros{font-size:1rem}.totalRegistros>span{padding-left:4px;font-size:1rem}button[disabled]{pointer-events:none}.sumax-dialog{display:flex;flex-grow:1;flex-direction:column;box-shadow:0 0 13px #523f690d;background-color:#fff;border-radius:4px;margin-bottom:0!important}.sumax-dialog-head{padding:0 15px;min-height:50px;display:flex;align-items:stretch;justify-content:space-between;position:relative;border-bottom:1px solid #ebedf2;border-top-left-radius:4px;border-top-right-radius:4px}.sumax-dialog-head-title{margin:0;padding:0;font-size:1.2rem;font-weight:500;color:#48465b}\n"]
            },] }
];
DialogAgGridSearchComponent.ctorParameters = () => [
    { type: MatDialogRef },
    { type: ChangeDetectorRef },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] }] }
];
DialogAgGridSearchComponent.propDecorators = {
    btnAceptar: [{ type: ViewChild, args: ['btnAceptar',] }],
    btnCancelar: [{ type: ViewChild, args: ['btnCancelar',] }],
    elTxtBuscar: [{ type: ViewChild, args: ['elTxtBuscar',] }],
    agGrid: [{ type: ViewChild, args: ['agGrid',] }],
    onSelectRow: [{ type: Output }],
    rowData: [{ type: Input }],
    columnDefs: [{ type: Input }],
    tittle: [{ type: Input }],
    rowSelection: [{ type: Input }],
    elbPageSize: [{ type: ViewChild, args: ['lbPageSize',] }],
    elbCurrentPage: [{ type: ViewChild, args: ['lbCurrentPage',] }],
    elbTotalPages: [{ type: ViewChild, args: ['lbTotalPages',] }],
    pagination: [{ type: Input }],
    paginationPageSize: [{ type: Input }]
};

class ValidateUtil {
    // messageUtilService = new MessageUtilService();
    requerido(obj, nombre) {
        if (typeof obj == "undefined" || obj == "Invalid date" || obj == null) {
            throw nombre;
        }
    }
    isUndefinedOrNull(obj) {
        if (typeof obj == "undefined" || obj == "Invalid date" || obj == null) {
            return true;
        }
        if (typeof obj == "string" && obj == '') {
            return true;
        }
        return false;
    }
}

class NgSelectSimpleService {
    constructor(validatorMessage = false, tooltipMessage = true, openWhenFocus = false, searchBy = "value", markFirstItem = false, submitted = true, searchable = true, validatorAlert = false, upperCase = false, appendTo = "body", loadingText = "Cargando...", clearAllText = "Limpiar", markFirst = true, clearable = true, clearOnBackspace = false, virtualScroll = true, openOnEnter = false, notFoundText = "No se encontraron resultados") {
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.openWhenFocus = openWhenFocus;
        this.searchBy = searchBy;
        this.markFirstItem = markFirstItem;
        this.submitted = submitted;
        this.searchable = searchable;
        this.validatorAlert = validatorAlert;
        this.upperCase = upperCase;
        this.appendTo = appendTo;
        this.loadingText = loadingText;
        this.clearAllText = clearAllText;
        this.markFirst = markFirst;
        this.clearable = clearable;
        this.clearOnBackspace = clearOnBackspace;
        this.virtualScroll = virtualScroll;
        this.openOnEnter = openOnEnter;
        this.notFoundText = notFoundText;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getOpenWhenFocus() {
        return this.openWhenFocus;
    }
    getSearchBy() {
        return this.searchBy;
    }
    getMarkFirstItem() {
        return this.markFirstItem;
    }
    getSubmitted() {
        return this.submitted;
    }
    getSearchable() {
        return this.searchable;
    }
    getValidatorAlert() {
        return this.validatorAlert;
    }
    getUpperCase() {
        return this.upperCase;
    }
    getAppendTo() {
        return this.appendTo;
    }
    getLoadingText() {
        return this.loadingText;
    }
    getClearAllText() {
        return this.clearAllText;
    }
    getMarkFirst() {
        return this.markFirst;
    }
    getClearable() {
        return this.clearable;
    }
    getClearOnBackspace() {
        return this.clearOnBackspace;
    }
    getVirtualScroll() {
        return this.virtualScroll;
    }
    getOpenOnEnter() {
        return this.openOnEnter;
    }
    getNotFoundText() {
        return this.notFoundText;
    }
}
NgSelectSimpleService.ɵprov = i0.ɵɵdefineInjectable({ factory: function NgSelectSimpleService_Factory() { return new NgSelectSimpleService(i0.ɵɵinject("NG_SELECT_SIMPLE_VALIDATOR_MESSAGE"), i0.ɵɵinject("NG_SELECT_SIMPLE_TOOLTIP_MESSAGE"), i0.ɵɵinject("NG_SELECT_SIMPLE_OPEN_WHEN_FOCUS"), i0.ɵɵinject("NG_SELECT_SIMPLE_SEARCH_BY"), i0.ɵɵinject("NG_SELECT_SIMPLE_MARK_FIRST_ITEM"), i0.ɵɵinject("NG_SELECT_SIMPLE_SUBMITTED"), i0.ɵɵinject("NG_SELECT_SIMPLE_SEARCHABLE"), i0.ɵɵinject("NG_SELECT_SIMPLE_VALIDATOR_ALERT"), i0.ɵɵinject("NG_SELECT_SIMPLE_UPPER_CASE"), i0.ɵɵinject("NG_SELECT_SIMPLE_APPEND_TO"), i0.ɵɵinject("NG_SELECT_SIMPLE_LOADING_TEXT"), i0.ɵɵinject("NG_SELECT_SIMPLE_CLEAR_ALL_TEXT"), i0.ɵɵinject("NG_SELECT_SIMPLE_MARK_FIRST"), i0.ɵɵinject("NG_SELECT_SIMPLE_CLEARABLE"), i0.ɵɵinject("NG_SELECT_SIMPLE_CLEAR_ON_BACKSPACE"), i0.ɵɵinject("NG_SELECT_SIMPLE_VIRTUAL_SCROLL"), i0.ɵɵinject("NG_SELECT_SIMPLE_OPEN_ON_ENTER"), i0.ɵɵinject("NG_SELECT_SIMPLE_NOT_FOUND_TEXT")); }, token: NgSelectSimpleService, providedIn: "root" });
NgSelectSimpleService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
NgSelectSimpleService.ctorParameters = () => [
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_OPEN_WHEN_FOCUS',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_SEARCH_BY',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_MARK_FIRST_ITEM',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_SUBMITTED',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_SEARCHABLE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_VALIDATOR_ALERT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_UPPER_CASE',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_APPEND_TO',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_LOADING_TEXT',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_CLEAR_ALL_TEXT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_MARK_FIRST',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_CLEARABLE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_CLEAR_ON_BACKSPACE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_VIRTUAL_SCROLL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_OPEN_ON_ENTER',] }] },
    { type: String, decorators: [{ type: Inject, args: ['NG_SELECT_SIMPLE_NOT_FOUND_TEXT',] }] }
];

var NgSelectSimpleComponent_1;
class SearchParams {
    constructor(columnDefs = [], title = '', width = '990px', rowData = of([])) {
        this.columnDefs = columnDefs;
        this.title = title;
        this.width = width;
        this.rowData = rowData;
    }
}
class ColumnDefs {
}
let NgSelectSimpleComponent = NgSelectSimpleComponent_1 = class NgSelectSimpleComponent {
    constructor(messageUtilService, dialog, ngSelectSimpleService) {
        this.messageUtilService = messageUtilService;
        this.dialog = dialog;
        this.ngSelectSimpleService = ngSelectSimpleService;
        this.showLabel = true;
        this.label = null;
        this.autocomplete = 'cc-csc';
        this.required = false;
        this.disabled = false;
        this.readonly = false;
        this.validatorMessage = false;
        this.tooltipMessage = true;
        this.openWhenFocus = false;
        this.searchBy = 'value';
        this.markFirstItem = false;
        this.markWhenHaveOneItem = false;
        this.submitted = true;
        this.setNgClass = '';
        this.searchable = true;
        this.validatorAlert = false;
        this.upperCase = false;
        this.templateLabel = null;
        this.appendTo = 'body';
        this.loading = true;
        this.loadingText = 'Cargando...';
        this.clearAllText = 'Limpiar';
        this.notFoundText = 'No se encontraron resultados';
        this.markFirst = true;
        this.clearable = true;
        this.clearOnBackspace = false;
        this.virtualScroll = true;
        this.openOnEnter = false;
        this.refresh = false;
        this.search = false;
        this.searchParams = new SearchParams();
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.change = new EventEmitter();
        this.blur = new EventEmitter();
        this.onfocus = new EventEmitter();
        this.onrefresh = new EventEmitter();
        this.onsearch = new EventEmitter();
        this.validateUtil = new ValidateUtil();
        this.sharedComponentsUtil = new SharedComponentsUtil();
        this.allItems = [];
        this.onChange = (_) => { };
        this.onValidationChange = () => { };
        this.onTouched = () => { };
        this.focus = () => {
            this.ngSelectSimple.focus();
            if (this.openWhenFocus) {
                this.ngSelectSimple.open();
            }
        };
        this.close = () => {
            this.ngSelectSimple.close();
        };
        this.validatorMessage = this.ngSelectSimpleService.getValidatorMessage();
        this.tooltipMessage = this.ngSelectSimpleService.getTooltipMessage();
        this.openWhenFocus = this.ngSelectSimpleService.getOpenWhenFocus();
        this.searchBy = this.ngSelectSimpleService.getSearchBy();
        this.markFirstItem = this.ngSelectSimpleService.getMarkFirstItem();
        this.submitted = this.ngSelectSimpleService.getSubmitted();
        this.searchable = this.ngSelectSimpleService.getSearchable();
        this.validatorAlert = this.ngSelectSimpleService.getValidatorAlert();
        this.upperCase = this.ngSelectSimpleService.getUpperCase();
        this.appendTo = this.ngSelectSimpleService.getAppendTo();
        this.loadingText = this.ngSelectSimpleService.getLoadingText();
        this.clearAllText = this.ngSelectSimpleService.getClearAllText();
        this.markFirst = this.ngSelectSimpleService.getMarkFirst();
        this.clearable = this.ngSelectSimpleService.getClearable();
        this.clearOnBackspace = this.ngSelectSimpleService.getClearOnBackspace();
        this.virtualScroll = this.ngSelectSimpleService.getVirtualScroll();
        this.openOnEnter = this.ngSelectSimpleService.getOpenOnEnter();
        this.notFoundText = this.ngSelectSimpleService.getNotFoundText();
    }
    ngOnDestroy() { }
    ngOnChanges(changes) {
        if (changes.items) {
            this.loading = true;
            this.carga();
        }
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    carga() {
        return __awaiter(this, void 0, void 0, function* () {
            this.allItems = yield new Promise((resolve, reject) => {
                this.items = this.items.pipe(shareReplay({ refCount: true }));
                this.items$ = this.items.subscribe((res) => {
                    resolve(res);
                });
            });
            this.loading = false;
            if (this._value != null) {
                this.allItems.forEach((element) => {
                    if (!this.validateUtil.isUndefinedOrNull(this.getObject(element, this.searchBy)) &&
                        this.getObject(element, this.searchBy) === this._value) {
                        this._value = element;
                        this.onChange(this._value);
                        this.onValidationChange();
                        this.change.emit(this._value);
                    }
                });
            }
            else {
                if (this.markFirstItem && this.allItems.length > 0) {
                    this._value = this.allItems[0];
                    this.onChange(this._value);
                    this.onValidationChange();
                    this.change.emit(this._value);
                }
                if (this.markWhenHaveOneItem && this.allItems.length === 1) {
                    this._value = this.allItems[0];
                    this.onChange(this._value);
                    this.onValidationChange();
                    this.change.emit(this._value);
                }
            }
        });
    }
    ngOnInit() { }
    getObject(obj, key) {
        return key.split('.').reduce(function (o, x) {
            return typeof o == 'undefined' || o === null ? o : o[x];
        }, obj);
    }
    writeValue(value) {
        if (value != null) {
            if (this.loading) {
                this._value = value;
            }
            else {
                this._value = value;
                this.allItems.forEach((element) => {
                    if (!this.validateUtil.isUndefinedOrNull(this.getObject(element, this.searchBy)) &&
                        this.getObject(element, this.searchBy) === this._value) {
                        this._value = element;
                        this.onChange(this._value);
                        this.onValidationChange();
                        this.change.emit(this._value);
                    }
                });
            }
            //this.searchElement(value);
            this.onValidationChange();
        }
        else {
            this._value = null;
            this.onValidationChange();
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    validate(control) {
        this.controls = control;
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    eventChange(e) {
        this.onChange(e);
        this.onValidationChange();
        this.change.emit(e);
    }
    eventBlur(e) {
        this.onTouched();
        this.onValidationChange();
        this.blur.emit(e);
    }
    eventFocus(e) {
        // this.ngSelectSimple.focus();
        if (this.openWhenFocus) {
            this.ngSelectSimple.open();
        }
        this.onfocus.emit(e);
    }
    eventSearch(e) {
        this.onsearch.emit(e);
    }
    enterKeyUp() {
        this.ngSelectSimple.close();
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    leftKeyUp() {
        this.ngSelectSimple.close();
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
    clear() {
        this._value = null;
        this.onChange(this._value);
        this.onValidationChange();
        this.change.emit(this._value);
    }
    onRefresh() {
        this.onrefresh.emit();
    }
    onSearch() {
        return __awaiter(this, void 0, void 0, function* () {
            const dialogRef = this.dialog.open(DialogAgGridSearchComponent, {
                width: this.searchParams.width,
                disableClose: true,
            });
            let rowdata = yield this.searchParams.rowData.toPromise();
            let instance = dialogRef.componentInstance;
            instance.tittle =
                this.searchParams.title === '' ? this.label : this.searchParams.title;
            instance.rowData =
                rowdata.length < 1 ? this.items : this.searchParams.rowData;
            instance.columnDefs = this.searchParams.columnDefs;
            dialogRef.afterClosed().subscribe((resp) => {
                this.focus();
                if (resp.length > 0) {
                    this._value = resp[0];
                    this.onChange(this._value);
                    this.onValidationChange();
                    this.change.emit(this._value);
                }
            });
        });
    }
    f2KeyUp() {
        if (!this.btnSearch) {
            return;
        }
        this.ngSelectSimple.close();
        //this.btnSearch.nativeElement.focus();
        this.onSearch();
    }
};
NgSelectSimpleComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-select-simple',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  >\r\n\r\n  <span *ngIf=\"!templateLabel; else templateLabel\" [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">\r\n    {{label}}\r\n  </span>\r\n  <span *ngIf=\"required\" [class.text-danger]=\"controls?.errors != null\">\r\n    *</span\r\n  >\r\n  <span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n\r\n<div\r\n  [class.input-icon]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n  [class.right]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted\r\n  \"\r\n  [class.refresh]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted &&\r\n    refresh\r\n  \"\r\n  [class.search]=\"\r\n    controls?.errors != null &&\r\n    (controls?.dirty || controls?.touched) &&\r\n    submitted &&\r\n    search\r\n  \"\r\n>\r\n  <div class=\"d-flex\">\r\n    <div\r\n      class=\"position-relative\"\r\n      [class.app-ng-selec-container]=\"search || refresh\"\r\n      [class.w-100]=\"!search && !refresh\"\r\n    >\r\n      <ng-select\r\n        #ngSelectSimple\r\n        [class]=\"search || refresh ? 'app-ng-select' : 'w-100'\"\r\n        [class.action]=\"search && refresh\"\r\n        [items]=\"items | async\"\r\n        [(ngModel)]=\"_value\"\r\n        [disabled]=\"disabled\"\r\n        [readonly]=\"readonly\"\r\n        (change)=\"eventChange($event)\"\r\n        (blur)=\"eventBlur($event)\"\r\n        (focus)=\"eventFocus($event)\"\r\n        (search)=\"eventSearch($event)\"\r\n        [markFirst]=\"markFirst\"\r\n        [clearable]=\"!required && clearable\"\r\n        [virtualScroll]=\"virtualScroll\"\r\n        [inputAttrs]=\"{ autocomplete: autocomplete }\"\r\n        [clearOnBackspace]=\"clearOnBackspace\"\r\n        [openOnEnter]=\"openOnEnter\"\r\n        (keydown.delete)=\"!required && clearable ? clear() : ''\"\r\n        (clear)=\"clear()\"\r\n        (keyup.F2)=\"$event.preventDefault();$event.stopPropagation();f2KeyUp()\"\r\n        [notFoundText]=\"notFoundText\"\r\n        placeholder=\"Seleccionar\"\r\n        (keyup.enter)=\"enterKeyUp()\"\r\n        [clearAllText]=\"clearAllText\"\r\n        [searchable]=\"searchable\"\r\n        (keyup.ArrowLeft)=\"leftKeyUp()\"\r\n        [appendTo]=\"appendTo\"\r\n        [loading]=\"loading\"\r\n        [loadingText]=\"loadingText\"\r\n        [class.ng-select-invalid]=\"\r\n          controls?.errors != null &&\r\n          (controls?.dirty || controls?.touched) &&\r\n          submitted\r\n        \"\r\n        [class.ng-select-touched]=\"\r\n          controls?.errors != null &&\r\n          (controls?.dirty || controls?.touched) &&\r\n          submitted\r\n        \"\r\n        [class.upperCase]=\"upperCase\"\r\n        [ngClass]=\"setNgClass\"\r\n      >\r\n        <!-- OPCIONES DE LISTADO -->\r\n        <ng-template ng-option-tmp let-item=\"item\" let-index=\"index\">\r\n          <span data-toggle=\"tooltip\" title=\"{{ item.label }}\">{{\r\n            item.label\r\n          }}</span>\r\n        </ng-template>\r\n      </ng-select>\r\n\r\n      <!-- tooltip-message es el icono de error -->\r\n      <tooltip-message\r\n        [label]=\"label\"\r\n        [controls]=\"controls\"\r\n        [validatorMessage]=\"validatorMessage\"\r\n        [submitted]=\"submitted\"\r\n        [tooltipMessage]=\"tooltipMessage\"\r\n      ></tooltip-message>\r\n    </div>\r\n    <ng-container *ngIf=\"search && refresh; else templateAction\">\r\n      <div class=\"app-ng-select-action bd-highligh\">\r\n        <button\r\n          #btnSearch\r\n          type=\"button\"\r\n          [disabled]=\"disabled || readonly\"\r\n          class=\"btn p-0 rounded-0 h-100\"\r\n          style=\"background-color: orange; border-color: orange;\"\r\n          (keyup.ArrowLeft)=\"ngSelectSimple.focus()\"\r\n          (click)=\"onSearch()\"\r\n        >\r\n          <i\r\n            class=\"fa fa-search text-white px-1\"\r\n            [matTooltip]=\"'Buscar'\"\r\n            matTooltipClass=\"custom-tooltip\"\r\n          ></i>\r\n        </button>\r\n        <button\r\n          *ngIf=\"refresh\"\r\n          type=\"button\"\r\n          [disabled]=\"disabled || readonly\"\r\n          class=\"btn btn-info p-0 rounded-0 h-100\"\r\n          (click)=\"onRefresh()\"\r\n        >\r\n          <i\r\n            class=\"la la-refresh text-white px-1\"\r\n            [matTooltip]=\"'Refrescar'\"\r\n            matTooltipClass=\"bg-info\"\r\n          ></i>\r\n        </button>\r\n      </div>\r\n    </ng-container>\r\n\r\n    <ng-template #templateAction>\r\n      <div class=\"app-ng-select-button bd-highlight\" *ngIf=\"search\">\r\n        <button\r\n          #btnSearch\r\n          type=\"button\"\r\n          [disabled]=\"disabled || readonly\"\r\n          class=\"btn p-0 rounded-0 h-100\"\r\n          style=\"background-color: orange; border-color: orange;\"\r\n          (keyup.ArrowLeft)=\"ngSelectSimple.focus()\"\r\n          (click)=\"onSearch()\"\r\n        >\r\n          <i\r\n            class=\"fa fa-search text-white px-1\"\r\n            [matTooltip]=\"'Buscar'\"\r\n            matTooltipClass=\"custom-tooltip\"\r\n          ></i>\r\n        </button>\r\n      </div>\r\n      <div class=\"app-ng-select-button bd-highlight\" *ngIf=\"refresh\">\r\n        <button\r\n          *ngIf=\"refresh\"\r\n          type=\"button\"\r\n          [disabled]=\"disabled || readonly\"\r\n          class=\"btn btn-info p-0 rounded-0 h-100\"\r\n          (click)=\"onRefresh()\"\r\n        >\r\n          <i\r\n            class=\"la la-refresh text-white px-1\"\r\n            [matTooltip]=\"'Refrescar'\"\r\n            matTooltipClass=\"bg-info\"\r\n          ></i>\r\n        </button>\r\n      </div>\r\n    </ng-template>\r\n\r\n    <ng-content select=\"[more-buttons]\"></ng-content>\r\n  </div>\r\n</div>\r\n\r\n<!-- error-message es el mansaje que aparece abajo del componente -->\r\n<error-message\r\n  [label]=\"label\"\r\n  [controls]=\"controls\"\r\n  [validatorMessage]=\"validatorMessage\"\r\n  [submitted]=\"submitted\"\r\n  [tooltipMessage]=\"tooltipMessage\"\r\n></error-message>\r\n",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NgSelectSimpleComponent_1),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => NgSelectSimpleComponent_1),
                        multi: true,
                    },
                ],
                encapsulation: ViewEncapsulation.None,
                styles: ["ng-select-simple{display:block}.sumax-label{color:#646c9a!important}.input-icon tooltip-message{color:#ccc;position:absolute;z-index:3;font-size:16px;text-align:center;right:9px;top:50%;transform:translateY(-50%)}.input-icon.right>.form-control{padding-right:33px;padding-left:12px}.upperCase .ng-select-container .ng-value-container .ng-input>input{text-transform:uppercase}.app-ng-select-button{width:34px}.app-ng-select-button button{width:100%}.app-ng-selec-container{width:calc(100% - 34px)}.app-ng-select-action{width:calc(100% - 80%)}.app-ng-select-action button{width:50%}.overflow-box{padding:5px;height:100px;border:1px solid #999;overflow:hidden}.ng-dropdown-panel{width:auto!important;max-width:550px;min-width:100%}.custom-tooltip{background-color:orange!important}\n"]
            },] }
];
NgSelectSimpleComponent.ctorParameters = () => [
    { type: MessageUtilService },
    { type: MatDialog },
    { type: NgSelectSimpleService }
];
NgSelectSimpleComponent.propDecorators = {
    ngSelectSimple: [{ type: ViewChild, args: ['ngSelectSimple',] }],
    btnSearch: [{ type: ViewChild, args: ['btnSearch',] }],
    showLabel: [{ type: Input }],
    label: [{ type: Input }],
    autocomplete: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    required: [{ type: Input }],
    disabled: [{ type: Input }],
    readonly: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    openWhenFocus: [{ type: Input }],
    searchBy: [{ type: Input }],
    markFirstItem: [{ type: Input }],
    markWhenHaveOneItem: [{ type: Input }],
    submitted: [{ type: Input }],
    setNgClass: [{ type: Input }],
    searchable: [{ type: Input }],
    validatorAlert: [{ type: Input }],
    upperCase: [{ type: Input }],
    templateLabel: [{ type: Input }],
    appendTo: [{ type: Input }],
    items: [{ type: Input }],
    loading: [{ type: Input }],
    loadingText: [{ type: Input }],
    clearAllText: [{ type: Input }],
    notFoundText: [{ type: Input }],
    markFirst: [{ type: Input }],
    clearable: [{ type: Input }],
    clearOnBackspace: [{ type: Input }],
    virtualScroll: [{ type: Input }],
    openOnEnter: [{ type: Input }],
    refresh: [{ type: Input }],
    search: [{ type: Input }],
    searchParams: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    change: [{ type: Output }],
    blur: [{ type: Output }],
    onfocus: [{ type: Output }],
    onrefresh: [{ type: Output }],
    onsearch: [{ type: Output }]
};
NgSelectSimpleComponent = NgSelectSimpleComponent_1 = __decorate([
    AutoUnsubscribe()
], NgSelectSimpleComponent);

class NgSelectSimple {
}

class NgSelectSimpleModule {
    static forRoot(ngSelectSimple = new NgSelectSimple()) {
        return {
            ngModule: NgSelectSimpleModule,
            providers: [
                { provide: 'NG_SELECT_SIMPLE_VALIDATOR_MESSAGE', useValue: ngSelectSimple.validatorMessage },
                { provide: 'NG_SELECT_SIMPLE_TOOLTIP_MESSAGE', useValue: ngSelectSimple.tooltipMessage },
                { provide: 'NG_SELECT_SIMPLE_OPEN_WHEN_FOCUS', useValue: ngSelectSimple.openWhenFocus },
                { provide: 'NG_SELECT_SIMPLE_SEARCH_BY', useValue: ngSelectSimple.searchBy },
                { provide: 'NG_SELECT_SIMPLE_MARK_FIRST_ITEM', useValue: ngSelectSimple.markFirstItem },
                { provide: 'NG_SELECT_SIMPLE_SUBMITTED', useValue: ngSelectSimple.submitted },
                { provide: 'NG_SELECT_SIMPLE_SEARCHABLE', useValue: ngSelectSimple.searchable },
                { provide: 'NG_SELECT_SIMPLE_VALIDATOR_ALERT', useValue: ngSelectSimple.validatorAlert },
                { provide: 'NG_SELECT_SIMPLE_UPPER_CASE', useValue: ngSelectSimple.upperCase },
                { provide: 'NG_SELECT_SIMPLE_APPEND_TO', useValue: ngSelectSimple.appendTo },
                { provide: 'NG_SELECT_SIMPLE_LOADING_TEXT', useValue: ngSelectSimple.loadingText },
                { provide: 'NG_SELECT_SIMPLE_CLEAR_ALL_TEXT', useValue: ngSelectSimple.clearAllText },
                { provide: 'NG_SELECT_SIMPLE_MARK_FIRST', useValue: ngSelectSimple.markFirst },
                { provide: 'NG_SELECT_SIMPLE_CLEARABLE', useValue: ngSelectSimple.clearable },
                { provide: 'NG_SELECT_SIMPLE_CLEAR_ON_BACKSPACE', useValue: ngSelectSimple.clearOnBackspace },
                { provide: 'NG_SELECT_SIMPLE_VIRTUAL_SCROLL', useValue: ngSelectSimple.virtualScroll },
                { provide: 'NG_SELECT_SIMPLE_OPEN_ON_ENTER', useValue: ngSelectSimple.openOnEnter },
                { provide: 'NG_SELECT_SIMPLE_NOT_FOUND_TEXT', useValue: ngSelectSimple.notFoundText },
                NgSelectSimpleService
            ]
        };
    }
}
NgSelectSimpleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [NgSelectSimpleComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    MatTooltipModule,
                    MatDialogModule,
                    NgSelectModule,
                    MatDialogModule,
                    MatIconModule,
                ],
                exports: [NgSelectSimpleComponent],
                providers: []
            },] }
];

var EnumButtonType;
(function (EnumButtonType) {
    EnumButtonType["TYPE_NONE"] = "TYPE_NONE";
    EnumButtonType["TYPE_EDIT"] = "TYPE_EDIT";
    EnumButtonType["TYPE_DELETE"] = "TYPE_DELETE";
})(EnumButtonType || (EnumButtonType = {}));

var TypeControl;
(function (TypeControl) {
    TypeControl["INPUT_TEXT"] = "input-text";
    TypeControl["INPUT_NUMBER"] = "input-number";
    TypeControl["NG_SELECT_SIMPLE"] = "ng-select-simple";
    TypeControl["NG_SELECT_MULTIPLE"] = "ng-select-multiple";
    TypeControl["DATE_PICKER"] = "date-picker";
    TypeControl["DATE_TIME_PICKER_EDITABLE"] = "date-time-picker-editable";
})(TypeControl || (TypeControl = {}));
class ContainerSharedComponent {
    constructor(cdRef) {
        this.cdRef = cdRef;
        this.value = null;
        this.params = {};
        this.label = 'undefined';
        this.width = '100px';
        this.items = of([]);
        this.defaultValue = null;
        this.validators = [];
        this.required = false;
        this.inputMask = '';
        this.textRight = false;
        this.decimals = 0;
        this.formatCero = false;
        this.clearable = false;
        this.maxLength = undefined;
        this.typeControl = null;
        this.formControl = new FormControl(null);
    }
    set control(v) {
        setTimeout(() => {
            if (v instanceof NgSelectSimpleComponent)
                v.ngSelectSimple.focus();
            else if (v instanceof InputTextComponent)
                v._inputText.nativeElement.focus();
            else if (v instanceof InputNumberComponent)
                v.inputText.nativeElement.focus();
            else if (v instanceof DatePickerComponent)
                v.focus();
            else
                v.focus();
        }, 150);
    }
    agInit(params) {
        this.formControl.markAllAsTouched();
        this.params = params;
        //console.log(params, 'PARAMS');
        if (this.params.width)
            this.width = this.params.width;
        if (this.params.items)
            this.items = this.params.items;
        if (this.params.defaultValue)
            this.defaultValue = this.params.defaultValue(this.params.data);
        if (this.params.validatorsCellEditor)
            this.validators = this.params.validatorsCellEditor;
        this.formControl.setValidators(this.validators);
        this.formControl.updateValueAndValidity();
        if (this.params.configControl) {
            const configControl = this.params.configControl;
            if (configControl.required)
                this.required = configControl.required;
            if (configControl.label)
                this.label = configControl.label;
            if (configControl.typeControl)
                this.typeControl = configControl.typeControl;
            if (configControl.inputMask)
                this.inputMask = configControl.inputMask;
            if (configControl.textRight)
                this.textRight = configControl.textRight;
            if (configControl.formatCero)
                this.formatCero = configControl.formatCero;
            if (configControl.maxLength)
                this.maxLength = configControl.maxLength;
            if (configControl.decimals)
                this.decimals = configControl.decimals;
            if (configControl.clearable)
                this.clearable = configControl.clearable;
            console.log(this.clearable);
        }
        if (this.typeControl == 'input-number' && this.defaultValue)
            this.formControl.setValue(this.defaultValue.toString());
        else
            this.formControl.setValue(this.defaultValue);
    }
    getValue() {
        var _a, _b, _c;
        if (this.formControl.invalid) {
            this.params.data = Object.assign(Object.assign({}, (_a = this.params.node) === null || _a === void 0 ? void 0 : _a.data), { [this.params.fieldValid]: false });
            if (this.params.fieldValid)
                (_b = this.params.node) === null || _b === void 0 ? void 0 : _b.setDataValue(this.params.fieldValid, false);
            return 'INVALID CONTROL';
        }
        else {
            if (this.params.fieldValid)
                (_c = this.params.node) === null || _c === void 0 ? void 0 : _c.setDataValue(this.params.fieldValid, true);
            return this.formControl.value;
        }
    }
    detec(event) {
        const letra = event.key;
        const patt = new RegExp(/^[A-Za-z0-9\-]+$/g);
        // Validar que el valor ingresado solo contenga combinaciones de (letras,numeros,-)
        if (!patt.test(letra)) {
            event.preventDefault();
        }
    }
    isPopup() {
        return true;
    }
    onClick(happy) {
        var _a;
        (_a = this.params.api) === null || _a === void 0 ? void 0 : _a.stopEditing();
    }
    onKeyDown(event) {
        const key = event.which || event.keyCode;
        if (key == 37 || // left
            key == 39) {
            // right
            event.stopPropagation();
        }
    }
    onFocusOut() {
        var _a;
        /* const { node, colDef } = this.params;
        const newValue = this.params.data;
        node.setDataValue(colDef.field, newValue); */
        (_a = this.params.api) === null || _a === void 0 ? void 0 : _a.stopEditing();
    }
}
ContainerSharedComponent.decorators = [
    { type: Component, args: [{
                selector: 'container-shared-component',
                template: "<div [ngStyle]=\"{'width': width}\" class=\"position-relative row\">\r\n\t<div *ngIf=\"typeControl==='ng-select-simple'\" class=\"col-12\">\r\n\t\t<ng-select-simple\r\n\t\t\t[showLabel]=\"false\"\r\n\t\t\t[label]=\"label\"\r\n\t\t\t[required]=\"required\"\r\n\t\t\t[clearable]=\"clearable\"\r\n\t\t\t[formControl]=\"formControl\"\r\n\t\t\t[tooltipMessage]=\"true\"\r\n\t\t\t[validatorMessage]=\"false\"\r\n\t\t\t#control\r\n\t\t\t[items]=\"items\">\r\n\t\t</ng-select-simple>\r\n\t</div>\r\n\t<div *ngIf=\"typeControl==='input-text'\" class=\"col-12\">\r\n\t\t<input-text\r\n\t\t\t(blur)=\"onFocusOut()\"\r\n\t\t\t[showLabel]=\"false\"\r\n\t\t\t[label]=\"label\"\r\n\t\t\t[required]=\"required\"\r\n\t\t\t[formControl]=\"formControl\"\r\n\t\t\t[inputMask]=\"inputMask\"\r\n\t\t\t[textRight]=\"textRight\"\r\n\t\t\t[tooltipMessage]=\"true\"\r\n\t\t\t[validatorMessage]=\"false\"\r\n\t\t\t(keypress)=\"detec($event)\"\r\n\t\t\t#control>\r\n\t\t</input-text>\r\n\t</div>\r\n\t<div *ngIf=\"typeControl==='input-number'\" class=\"col-12\">\r\n\t\t<input-number\r\n\t\t\t(blur)=\"onFocusOut()\"\r\n\t\t\t[formatCero]=\"formatCero\"\r\n\t\t\t[maxLength]=\"maxLength\"\r\n\t\t\t[showLabel]=\"false\"\r\n\t\t\t[decimals]=\"decimals\"\r\n\t\t\t[label]=\"label\"\r\n\t\t\t[tooltipMessage]=\"true\"\r\n\t\t\t[validatorMessage]=\"false\"\r\n\t\t\t[required]=\"required\"\r\n\t\t\t[formControl]=\"formControl\"\r\n\t\t\t#control>\r\n\t\t</input-number>\r\n\t</div>\r\n\t<div *ngIf=\"typeControl==='date-picker'\" class=\"col-12\">\r\n\t\t<date-picker\r\n\t\t\t[showLabel]=\"false\"\r\n\t\t\t[label]=\"label\"\r\n\t\t\t[required]=\"required\"\r\n\t\t\t[formControl]=\"formControl\"\r\n\t\t\t[tooltipMessage]=\"true\"\r\n\t\t\t[validatorMessage]=\"false\"\r\n\t\t\t#control>\r\n\t\t</date-picker>\r\n\t</div>\r\n\t<div *ngIf=\"typeControl==='date-time-picker-editable'\" class=\"col-12\">\r\n\t\t<date-time-picker-editable\r\n\t\t\t[showLabel]=\"false\"\r\n\t\t\t[label]=\"label\"\r\n\t\t\t[required]=\"required\"\r\n\t\t\t[formControl]=\"formControl\"\r\n\t\t\t[tooltipMessage]=\"true\"\r\n\t\t\t[validatorMessage]=\"false\"\r\n\t\t\t#control>\r\n\t\t\t></date-time-picker-editable\r\n\t\t>\r\n\t</div>\r\n</div>\r\n",
                styles: [".ag-theme-balham .ag-cell.ag-cell-inline-editing{height:100%}\n"]
            },] }
];
ContainerSharedComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
ContainerSharedComponent.propDecorators = {
    control: [{ type: ViewChild, args: ['control',] }]
};

class NoRowsOverlayCustomComponent {
    agInit(params) {
        this.params = params;
    }
    onNoRowsClick() {
        var _a;
        (_a = this.params) === null || _a === void 0 ? void 0 : _a.addRow();
    }
}
NoRowsOverlayCustomComponent.decorators = [
    { type: Component, args: [{
                selector: 'edit-delete',
                template: `
		<p class="ag-overlay-loading-center border-0 bg-transparent shadow-none d-flex flex-column">
			<span>No se encontraron registros...</span>
			<a href="javascript:void(0)" (click)="onNoRowsClick()">Agregar</a>
		</p>
	`
            },] }
];

class NoRowsOverlayDefaultComponent {
    agInit(params) {
        this.params = params;
    }
}
NoRowsOverlayDefaultComponent.decorators = [
    { type: Component, args: [{
                selector: 'edit-delete',
                template: `
		<span class="ag-overlay-loading-center border-0 bg-transparent shadow-none">
			No se encontraron registros...
		</span>
	`
            },] }
];

let scCellRenderButtonNextId = 0;
let scMenuPanelNextId = 0;
class ScCellRenderButtonService {
    constructor() {
        this._handlerButtonAction$ = new Subject();
        this.handlerButtonAction$ = this._handlerButtonAction$.asObservable();
    }
    buttonAction(option) {
        this._handlerButtonAction$.next(option);
    }
}
ScCellRenderButtonService.ɵprov = i0.ɵɵdefineInjectable({ factory: function ScCellRenderButtonService_Factory() { return new ScCellRenderButtonService(); }, token: ScCellRenderButtonService, providedIn: "root" });
ScCellRenderButtonService.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
class ScCellRenderBase {
    isFunctionDisabled(value) {
        if (value == null)
            return false;
        if (typeof value === 'function') {
            return value(this.params);
        }
        return value;
    }
    isFunctionHide(value) {
        if (value == null)
            return false;
        if (typeof value === 'function') {
            return value(this.params);
        }
        return value;
    }
}
ScCellRenderBase.decorators = [
    { type: Directive }
];
class ScMenuPanelComponent extends ScCellRenderBase {
    constructor(_scCellRenderButtonService) {
        super();
        this._scCellRenderButtonService = _scCellRenderButtonService;
        this.idScMenuPanel = `sc-menu-panel-${++scMenuPanelNextId}`;
        this.subMenus = [];
    }
    onButtonActionEmit(action) {
        var _a, _b;
        const index = (_b = (_a = this.params) === null || _a === void 0 ? void 0 : _a.node.rowIndex) !== null && _b !== void 0 ? _b : -1;
        this._scCellRenderButtonService.buttonAction({
            index,
            action,
        });
    }
}
ScMenuPanelComponent.decorators = [
    { type: Component, args: [{
                selector: 'sc-menu-panel',
                template: `
    <mat-menu #menu>
      <ng-container *ngFor="let subMenu of subMenus">
        <ng-container *ngIf="!isFunctionHide(subMenu.hide ?? false)">
          <button
            *ngIf="!subMenu.submenu; else branch"
            mat-menu-item
            [disabled]="isFunctionDisabled(subMenu?.disabled)"
            [class.sc-menu-panel-bottom]="subMenu?.icon !== undefined"
            [attr.aria-label]="subMenu?.label ?? ''"
            (click)="onButtonActionEmit(subMenu?.actionCode ?? '')"
          >
            <i
              *ngIf="subMenu?.icon"
              class="fa-lg"
              [class]="
                'sc-menu-panel-icon ' +
                subMenu.icon +
                ' ' +
                (isFunctionDisabled(subMenu?.disabled)
                  ? 'text-muted'
                  : subMenu?.iconClass ?? '')
              "
            ></i>
            <span class="sumax-label">{{ subMenu?.label ?? '' }}</span>
          </button>

          <ng-template #branch>
            <button
              mat-menu-item
              [matMenuTriggerFor]="innerPanel.menu"
              [class.sc-menu-panel-bottom]="subMenu?.icon !== undefined"
              [disabled]="isFunctionDisabled(subMenu?.disabled)"
              [attr.aria-label]="subMenu?.label ?? ''"
            >
              <i
                *ngIf="subMenu?.icon"
                class="fa-lg"
                [class]="
                  'sc-menu-panel-icon ' +
                  subMenu.icon +
                  ' ' +
                  (isFunctionDisabled(subMenu?.disabled)
                    ? 'text-muted'
                    : subMenu?.iconClass ?? '')
                "
              ></i>
              <span class="sumax-label">{{ subMenu?.label ?? '' }}</span>
            </button>

            <sc-menu-panel
              #innerPanel
              [params]="params"
              (onButtonAction)="onButtonActionEmit(subMenu?.actionCode ?? '')"
              [subMenus]="subMenu.submenu ?? []"
            ></sc-menu-panel>
          </ng-template>
        </ng-container>
      </ng-container>
    </mat-menu>
  `,
                host: {
                    '[id]': 'idScMenuPanel',
                },
                styles: [`
      .sc-menu-panel-bottom {
        display: flex;
        align-items: center;
      }

      .sc-menu-panel-icon {
        width: 1.6rem;
        margin-right: 0.3em;
      }

      .mat-menu-item[disabled] {
        pointer-events: auto !important;
        cursor: no-drop !important;
      }

      button:disabled {
        cursor: no-drop;
      }
    `]
            },] }
];
ScMenuPanelComponent.ctorParameters = () => [
    { type: ScCellRenderButtonService }
];
ScMenuPanelComponent.propDecorators = {
    menu: [{ type: ViewChild, args: ['menu', { static: true },] }],
    subMenus: [{ type: Input }],
    params: [{ type: Input }]
};
class ScCellRendererButtonComponent extends ScCellRenderBase {
    constructor() {
        super(...arguments);
        this.idScCellRenderButton = `sc-cell-render-button-${++scCellRenderButtonNextId}`;
        this.configButtons = [];
    }
    agInit(params) {
        this.params = params;
        this.configButtons =
            params.context.componentParent._configButtonsDefaultAgGrid;
    }
    onButtonAction(typeButton) {
        var _a;
        if (typeButton)
            (_a = this.params) === null || _a === void 0 ? void 0 : _a.context.componentParent.onButtonActionAgGridEmit(this.params.node.rowIndex, typeButton);
    }
    refresh(_) {
        return true;
    }
    hideSubMenu(subMenu) {
        if (subMenu.length === 0)
            return true;
        return subMenu.every(({ hide }) => {
            if (hide == null)
                return false;
            if (typeof hide == 'function')
                return hide();
            return hide;
        });
    }
    getTooltipOption(configButtons) {
        if (typeof (configButtons === null || configButtons === void 0 ? void 0 : configButtons.tooltipOption) === 'function')
            return configButtons === null || configButtons === void 0 ? void 0 : configButtons.tooltipOption(this.params);
        else
            return configButtons === null || configButtons === void 0 ? void 0 : configButtons.tooltipOption;
    }
}
ScCellRendererButtonComponent.decorators = [
    { type: Component, args: [{
                template: "<ng-container *ngFor=\"let option of configButtons\">\r\n  <ng-container *ngIf=\"option?.submenu?.length ?? 0 > 0; else buttonPrincipal\">\r\n    <ng-container *ngIf=\"!hideSubMenu(option?.submenu ?? [])\">\r\n      <button\r\n        matRipple\r\n        class=\"btn sc-cell-render-button-action\"\r\n        [ngClass]=\"option?.buttonOption?.classList ? $any(option?.buttonOption?.classList) : ''\"\r\n        *ngIf=\"!isFunctionHide(option?.hide ?? false)\"\r\n        [disabled]=\"isFunctionDisabled(option?.disabled)\"\r\n        [matMenuTriggerFor]=\"panel.menu\"\r\n        [matTooltip]=\"getTooltipOption(option).label ?? ''\"\r\n        [matTooltipClass]=\"getTooltipOption(option).classList ?? ''\"\r\n        [matTooltipDisabled]=\"isFunctionDisabled(option?.disabled)\"\r\n        [attr.aria-label]=\"getTooltipOption(option).label\"\r\n      >\r\n        <em\r\n          class=\"p-0\"\r\n          [class]=\"\r\n            (option?.iconOption?.icon ?? '') +\r\n            ' ' +\r\n            (isFunctionDisabled(option?.disabled)\r\n              ? 'text-muted'\r\n              : option?.iconOption?.classList ?? '')\r\n          \"\r\n        ></em>\r\n      </button>\r\n\r\n      <sc-menu-panel\r\n        #panel\r\n        [params]=\"params\"\r\n        [subMenus]=\"option.submenu ?? []\"\r\n      ></sc-menu-panel>\r\n    </ng-container>\r\n  </ng-container>\r\n\r\n  <ng-template #buttonPrincipal>\r\n    <button\r\n      *ngIf=\"!isFunctionHide(option?.hide ?? false)\"\r\n      [disabled]=\"isFunctionDisabled(option?.disabled)\"\r\n      [ngClass]=\"option?.buttonOption?.classList ? $any(option?.buttonOption?.classList) : ''\"\r\n      class=\"btn sc-cell-render-button-action\"\r\n      matRipple\r\n      (click)=\"onButtonAction(option?.actionCode ?? '')\"\r\n      type=\"button\"\r\n      [matTooltip]=\"getTooltipOption(option).label ?? ''\"\r\n      [matTooltipClass]=\"getTooltipOption(option).classList ?? ''\"\r\n      [matTooltipDisabled]=\"isFunctionDisabled(option?.disabled)\"\r\n      [attr.aria-label]=\"getTooltipOption(option).label\"\r\n    >\r\n      <em\r\n        class=\"pt-0\"\r\n        [class]=\"\r\n          (option?.iconOption?.icon ?? '') +\r\n          ' ' +\r\n          (isFunctionDisabled(option?.disabled)\r\n            ? 'text-muted'\r\n            : option?.iconOption?.classList ?? '')\r\n        \"\r\n      ></em>\r\n    </button>\r\n  </ng-template>\r\n</ng-container>\r\n",
                host: {
                    '[id]': 'idScCellRenderButton',
                    class: 'd-flex justify-content-center sc-cell-render-button',
                },
                encapsulation: ViewEncapsulation.None,
                styles: [`
      .sc-cell-render-button {
        padding: 0.1em 1em;
      }
      .sc-cell-render-button-action {
        border: none;
        border-radius: 50%;
        padding: 0 0.5em;
        text-align: center;
        margin: 0.1em;
        background-color: transparent;
      }
      .sc-cell-render-button-action i {
        display: block;
        width: 1.7em;
        height: 1.7em;
        line-height: 1.7em;
        padding-right: 0;
      }
      button:disabled {
        cursor: no-drop;
      }
    `]
            },] }
];

let nextId$2 = 0;
class ScCellRenderCheckboxListComponent {
    constructor() {
        this.idScCellRenderCheckboxLis = `sc-cell-render-checkbox-list-${++nextId$2}`;
    }
    agInit(params) {
        this.params = params;
    }
    refresh(_) {
        return false;
    }
}
ScCellRenderCheckboxListComponent.decorators = [
    { type: Component, args: [{
                template: `
		<div>
			<ul>
				<ng-container *ngIf="params?.value as items">
					<li *ngFor="let item of items">
						<ng-container *ngIf="item">
							<mat-checkbox
								[ngClass]="{ 'checkbox-list-disabled': item.disabled }"
								color="primary"
								[(ngModel)]="item.checked"
								[disabled]="item.disabled"
								>{{ item.label || '' }}</mat-checkbox
							>
						</ng-container>
					</li>
				</ng-container>
			</ul>
		</div>
	`,
                host: {
                    '[id]': 'idScCellRenderCheckboxLis',
                },
                encapsulation: ViewEncapsulation.None,
                styles: [`
			ul {
				list-style-type: none;
				margin-top: 1.5px;
				padding-left: 0px;
			}
		`]
            },] }
];

class ScCellRenderSelectComponent {
    constructor() {
        this.items$ = of([]);
        this.formControl = new FormControl();
    }
    agInit(params) {
        this._params = params;
        const values = params.values;
        if (values) {
            if (Array.isArray(values))
                this.items$ = of(params.values);
            else
                this.items$ = params.values;
            if (params.value !== null) {
                const { value } = params.value;
                this.items$
                    .pipe(map((data) => data.filter((d) => d.value === value)))
                    .subscribe((v) => {
                    if (v[0]) {
                        this.formControl.setValue(v[0]);
                    }
                });
            }
        }
    }
    refresh(_) {
        return false;
    }
    getValue() {
        return this.formControl.value;
    }
    onChange(_) {
        this._params.api.stopEditing();
    }
}
ScCellRenderSelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'sc-cell-render-select',
                template: `
    <ng-select-simple
      (change)="onChange($event)"
      [formControl]="formControl"
      [items]="items$"
      [virtualScroll]="true"
      [clearable]="false"
    >
    </ng-select-simple>
  `
            },] }
];

class ScCellRenderToggleComponent {
    constructor() {
        this.checkbox = false;
        this.disabled = false;
        this.label = '';
    }
    agInit(params) {
        var _a, _b;
        const { value } = params;
        this._params = params;
        this.label = (_a = params.label) !== null && _a !== void 0 ? _a : '';
        this.disabled = (_b = params.disabled) !== null && _b !== void 0 ? _b : true;
        this.checkbox = value !== null && value !== void 0 ? value : false;
    }
    refresh(_) {
        return false;
    }
    getValue() {
        return this.checkbox;
    }
    onChange(change) {
        this.checkbox = change.checked;
        this._params.api.stopEditing();
    }
}
ScCellRenderToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'sc-cell-render-toggle',
                template: `
		<mat-slide-toggle [disabled]="disabled" [checked]="checkbox" (change)="onChange($event)">{{
			label
		}}</mat-slide-toggle>
	`
            },] }
];

const SC_AG_GRID_BUTTON_HEADER = new InjectionToken('ScAgGridButtonHeader');
class ScAgGridButtonHeader {
    constructor(template) {
        this.template = template;
    }
}
ScAgGridButtonHeader.decorators = [
    { type: Directive, args: [{
                selector: 'ng-template[scAgridButtonHeader]',
                providers: [
                    { provide: SC_AG_GRID_BUTTON_HEADER, useExisting: ScAgGridButtonHeader },
                ],
            },] }
];
ScAgGridButtonHeader.ctorParameters = () => [
    { type: TemplateRef }
];
ScAgGridButtonHeader.propDecorators = {
    content: [{ type: ViewChild, args: [TemplateRef, { static: true },] }]
};

class InputSearchComponent {
    constructor() {
        this.onChange = new EventEmitter();
        this.formControl = new FormControl('');
        this._subscription = this.formControl.valueChanges.subscribe((value) => {
            this.onChange.emit(value.trim());
        });
    }
    ngOnDestroy() {
        var _a;
        (_a = this._subscription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
}
InputSearchComponent.decorators = [
    { type: Component, args: [{
                selector: 'input-search',
                template: "<div class=\"input-search\">\r\n    <input\r\n    class=\"input form-control form-control-sm\"\r\n    [class.input-border]=\"true\"\r\n    type=\"text\"\r\n    [placeholder]=\"'Buscar...'\"\r\n    [formControl]=\"formControl\"/>\r\n\r\n    <span class=\"clear\">\r\n        <i class=\"fas fa-search\"></i>\r\n    </span>\r\n</div>",
                styles: [".input-search{position:relative;display:block}.input-search .clear{position:absolute;top:50%;transform:translateY(-50%);right:1em;z-index:10;padding:.2em;width:2em;font-weight:normal;text-align:right}.input-search .input-border{border-radius:8px}\n"]
            },] }
];
InputSearchComponent.ctorParameters = () => [];
InputSearchComponent.propDecorators = {
    onChange: [{ type: Output }]
};

const scCellRendererFramework = {
    scCellRendererButtonComponent: ScCellRendererButtonComponent,
    scCellRenderCheckboxListComponent: ScCellRenderCheckboxListComponent,
    scCellRenderSelectComponent: ScCellRenderSelectComponent,
    scCellRenderToggleComponent: ScCellRenderToggleComponent,
    noRowsOverlayDefault: NoRowsOverlayDefaultComponent
};
const scCellRendererComponents = [
    ScCellRendererButtonComponent,
    ScCellRenderCheckboxListComponent,
    ScCellRenderSelectComponent,
    ScCellRenderToggleComponent,
    ScMenuPanelComponent
];

let nextId$1 = 0;
class ScAgGridCustomizableComponent {
    constructor(_scCellRenderButtonService, _messageUtilService) {
        this._scCellRenderButtonService = _scCellRenderButtonService;
        this._messageUtilService = _messageUtilService;
        this.idScAgGridCustomizableComponent = `sc-ag-grid-customizable-${++nextId$1}`;
        this.isRowSelectable = () => true;
        this.searchClass = 'col-12 col-sm-12 col-md-6 col-lg-6 col-xl-5 my-2';
        this.getRowStyle = () => undefined;
        this.fillSearch = false;
        //#region Inputs
        /**
         * @description Cantidad de items que se mostrará por página
         * @default 15
         */
        this.paginationPageSize = 15;
        this.searchWidth = '';
        /**
         * @description  Opciones de tamaño de página
         * @default [5, 10, 15, 20, 25]
         */
        this.pageSizeOptions = [5, 10, 15, 20, 25];
        /**
         * @description Si el valor es `true` muestra la paginación
         * @default true
         */
        this.pagination = true;
        /**
         * @description Tipo de selecion en la `grilla`s
         * @default 'simple'
         */
        this.rowSelection = 'single';
        /**
         * @description Array de columnas que se mostrara en la `grilla`
         * @default undefined
         */
        this.columnDefs = [];
        /**
         * @description Array de datos que se mostrara en la `grilla`
         * @default null
         */
        this.rowData = of([]);
        this.defaultCellRendererActions = undefined;
        this._configButtonsDefaultAgGrid = [];
        /**
         * @description Si el valor es `true` muestra el `buscador`
         * @default true
         */
        this.visibleSearch = true;
        this.domLayout = 'normal';
        this.height = '20em';
        /**
         * @description Cpnfiguración para el boton `Agregar`
         * @default { visible: true, disabled: false }
         */
        this.btnAdd = { visible: true };
        /**
         * @description Para activar o descativar el drag & drop
         * @default false
         */
        this.rowDragManaged = false;
        /**
         * @description Para activar o descativar las animaciones
         * @default false
         */
        this.animateRows = false;
        this.useGridCopy = false;
        this.showMenuDefault = false;
        this.enableCellTextSelection = true;
        this.suppressRowTransform = false;
        this.enableRangeSelection = false;
        this.noRowsOverlayComponent = 'noRowsOverlayDefault';
        this.noRowsOverlayComponentParams = {};
        this.validatePasteCell = (evtSource, evtTarget) => Promise.resolve(true);
        this.validatePasteRows = (evtSource, evtTarget) => Promise.resolve(true);
        //#region Output
        this.onChangeFilter = new EventEmitter();
        this.onAddRow = new EventEmitter();
        this.onGridAddRow = new EventEmitter();
        this.onEditRow = new EventEmitter();
        this.onDeleteRow = new EventEmitter();
        this.onCellKeyDown = new EventEmitter();
        this.onCellStopEditing = new EventEmitter();
        this.onButtonActionAgGrid = new EventEmitter();
        this.onButtonActionHeader = new EventEmitter();
        // AgGrid Events - Ouput
        this.onGridReady = new EventEmitter();
        this.onGridSelectChange = new EventEmitter();
        this.onGridChange = new EventEmitter();
        this.onRowDragEnd = new EventEmitter();
        this.onRowEditingStarted = new EventEmitter();
        this.rowClicked = new EventEmitter();
        this.rowDoubleClicked = new EventEmitter();
        this.onRowSelected = new EventEmitter();
        this.cellValueChanged = new EventEmitter();
        this.onCellContextMenu = new EventEmitter();
        this.onPasteMenu = new EventEmitter();
        this.onCopyMenu = new EventEmitter();
        this.afterPasteCell = new EventEmitter();
        this.beforePasteCell = new EventEmitter();
        this.afterPasteRows = new EventEmitter();
        this.beforePasteRows = new EventEmitter();
        //#endregion
        // AgGrid Properties
        this.columnDefsAndAddCellActions = [];
        this.defaultColDef = {
            resizable: true,
            sortable: true,
        };
        this._frameworkComponents = Object.assign({}, scCellRendererFramework);
        this._context = { componentParent: this };
        this.bottomMenu = '0';
        this.leftMenu = '0';
        this.hiddenMenu = true;
        this.overlayNoRowsTemplate = `<span class="ag-overlay-loading-center border-0 bg-transparent shadow-none">
			No se encontraron registros...
		</span>`;
        this.overlayLoadingTemplate = `<span class="ag-overlay-loading-top d-flex align-items-center border-0 bg-white shadow p-4 text-info" style="height: 20px;">
			<img src="assets/media-demo/loading.gif" height="20" width="25" class="mr-2">
			<strong>Cargando registros</strong>
		</span>
		`;
        this.suppressDragLeaveHidesColumns = true;
        this.suppressScrollOnNewData = false;
        this.suppressPaginationPanel = true;
        this._subscription$ = new Subscription();
        this.progressVisibled = false;
        this.selectedRows = [];
    }
    get buttonAddElement() {
        var _a, _b;
        return (_b = (_a = this.buttonAdd) === null || _a === void 0 ? void 0 : _a.nativeElement) !== null && _b !== void 0 ? _b : null;
    }
    // @Input() suppressRowClickSelection = true;
    get suppressRowClickSelection() {
        return this.rowSelection === 'single' ? false : true;
    }
    get configHeader() {
        var _a, _b;
        return (_b = (_a = this.configButtonsAction) === null || _a === void 0 ? void 0 : _a.header) !== null && _b !== void 0 ? _b : null;
    }
    //#endregion
    /**
     * @description Para agregar componentes internos dentro de la grilla
     */
    set frameworkComponents(value) {
        this._frameworkComponents = Object.assign(Object.assign({}, this._frameworkComponents), value);
    }
    /**
     * @description Para poder agregar más objetos al contexto
     */
    set context(value) {
        this._context = Object.assign(Object.assign({}, this._context), value);
    }
    // AgGrid Style
    get ngStyleContainer() {
        return {
            width: '100%',
            height: this.height,
        };
    }
    get ngStyleAgGrid() {
        return {
            width: '100%',
            height: '100%',
        };
    }
    ngOnInit() {
        this._subscription$.add(this._scCellRenderButtonService.handlerButtonAction$.subscribe(({ index, action }) => {
            if (action == null)
                return;
            if (action.trim() === '')
                return;
            if (index !== -1) {
                this.onButtonActionAgGridEmit(index, action);
                return;
            }
            this.onButtonActionHeaderEmit(action);
        }));
        this.initActionButton();
    }
    ngOnChanges(changes) {
        if (!this.gridApi)
            return;
        if (changes.configButtonsAction)
            this.initActionButton();
        if (changes.rowData)
            this.initRowData();
    }
    initRowData() {
        var _a, _b, _c;
        if (!((_a = this.configButtonsAction) === null || _a === void 0 ? void 0 : _a.agGrid))
            this.sizeFitColumnAction();
        if (this._subscriptionRowData$) {
            this._subscriptionRowData$.unsubscribe();
            (_b = this.gridApi) === null || _b === void 0 ? void 0 : _b.setRowData([]);
            (_c = this.gridApi) === null || _c === void 0 ? void 0 : _c.showLoadingOverlay();
        }
        this._subscriptionRowData$ = this.rowData.subscribe((data) => {
            this.gridApi.setRowData(data);
        });
    }
    sizeFitColumnAction() {
        const length = this._configButtonsDefaultAgGrid.filter(({ hide }) => {
            return !this._hideFunc(hide);
        }).length;
        const width = length == 2 ? 90 : 80;
        const minWidth = length > 2 ? length * 33 + 10 : width;
        const newColumns = {
            headerName: 'Acciones',
            headerClass: 'ag-header__center',
            field: '',
            width: minWidth,
            minWidth,
            maxWidth: minWidth,
            cellClass: ['d-flex', 'justify-content-center', 'align-items-center'],
            cellStyle: { overflow: 'visible' },
            resizable: false,
            sortable: false,
            cellRenderer: this.defaultCellRendererActions
                ? this.defaultCellRendererActions
                : 'scCellRendererButtonComponent',
            pinned: 'right',
            suppressMenu: true,
            lockPosition: true,
        };
        this.columnDefsAndAddCellActions = this._hideAgGridMenuAction()
            ? [...this.columnDefs]
            : [...this.columnDefs, newColumns];
    }
    initActionButton() {
        if (isObjEmpty(this.configButtonsAction))
            return;
        const { agGrid } = this.configButtonsAction;
        if (agGrid && agGrid.actions.length > 0) {
            this._configButtonsDefaultAgGrid = [...agGrid.actions];
        }
        this.sizeFitColumnAction();
    }
    /* autoSizeColumns(): void {
      this._gridColumnApi?.autoSizeColumns(
        this._gridColumnApi.getAllColumns()?.map((column) => column.getColId()) ??
          []
      );
  
    }*/
    _hideFunc(hide) {
        if (hide == null)
            return false;
        if (typeof hide == 'function')
            return hide();
        return hide;
    }
    _hideAgGridMenuAction() {
        var _a, _b;
        if (this.configButtonsAction == null)
            return true;
        return ((_b = (_a = this.configButtonsAction.agGrid) === null || _a === void 0 ? void 0 : _a.actions.every(({ hide }) => {
            return this._hideFunc(hide);
        })) !== null && _b !== void 0 ? _b : true);
    }
    hideHeaderMenuAction() {
        var _a, _b, _c;
        return ((_c = (_b = (_a = this.configButtonsAction.header) === null || _a === void 0 ? void 0 : _a.submenu) === null || _b === void 0 ? void 0 : _b.every(({ hide }) => {
            return this._hideFunc(hide);
        })) !== null && _c !== void 0 ? _c : false);
    }
    // AgGrid Events
    gridReady(event) {
        this.gridApi = event.api;
        this._gridColumnApi = event.columnApi;
        this.initRowData();
        this.onGridReady.emit([this.gridApi, this._gridColumnApi]);
    }
    rowDataChanged(event) {
        var _a;
        if (!this.gridApi)
            return;
        if (!((_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.getDisplayedRowCount()))
            return;
        this.onGridChange.emit([this.gridApi, this._gridColumnApi, event]);
    }
    /**
     * @param event: opcional - Contiene el nodo y la data de la fila actual.
     * @description Se dispara cada vez que la fila es colocada en su nueva posición (Drag & Drop).
     */
    rowDragEndEmit(event) {
        this.onRowDragEnd.emit(event);
    }
    selectionChanged() {
        var _a, _b;
        this.selectedRows = (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.getSelectedRows();
        this.onGridSelectChange.emit((_b = this.gridApi) === null || _b === void 0 ? void 0 : _b.getSelectedRows());
    }
    paginationChanged() {
        if (this._scAgGridPagination)
            this._scAgGridPagination.onPaginationChanged();
    }
    changeFilter(value) {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.setQuickFilter(value);
        this.onChangeFilter.emit(value);
    }
    // Button Heder - events
    onAddRowEmit() {
        this.onAddRow.emit(this.gridApi);
    }
    copyMenu(event) {
        this.onCopyMenu.emit(event);
        this.copy(event);
    }
    pasteMenu(event) {
        this.onPasteMenu.emit(event);
        this.paste(event);
    }
    // Button action - events agGrid
    onButtonActionAgGridEmit(rowIndex, typeButton) {
        var _a;
        const ROWNODE = (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.getDisplayedRowAtIndex(rowIndex);
        if (ROWNODE) {
            if (typeButton === EnumButtonType.TYPE_EDIT) {
                this.onEditRow.emit(ROWNODE);
                return;
            }
            if (typeButton === EnumButtonType.TYPE_DELETE) {
                this.onDeleteRow.emit([this.gridApi, [ROWNODE.data]]);
                return;
            }
            this.onButtonActionAgGrid.emit([typeButton, ROWNODE]);
        }
    }
    onButtonActionHeaderEmit(typeButton) {
        var _a;
        const rowsSelected = (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.getSelectedRows();
        this.onButtonActionHeader.emit([typeButton, rowsSelected]);
    }
    copy(evt) {
        var _a, _b, _c;
        if (!evt.node.isSelected()) {
            this.copiedCell = evt;
            if (evt.value instanceof Object)
                navigator.clipboard.writeText((_b = (_a = evt.value) === null || _a === void 0 ? void 0 : _a.label) !== null && _b !== void 0 ? _b : '');
            else
                navigator.clipboard.writeText((_c = evt.value) !== null && _c !== void 0 ? _c : '');
            this._messageUtilService.getAlertSuccess('Celda Copiada');
        }
        else {
            this.copiedRow = this.gridApi.getSelectedNodes();
            this._messageUtilService.getAlertSuccess('Fila Copiada');
        }
        this.gridApi.deselectAll();
    }
    paste(evt) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!evt.node.isSelected() && this.copiedCell) {
                if (evt.column.getColId() === this.copiedCell.column.getColId() &&
                    evt.data.get(evt.column.getColId()).enabled) {
                    let isValid = true;
                    if (this.validatePasteCell)
                        isValid = yield this.validatePasteCell(this.copiedCell, evt);
                    else
                        this.gridApi.deselectAll();
                    this.beforePasteCell.emit([evt, this.copiedCell]);
                    if (isValid) {
                        evt.data.get(evt.column.getColId()).setValue(this.copiedCell.value);
                        this.gridApi.refreshCells({
                            columns: [evt.column],
                        });
                        this.afterPasteCell.emit([evt, this.copiedCell]);
                    }
                }
            }
            else if (evt.node.isSelected() && this.copiedRow) {
                const rowNode = this.gridApi.getSelectedNodes();
                let isValid = true;
                if (this.validatePasteRows)
                    isValid = yield this.validatePasteRows(this.copiedRow, rowNode);
                else
                    this.gridApi.deselectAll();
                this.beforePasteRows.emit([this.gridApi.getSelectedNodes(), this.copiedRow]);
                if (isValid) {
                    let indexRowCopy = 0;
                    rowNode.forEach((r) => {
                        r.data.patchValue(this.copiedRow[indexRowCopy].data.getRawValue());
                        this.gridApi.refreshCells({
                            rowNodes: [r],
                        });
                        indexRowCopy++;
                        if (indexRowCopy == this.copiedRow.length) {
                            indexRowCopy = 0;
                        }
                    });
                    this.afterPasteRows.emit([this.gridApi.getSelectedNodes(), this.copiedRow]);
                    this.gridApi.deselectAll();
                }
            }
        });
    }
    get disabledPasteMenu() {
        var _a, _b;
        if (((_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.getSelectedRows().length) == 0 && !this.copiedCell) {
            return true;
        }
        else if (((_b = this.gridApi) === null || _b === void 0 ? void 0 : _b.getSelectedRows().length) > 0 && !this.copiedRow) {
            return true;
        }
        else if (!this.copiedCell && !this.copiedRow) {
            return true;
        }
        else {
            return false;
        }
    }
    cellKeyDown(evt) {
        return __awaiter(this, void 0, void 0, function* () {
            this.onCellKeyDown.emit(evt);
            if (evt.event.ctrlKey &&
                evt.event.key === 'ArrowDown' &&
                evt.node.lastChild) {
                this.onGridAddRow.emit(evt);
            }
            else if (evt.event.ctrlKey &&
                evt.event.key.toLocaleLowerCase() === 'c'
                && this.useGridCopy) {
                this.copy(evt);
            }
            else if (evt.event.ctrlKey &&
                evt.event.key.toLocaleLowerCase() === 'v'
                && this.useGridCopy) {
                yield this.paste(evt);
            }
        });
    }
    cellStopEditing(evt) {
        this.onCellStopEditing.emit(evt);
    }
    onCancel(e) {
        e.stopPropagation();
        e.preventDefault();
        return false;
    }
    cellContextMenu(event) {
        var _a;
        this.cellContextMenuActual = event;
        this.onCellContextMenu.emit(event);
        this.leftMenu = event.event.x.toString();
        this.bottomMenu = (event.event.y - 20).toString();
        if (event.value !== undefined && this.showMenuDefault)
            (_a = this.menuTrigger) === null || _a === void 0 ? void 0 : _a.openMenu();
    }
    ngOnDestroy() {
        var _a, _b;
        (_a = this._subscription$) === null || _a === void 0 ? void 0 : _a.unsubscribe();
        (_b = this._subscriptionRowData$) === null || _b === void 0 ? void 0 : _b.unsubscribe();
        this.selectedRows.length = 0;
    }
}
ScAgGridCustomizableComponent.decorators = [
    { type: Component, args: [{
                selector: 'sc-ag-grid-customizable',
                template: "<div class=\"w-100\">\r\n  <!--===========================================-->\r\n  <!-- AG-GRID HEADER -->\r\n  <!--===========================================-->\r\n  <div\r\n    class=\"row justify-content-between align-items-center my-2\"\r\n    *ngIf=\"\r\n      visibleSearch || btnAdd?.visible || viewChildrenButtonHeaders?.length\r\n    \"\r\n  >\r\n    <div\r\n      [class]=\"fillSearch ? 'col-12 my-2' : searchClass\"\r\n      *ngIf=\"visibleSearch\"\r\n    >\r\n      <input-search (onChange)=\"changeFilter($event)\"></input-search>\r\n    </div>\r\n\r\n    <div\r\n      [class]=\"\r\n        visibleSearch ? 'col-sm-12 col-md-6 col-lg-6 col-xl-7 col-12' : 'col-12'\r\n      \"\r\n      class=\"sc-ag-grid-header-actions d-flex justify-content-end\"\r\n      *ngIf=\"\r\n        btnAdd?.visible ||\r\n        viewChildrenButtonHeaders?.length ||\r\n        configButtonsAction?.header ||\r\n        configHeader != null\r\n      \"\r\n    >\r\n      <!-- Header actions buttons -->\r\n      <ng-container *ngIf=\"configButtonsAction && configHeader\">\r\n        <ng-container\r\n          *ngIf=\"configHeader.disabled === false; else templateAction\"\r\n        >\r\n          <ng-container [ngTemplateOutlet]=\"tempActions\"></ng-container>\r\n        </ng-container>\r\n\r\n        <ng-template #templateAction>\r\n          <ng-container *ngIf=\"selectedRows.length === 0; else tempActions\">\r\n            <button class=\"btn-icon btn-width btn btn-primary btn-sm\" disabled>\r\n              Acciones\r\n              <em class=\"fa fa-chevron-down\"></em>\r\n            </button>\r\n          </ng-container>\r\n        </ng-template>\r\n\r\n        <ng-template #tempActions>\r\n          <button\r\n            *ngIf=\"hideHeaderMenuAction(); else templateHeaderAction\"\r\n            class=\"btn-icon btn-width btn btn-primary btn-sm\"\r\n          >\r\n            Acciones\r\n            <em class=\"fa fa-chevron-down\"></em>\r\n          </button>\r\n\r\n          <ng-template #templateHeaderAction>\r\n            <button\r\n              type=\"button\"\r\n              class=\"btn-icon btn-width btn btn-primary btn-sm\"\r\n              [matMenuTriggerFor]=\"panel.menu\"\r\n            >\r\n              Acciones\r\n              <em class=\"fa fa-chevron-down\"></em>\r\n            </button>\r\n\r\n            <sc-menu-panel\r\n              #panel\r\n              class=\"d-none\"\r\n              [subMenus]=\"configHeader.submenu ?? []\"\r\n            ></sc-menu-panel>\r\n          </ng-template>\r\n        </ng-template>\r\n      </ng-container>\r\n      <!-- End header actions buttons -->\r\n\r\n      <!-- Other buttons -->\r\n      <ng-container *ngIf=\"viewChildrenButtonHeaders?.length\">\r\n        <ng-container\r\n          *ngFor=\"let viewChildrenButtonHeader of viewChildrenButtonHeaders\"\r\n          [ngTemplateOutlet]=\"viewChildrenButtonHeader.template\"\r\n        >\r\n        </ng-container>\r\n      </ng-container>\r\n      <!--End other buttons -->\r\n\r\n      <!-- Add button -->\r\n      <ng-container *ngIf=\"btnAdd?.visible\">\r\n        <button\r\n          type=\"button\"\r\n          class=\"btn-width btn btn-warning btn-sm\"\r\n          (click)=\"onAddRowEmit()\"\r\n          #buttonAdd\r\n          [disabled]=\"btnAdd.disabled ?? false\"\r\n        >\r\n          Agregar\r\n        </button>\r\n      </ng-container>\r\n      <!--End add button -->\r\n    </div>\r\n  </div>\r\n  <!--===========================================-->\r\n  <!-- AG-GRID HEADER END -->\r\n  <!--===========================================-->\r\n\r\n  <div class=\"row\">\r\n    <div class=\"col-12\" [ngStyle]=\"ngStyleContainer\">\r\n      <ag-grid-angular\r\n        #agGrid\r\n        class=\"ag-theme-balham\"\r\n        [ngStyle]=\"ngStyleAgGrid\"\r\n        [columnDefs]=\"columnDefsAndAddCellActions\"\r\n        [defaultColDef]=\"defaultColDef\"\r\n        [frameworkComponents]=\"_frameworkComponents\"\r\n        [context]=\"_context\"\r\n        [rowSelection]=\"rowSelection\"\r\n        [isRowSelectable]=\"isRowSelectable\"\r\n        [rowDragManaged]=\"rowDragManaged\"\r\n        [domLayout]=\"domLayout\"\r\n        [animateRows]=\"animateRows\"\r\n        [getRowStyle]=\"getRowStyle\"\r\n        [enableRangeSelection]=\"enableRangeSelection\"\r\n        [suppressRowTransform]=\"suppressRowTransform\"\r\n        [suppressMoveWhenRowDragging]=\"animateRows\"\r\n        [overlayNoRowsTemplate]=\"overlayNoRowsTemplate\"\r\n        [overlayLoadingTemplate]=\"overlayLoadingTemplate\"\r\n        [noRowsOverlayComponent]=\"noRowsOverlayComponent\"\r\n\t\t\t\t[noRowsOverlayComponentParams]=\"noRowsOverlayComponentParams\"\r\n        [suppressRowClickSelection]=\"suppressRowClickSelection\"\r\n        [suppressDragLeaveHidesColumns]=\"suppressDragLeaveHidesColumns\"\r\n        [suppressScrollOnNewData]=\"suppressScrollOnNewData\"\r\n        [suppressPropertyNamesCheck]=\"true\"\r\n        [paginationPageSize]=\"pagination ? paginationPageSize : undefined\"\r\n        [pagination]=\"pagination\"\r\n        [suppressPaginationPanel]=\"suppressPaginationPanel\"\r\n        (rowClicked)=\"rowClicked.emit($event)\"\r\n        (rowDoubleClicked)=\"rowDoubleClicked.emit($event)\"\r\n        (rowSelected)=\"onRowSelected.emit($event)\"\r\n        (paginationChanged)=\"paginationChanged()\"\r\n        (gridReady)=\"gridReady($event)\"\r\n        (rowDragEnd)=\"rowDragEndEmit($event)\"\r\n        (cellContextMenu)=\"cellContextMenu($event)\"\r\n        [enableCellTextSelection]=\"enableCellTextSelection\"\r\n        (rowDataChanged)=\"rowDataChanged($event)\"\r\n        (rowEditingStarted)=\"onRowEditingStarted.emit($event)\"\r\n        (cellValueChanged)=\"cellValueChanged.emit($event)\"\r\n        (selectionChanged)=\"selectionChanged()\"\r\n        (cellEditingStopped)=\"cellStopEditing($event)\"\r\n        (cellKeyDown)=\"cellKeyDown($any($event))\"\r\n        [multiSortKey]=\"multiSortKey\"\r\n        oncontextmenu=\"return false;\"\r\n      >\r\n      </ag-grid-angular>\r\n    </div>\r\n  </div>\r\n\r\n  <!--===========================================-->\r\n  <!-- AG-GRID PAGINATION -->\r\n  <!--===========================================-->\r\n  <div class=\"row\" *ngIf=\"pagination\">\r\n    <div class=\"col-12\">\r\n      <sc-ag-grid-pagination\r\n        #scAgGridPagination\r\n        [gridApi]=\"gridApi\"\r\n        [paginationPageSize]=\"paginationPageSize\"\r\n        [pageSizeOptions]=\"pageSizeOptions\"\r\n      ></sc-ag-grid-pagination>\r\n    </div>\r\n  </div>\r\n  <!--===========================================-->\r\n  <!-- AG-GRID PAGINATION END -->\r\n  <!--===========================================-->\r\n</div>\r\n\r\n<div *ngIf=\"showMenuDefault\" oncontextmenu=\"return false;\" style=\"position: fixed;width: 0px; height: 0px;\" [ngStyle]=\"{'top': bottomMenu + 'px', 'left': leftMenu + 'px'}\">\r\n  <mat-menu oncontextmenu=\"return false;\" #scMenu=\"matMenu\">\r\n    <button oncontextmenu=\"return false;\" (click)=\"copyMenu(cellContextMenuActual!)\" mat-menu-item><mat-icon>content_copy</mat-icon>\r\n      <span>Copiar</span></button>\r\n    <button [disabled]=\"disabledPasteMenu\" oncontextmenu=\"return false;\" (click)=\"pasteMenu(cellContextMenuActual!)\" mat-menu-item><mat-icon>content_paste</mat-icon><span>Pegar</span></button>\r\n  </mat-menu>\r\n  <button oncontextmenu=\"return false;\" style=\"visibility: hidden;\" mat-button [matMenuTriggerFor]=\"scMenu\" #menuTrigger=\"matMenuTrigger\">Menu</button>\r\n</div>\r\n",
                changeDetection: ChangeDetectionStrategy.OnPush,
                // encapsulation: ViewEncapsulation.None,
                host: {
                    '[id]': 'idScAgGridCustomizableComponent',
                    class: 'sc-ag-grid-customizable',
                },
                styles: [".cell-wrap-text{white-space:normal!important}.ag-header__center .ag-header-cell-text{display:block;width:100%;text-align:center!important}.ag-header__right .ag-header-cell-text{display:block;width:100%;text-align:right!important}.sc-ag-grid-header-actions{display:flex;grid-gap:.6rem;gap:.6rem}.sc-ag-grid-header-actions .btn-width{width:6.5rem}.sc-ag-grid-header-actions .btn-icon em{margin-left:10px}.material-icons{font-size:24px!important}\n"]
            },] }
];
ScAgGridCustomizableComponent.ctorParameters = () => [
    { type: ScCellRenderButtonService },
    { type: MessageUtilService }
];
ScAgGridCustomizableComponent.propDecorators = {
    viewChildrenButtonHeaders: [{ type: ContentChildren, args: [ScAgGridButtonHeader, { descendants: true },] }],
    menuTrigger: [{ type: ViewChild, args: ['menuTrigger',] }],
    _scAgGridPagination: [{ type: ViewChild, args: ['scAgGridPagination',] }],
    buttonAdd: [{ type: ViewChild, args: ['buttonAdd',] }],
    isRowSelectable: [{ type: Input }],
    getRowStyle: [{ type: Input }],
    fillSearch: [{ type: Input }],
    paginationPageSize: [{ type: Input }],
    searchWidth: [{ type: Input }],
    pageSizeOptions: [{ type: Input }],
    pagination: [{ type: Input }],
    rowSelection: [{ type: Input }],
    columnDefs: [{ type: Input }],
    rowData: [{ type: Input }],
    configButtonsAction: [{ type: Input }],
    defaultCellRendererActions: [{ type: Input }],
    visibleSearch: [{ type: Input }],
    domLayout: [{ type: Input }],
    height: [{ type: Input }],
    btnAdd: [{ type: Input }],
    rowDragManaged: [{ type: Input }],
    animateRows: [{ type: Input }],
    useGridCopy: [{ type: Input }],
    multiSortKey: [{ type: Input }],
    showMenuDefault: [{ type: Input }],
    enableCellTextSelection: [{ type: Input }],
    suppressRowTransform: [{ type: Input }],
    enableRangeSelection: [{ type: Input }],
    noRowsOverlayComponent: [{ type: Input }],
    noRowsOverlayComponentParams: [{ type: Input }],
    validatePasteCell: [{ type: Input }],
    validatePasteRows: [{ type: Input }],
    frameworkComponents: [{ type: Input }],
    context: [{ type: Input }],
    onChangeFilter: [{ type: Output }],
    onAddRow: [{ type: Output }],
    onGridAddRow: [{ type: Output }],
    onEditRow: [{ type: Output }],
    onDeleteRow: [{ type: Output }],
    onCellKeyDown: [{ type: Output }],
    onCellStopEditing: [{ type: Output }],
    onButtonActionAgGrid: [{ type: Output }],
    onButtonActionHeader: [{ type: Output }],
    onGridReady: [{ type: Output }],
    onGridSelectChange: [{ type: Output }],
    onGridChange: [{ type: Output }],
    onRowDragEnd: [{ type: Output }],
    onRowEditingStarted: [{ type: Output }],
    rowClicked: [{ type: Output }],
    rowDoubleClicked: [{ type: Output }],
    onRowSelected: [{ type: Output }],
    cellValueChanged: [{ type: Output }],
    onCellContextMenu: [{ type: Output }],
    onPasteMenu: [{ type: Output }],
    onCopyMenu: [{ type: Output }],
    afterPasteCell: [{ type: Output }],
    beforePasteCell: [{ type: Output }],
    afterPasteRows: [{ type: Output }],
    beforePasteRows: [{ type: Output }],
    overlayNoRowsTemplate: [{ type: Input }]
};
function isObjEmpty(object) {
    if (object === null || object === undefined)
        return true;
    return Object.keys(object).length === 0;
}

let nextId = 0;
class ScAgGridPaginationComponent {
    constructor(_changeRef) {
        this._changeRef = _changeRef;
        this.idScAgGridPaginationComponent = `sc-ag-grid-paginatio-${++nextId}`;
        this.paginationPageSize = 15;
        this.pageSizeOptions = [5, 10, 15, 20, 25];
        this.pages = [];
    }
    ngOnInit() {
        if (this.pageSizeOptions && this.pageSizeOptions.length > 0) {
            // establecer la página si la matriz de elementos no está vacía
            if (this.pageSizeOptions.filter((p) => p === this.paginationPageSize).length == 0) {
                this.paginationPageSize = this.pageSizeOptions[0];
            }
        }
        else {
            this.pageSizeOptions = [5, 10, 15, 20, 25];
            this.paginationPageSize = this.pageSizeOptions[0];
        }
        this.onPaginationChanged();
    }
    onPaginationGoToFirstPage() {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.paginationGoToFirstPage();
    }
    onPaginationGoToPreviousPage() {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.paginationGoToPreviousPage();
    }
    onPaginationGoToPage(page) {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.paginationGoToPage(page);
    }
    onPaginationGoToNextPage() {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.paginationGoToNextPage();
    }
    onPaginationGoToLastPage() {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.paginationGoToLastPage();
    }
    onPageSizeChanged(evt) {
        var _a;
        (_a = this.gridApi) === null || _a === void 0 ? void 0 : _a.paginationSetPageSize(Number(evt.target.value));
    }
    onPaginationChanged() {
        if (!this.gridApi)
            return;
        if (this.gridApi.paginationGetRowCount() > -1) {
            this._pageFound = this.gridApi.paginationGetTotalPages() < 1;
            this._pageFrom = Math.min(Math.max(1, this.gridApi.paginationGetCurrentPage() - 2), this.gridApi.paginationGetTotalPages() - 2);
            this._pageUp = Math.max(Math.min(this.gridApi.paginationGetTotalPages(), this.gridApi.paginationGetCurrentPage() + 2), 5);
            if (this.gridApi.paginationGetTotalPages() > 5) {
                this.pages = new Array(this._pageUp - this._pageFrom + 1)
                    .fill(0)
                    .map((_, index) => index + this._pageFrom);
            }
            else {
                this.pages = new Array(this.gridApi.paginationGetTotalPages())
                    .fill(0)
                    .map((_, index) => index + 1);
            }
            this._changeRef.markForCheck();
        }
    }
}
ScAgGridPaginationComponent.decorators = [
    { type: Component, args: [{
                selector: 'sc-ag-grid-pagination',
                template: "<div\r\n  class=\"d-flex mt-2 justify-content-center justify-content-sm-between sc-ag-grid__pagination\"\r\n>\r\n  <nav class=\"d-flex flex-wrap\" aria-label=\"AgGrid pagination\">\r\n    <ul class=\"pagination p-0 m-0\">\r\n      <li\r\n        class=\"page-item\"\r\n        [ngClass]=\"\r\n          gridApi?.paginationGetCurrentPage() == 0 || pages?.length == 0\r\n            ? 'disabled'\r\n            : ''\r\n        \"\r\n      >\r\n        <a class=\"page-link\" (click)=\"onPaginationGoToFirstPage()\"\r\n          ><em class=\"fa fa-angle-double-left\"></em\r\n        ></a>\r\n      </li>\r\n      <li\r\n        class=\"page-item\"\r\n        [ngClass]=\"\r\n          gridApi?.paginationGetCurrentPage() == 0 || pages?.length == 0\r\n            ? 'disabled'\r\n            : ''\r\n        \"\r\n      >\r\n        <a class=\"page-link\" (click)=\"onPaginationGoToPreviousPage()\"\r\n          ><em class=\"fa fa-angle-left\"></em\r\n        ></a>\r\n      </li>\r\n\r\n      <li\r\n        class=\"page-item\"\r\n        *ngFor=\"let page of pages\"\r\n        [ngClass]=\"\r\n          page - 1 == gridApi?.paginationGetCurrentPage() ? 'active' : ''\r\n        \"\r\n      >\r\n        <span\r\n          class=\"page-link\"\r\n          *ngIf=\"page - 1 == gridApi?.paginationGetCurrentPage()\"\r\n        >\r\n          {{ page }}\r\n        </span>\r\n        <a\r\n          class=\"page-link\"\r\n          *ngIf=\"page - 1 != gridApi?.paginationGetCurrentPage()\"\r\n          (click)=\"onPaginationGoToPage(page - 1)\"\r\n          >{{ page }}</a\r\n        >\r\n      </li>\r\n\r\n      <li\r\n        class=\"page-item\"\r\n        [ngClass]=\"\r\n          gridApi?.paginationGetCurrentPage() ==\r\n            (gridApi?.paginationGetTotalPages() || 1) - 1 || pages?.length == 0\r\n            ? 'disabled'\r\n            : ''\r\n        \"\r\n      >\r\n        <a class=\"page-link\" (click)=\"onPaginationGoToNextPage()\"\r\n          ><em class=\"fa fa-angle-right\"></em\r\n        ></a>\r\n      </li>\r\n      <li\r\n        class=\"page-item\"\r\n        [ngClass]=\"\r\n          gridApi?.paginationGetCurrentPage() ==\r\n            (gridApi?.paginationGetTotalPages() || 1) - 1 || pages?.length == 0\r\n            ? 'disabled'\r\n            : ''\r\n        \"\r\n      >\r\n        <a class=\"page-link\" (click)=\"onPaginationGoToLastPage()\"\r\n          ><em class=\"fa fa-angle-double-right\"></em\r\n        ></a>\r\n      </li>\r\n    </ul>\r\n    <div class=\"d-flex mx-2 align-items-center input-group-sm\">\r\n      Mostrar\r\n      <select\r\n        [(ngModel)]=\"paginationPageSize\"\r\n        (change)=\"onPageSizeChanged($event)\"\r\n        class=\"custom-select mx-2\"\r\n      >\r\n        <option *ngFor=\"let option of pageSizeOptions\" [value]=\"option\">\r\n          {{ option }}\r\n        </option>\r\n      </select>\r\n      registros\r\n    </div>\r\n  </nav>\r\n\r\n  <div class=\"d-flex justify-content-end mt-2 mt-sm-0\">\r\n    <div\r\n      class=\"sc-ag-grid__pagination--total d-flex align-items-center flex-nowrap\"\r\n    >\r\n      <span class=\"value\">{{ gridApi?.paginationGetRowCount() }}&nbsp;</span>\r\n      <span class=\"label\">{{\r\n        gridApi?.paginationGetRowCount() ?? 0 > 1 ? \"Registros.\" : \"Registro.\"\r\n      }}</span>\r\n      <span class=\"label\">&nbsp;P&aacute;gina&nbsp;</span>\r\n      <span class=\"value\">\r\n        {{ (gridApi?.paginationGetCurrentPage() ?? 0) + 1 }}\r\n      </span>\r\n      <span class=\"label\">&nbsp;de&nbsp;</span>\r\n      <span class=\"value\">\r\n        {{\r\n          gridApi?.paginationGetTotalPages() == 0\r\n            ? 1\r\n            : gridApi?.paginationGetTotalPages() ?? 0\r\n        }}\r\n      </span>\r\n    </div>\r\n  </div>\r\n</div>\r\n",
                host: {
                    '[id]': 'idScAgGridPaginationComponent',
                },
                styles: [".sc-ag-grid__pagination{margin:0;padding:0}.sc-ag-grid__pagination--total{font-size:1rem}.sc-ag-grid__pagination--total span{padding-left:4px;font-size:1rem}.sc-ag-grid__pagination>nav>ul>li>a,.sc-ag-grid__pagination>nav>ul>li>span{font-size:1rem}.sc-ag-grid__pagination>nav>ul>li>a{cursor:pointer}.sc-ag-grid__pagination>nav>ul>li>a>i{margin:0;padding:0}button[disabled]{pointer-events:none}\n"]
            },] }
];
ScAgGridPaginationComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
ScAgGridPaginationComponent.propDecorators = {
    paginationPageSize: [{ type: Input }],
    gridApi: [{ type: Input }],
    pageSizeOptions: [{ type: Input }]
};

class ScAgGridModule {
}
ScAgGridModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    ScAgGridCustomizableComponent,
                    ScAgGridPaginationComponent,
                    InputSearchComponent,
                    ContainerSharedComponent,
                    NoRowsOverlayDefaultComponent,
                    NoRowsOverlayCustomComponent,
                    // Cell Renders
                    ...scCellRendererComponents,
                    //Directives
                    ScAgGridButtonHeader,
                    DialogAgGridSearchComponent
                ],
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    AgGridModule.withComponents([...scCellRendererComponents]),
                    MatMenuModule,
                    MatIconModule,
                    MatDialogModule,
                    MatTooltipModule,
                    MatCheckboxModule,
                    MatSlideToggleModule,
                    MatProgressBarModule,
                    NgSelectSimpleModule,
                    InputTextModule,
                    InputNumberModule,
                    DatePickerModule,
                    DateTimePickerEditableModule,
                ],
                exports: [
                    ScAgGridCustomizableComponent,
                    ScAgGridPaginationComponent,
                    ContainerSharedComponent,
                    //Directives
                    ScAgGridButtonHeader,
                    DialogAgGridSearchComponent
                ],
            },] }
];

function setClassFlex(justifyContent, alignItems) {
    return `d-flex justify-content-${justifyContent} align-items-${alignItems}`;
}
function bodyContentCenter() {
    return setClassFlex('center', 'center');
}
function bodyContentRight() {
    return setClassFlex('end', 'center');
}

var ScWizardComponent_1;
let ScWizardComponent = ScWizardComponent_1 = class ScWizardComponent extends CdkStepper {
    constructor(dir, changeDetectorRef, elementRef, 
    // eslint-disable-next-line @typescript-eslint/no-explicit-any, @typescript-eslint/explicit-module-boundary-types
    document) {
        super(dir, changeDetectorRef, elementRef, document);
        this.changeDetectorRef = changeDetectorRef;
        this.clickStepEmit = new EventEmitter();
        this.hasAutoFillSteps = true;
        this.hasSkeleton = false;
        this.showArrows = true;
        this.subWizard = false;
        this.baseSubWizard = 1;
    }
    // @Input() hasAutoScrolling = false;
    get totalSteps() {
        return this.steps.length;
    }
    get isFirstStep() {
        return this.selectedIndex === 0;
    }
    get isLastStep() {
        return this.steps.length - 1 === this.selectedIndex;
    }
    selectStepByIndex(index) {
        this.selectedIndex = index;
    }
    convertLabelToType(label) {
        try {
            return JSON.parse(label);
        }
        catch (_a) {
            return {
                title: label,
            };
        }
    }
};
ScWizardComponent.decorators = [
    { type: Component, args: [{
                selector: 'sc-wizard',
                template: "<div\r\n\t[class.sc-wizard-horizontal]=\"this.orientation === 'horizontal'\"\r\n\t[class.sc-wizard-vertical]=\"this.orientation === 'vertical'\">\r\n\t<div [class]=\"'sc-wizard-' + orientation + '-steps-container'\">\r\n\t\t<button\r\n\t\t\t*ngIf=\"showArrows\"\r\n\t\t\t[disabled]=\"isFirstStep\"\r\n\t\t\t[class.sc-wizard-skeleton]=\"hasSkeleton\"\r\n\t\t\t[class]=\"'sc-wizard-' + orientation + '-button prev'\"\r\n\t\t\ttype=\"button\"\r\n\t\t\tmat-icon-button\r\n\t\t\tcdkStepperPrevious>\r\n\t\t\t<mat-icon>{{ orientation === 'horizontal' ? 'chevron_left' : 'expand_less' }}</mat-icon>\r\n\t\t</button>\r\n\r\n\t\t<ng-container *ngIf=\"this.orientation === 'horizontal'\">\r\n\t\t\t<ng-container *ngIf=\"hasAutoFillSteps\">\r\n\t\t\t\t<div class=\"sc-wizard-horizontal-steps sc-wizard-horizontal-steps-fill\">\r\n\t\t\t\t\t<ng-container [ngTemplateOutlet]=\"templateSteps\"></ng-container>\r\n\t\t\t\t</div>\r\n\t\t\t</ng-container>\r\n\r\n\t\t\t<ng-container *ngIf=\"!hasAutoFillSteps\">\r\n\t\t\t\t<div class=\"sc-wizard-horizontal-steps\">\r\n\t\t\t\t\t<div class=\"sc-wizard-horizontal-steps-wrapper\" [style.width]=\"24 * totalSteps + 'rem'\">\r\n\t\t\t\t\t\t<ng-container [ngTemplateOutlet]=\"templateSteps\"></ng-container>\r\n\t\t\t\t\t</div>\r\n\t\t\t\t</div>\r\n\t\t\t</ng-container>\r\n\t\t</ng-container>\r\n\r\n\t\t<ng-container *ngIf=\"this.orientation === 'vertical'\">\r\n\t\t\t<div class=\"sc-wizard-steps sc-wizard-vertical-steps\">\r\n\t\t\t\t<ng-container [ngTemplateOutlet]=\"templateSteps\"></ng-container>\r\n\t\t\t</div>\r\n\t\t</ng-container>\r\n\r\n\t\t<button\r\n\t\t\t*ngIf=\"showArrows\"\r\n\t\t\t[disabled]=\"isLastStep\"\r\n\t\t\t[class.sc-wizard-skeleton]=\"hasSkeleton\"\r\n\t\t\t[class]=\"'sc-wizard-' + orientation + '-button next'\"\r\n\t\t\ttype=\"button\"\r\n\t\t\tmat-icon-button\r\n\t\t\tcdkStepperNext>\r\n\t\t\t<mat-icon>{{ orientation === 'horizontal' ? 'navigate_next' : 'expand_more' }}</mat-icon>\r\n\t\t</button>\r\n\t</div>\r\n\r\n\t<div\r\n\t\t#scWizardContainer\r\n\t\t[class.sc-wizard-skeleton]=\"hasSkeleton\"\r\n\t\t[class]=\"'sc-wizard-' + orientation + '-content'\">\r\n\t\t<ng-container [ngTemplateOutlet]=\"selected ? selected.content : null\"></ng-container>\r\n\t</div>\r\n</div>\r\n\r\n<ng-template #templateSteps>\r\n\t<div\r\n\t\t*ngFor=\"let step of steps; let i = index\"\r\n\t\t[class.invisible]=\"step.content.elementRef.nativeElement.parentNode.className === 'invisible'\"\r\n\t\t[tabIndex]=\"selectedIndex === i ? 1 : -1\"\r\n\t\t[attr.data-position]=\"i\"\r\n\t\t[class.sc-wizard-steps-item-active]=\"selectedIndex === i && !step.hasError\"\r\n\t\t[class.sc-wizard-steps-item-error]=\"selectedIndex === i && step.hasError\"\r\n\t\t[class.sc-wizard-steps-item-disable]=\"!step.editable || convertLabelToType(step.label)!.disabled\"\r\n\t\tclass=\"sc-wizard-steps-item\"\r\n\t\t[class.sc-wizard-skeleton]=\"hasSkeleton\"\r\n\t\t(click)=\"selectStepByIndex(i); clickStepEmit.emit(i)\">\r\n\t\t<span\r\n\t\t\tclass=\"sc-wizard-steps-item-number d-flex justify-content-center align-items-center\"\r\n\t\t\t[class.sc-wizard-steps-item-number-active]=\"selectedIndex === i\"\r\n\t\t\t[class.sc-wizard-steps-item-number-error]=\"step.hasError\">\r\n\t\t\t<ng-container *ngIf=\"!step.hasError\">\r\n\t\t\t\t{{ subWizard ? baseSubWizard + '.' + (i + 1) : i + 1 }}\r\n\t\t\t</ng-container>\r\n\t\t\t<ng-container *ngIf=\"step.hasError\">\r\n\t\t\t\t<em class=\"fa fa-exclamation-triangle\"></em>\r\n\t\t\t</ng-container>\r\n\t\t</span>\r\n\r\n\t\t<div\r\n\t\t\tclass=\"sc-wizard-steps-item-label\"\r\n\t\t\t[class.sc-wizard-steps-item-label-error]=\"step.hasError\">\r\n\t\t\t<p\r\n\t\t\t\tclass=\"sc-wizard-steps-item-label-title\"\r\n\t\t\t\t[class.sc-wizard-steps-item-label-title-active]=\"selectedIndex === i\"\r\n\t\t\t\t[class.sc-wizard-steps-item-label-title-error]=\"step.hasError\">\r\n\t\t\t\t{{ convertLabelToType(step.label).title }}\r\n\t\t\t</p>\r\n\t\t\t<span\r\n\t\t\t\tclass=\"sc-wizard-steps-item-label-subtitle\"\r\n\t\t\t\t[ngStyle]=\"selectedIndex === i ? convertLabelToType(step.label).subtitleStyleActive! : null\"\r\n\t\t\t\t[ngClass]=\"selectedIndex === i ? convertLabelToType(step.label).subtitleClassActive! : []\"\r\n\t\t\t\t[class.sc-wizard-steps-item-label-subtitle-error]=\"step.hasError\">\r\n\t\t\t\t<ng-container *ngIf=\"!step.hasError && convertLabelToType(step.label)?.subtitle\">\r\n\t\t\t\t\t{{ convertLabelToType(step.label).subtitle }}\r\n\t\t\t\t</ng-container>\r\n\t\t\t\t<ng-container *ngIf=\"step.hasError\">\r\n\t\t\t\t\t{{ step.errorMessage }}\r\n\t\t\t\t</ng-container>\r\n\t\t\t</span>\r\n\t\t</div>\r\n\t</div>\r\n</ng-template>\r\n",
                providers: [{ provide: CdkStepper, useExisting: ScWizardComponent_1 }],
                styles: [":host{font-family:\"Soho Gothic Pro\",Arial,Helvetica,sans-serif;background-color:#fff;overflow:hidden;height:100%;width:100%;display:block}.sc-wizard-horizontal{display:grid;height:100%;grid-template-rows:auto 1fr}.sc-wizard-horizontal-steps{width:100%;overflow:auto hidden}.sc-wizard-horizontal-steps-fill,.sc-wizard-horizontal-steps-wrapper{display:flex;grid-gap:.5rem;gap:.5rem}.sc-wizard-horizontal-steps-fill{overflow:hidden}.sc-wizard-horizontal-steps-fill .sc-wizard-steps-item{flex:1}.sc-wizard-horizontal-steps .sc-wizard-steps-item{width:24rem;margin-bottom:0}.sc-wizard-vertical{height:100%;display:flex}.sc-wizard-vertical-steps{overflow:hidden auto;margin-right:1rem}.sc-wizard-vertical-steps-container{min-width:280px;width:20%}.sc-wizard-steps,.sc-wizard-horizontal-content,.sc-wizard-vertical-content{height:100%;scroll-behavior:smooth}.sc-wizard-horizontal-steps-container,.sc-wizard-vertical-steps-container{height:100%;display:grid;border-radius:.8rem}.sc-wizard-horizontal-steps-container{grid-template-columns:auto 1fr auto}.sc-wizard-vertical-steps-container{grid-template-rows:auto 1fr auto}.sc-wizard-steps-item{display:flex;align-items:center;cursor:pointer;padding:.8rem 1rem;border-radius:.8rem;margin-bottom:.4em;transition:.3s all}.sc-wizard-steps-item:last-child{margin-bottom:0}.sc-wizard-steps-item-disable{pointer-events:none;opacity:.5}.sc-wizard-steps-item-active{position:relative;background-color:#646c9a21}.sc-wizard-steps-item-error{background-color:#fd397a21}.sc-wizard-steps-item-number{border-radius:8px;background-color:#f3f3f7;color:#646c9a;font-size:1.3rem;font-weight:700;margin-right:1rem;height:3.2rem;width:3rem;text-align:center;position:relative}.sc-wizard-steps-item-number em,.sc-wizard-steps-item-number span{position:absolute;z-index:1;left:50%;top:50%;transform:translate(-50%,-50%)}.sc-wizard-steps-item-number-active{color:#fff;background-color:#646c9a}.sc-wizard-steps-item-number-error{color:#fff;background-color:#fd397a}.sc-wizard-steps-item-label-title{margin:0;font-weight:100;color:#646c9a;font-size:16px}.sc-wizard-steps-item-label-title-active{font-weight:700}.sc-wizard-steps-item-label-title-error{color:#fd397a}.sc-wizard-steps-item-label-subtitle{color:gray;font-size:11px}.sc-wizard-steps-item-label-subtitle-error{color:#fd397a}.sc-wizard-horizontal-content,.sc-wizard-vertical-content{background-color:#fff;overflow:hidden auto}.sc-wizard-horizontal-content{padding:1rem 0;width:100%;margin-top:.4rem}.sc-wizard-vertical-content{overflow:hidden auto;padding:1rem;width:80%}.sc-wizard-content{padding:1rem}@media screen and (min-height: 750px){.sc-wizard-content{height:calc(100vh - 333px)}}.sc-wizard-horizontal-button,.sc-wizard-vertical-button{margin:auto;transition:all .3s;height:3rem;width:3.1rem}.sc-wizard-vertical-button.prev{margin-bottom:1rem}.sc-wizard-vertical-button.next{margin-top:1rem}.sc-wizard-horizontal-button.prev{margin-right:1rem}.sc-wizard-horizontal-button.next{margin-left:1rem}.sc-wizard-skeleton{overflow:hidden;position:relative}.sc-wizard-skeleton:after{content:\"\";width:100%;height:100%;background:#dedfe1;background:#e6e6e6;background-image:linear-gradient(to right,#e6e6e6 0%,#f2f3f5 20%,#e6e6e6 40%,#e6e6e6 100%);background-repeat:no-repeat;position:absolute;left:0;top:0;z-index:5;border-radius:.8rem;animation:loading 1.1s infinite linear}@keyframes loading{0%{background-position:-100px}to{background-position:200px}}.visible{visibility:visible}.invisible{visibility:hidden}\n"]
            },] }
];
ScWizardComponent.ctorParameters = () => [
    { type: Directionality },
    { type: ChangeDetectorRef },
    { type: ElementRef },
    { type: undefined, decorators: [{ type: Inject, args: [DOCUMENT,] }] }
];
ScWizardComponent.propDecorators = {
    _scWizardContainer: [{ type: ViewChild, args: ['scWizardContainer',] }],
    clickStepEmit: [{ type: Output }],
    hasAutoFillSteps: [{ type: Input }],
    hasSkeleton: [{ type: Input }],
    showArrows: [{ type: Input }],
    subWizard: [{ type: Input }],
    baseSubWizard: [{ type: Input }]
};
ScWizardComponent = ScWizardComponent_1 = __decorate([
    __param(0, Optional())
], ScWizardComponent);

class ScWizardModule {
}
ScWizardModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    FormsModule,
                    ReactiveFormsModule,
                    CdkStepperModule,
                    MatButtonModule,
                    MatIconModule,
                ],
                exports: [ScWizardComponent, CdkStepperModule],
                declarations: [ScWizardComponent],
                providers: [],
            },] }
];

class TextAreaService {
    constructor(format = 'M', showLabel = true, validatorMessage = false, tooltipMessage = true, submitted = true, validatorAlert = false) {
        this.format = format;
        this.showLabel = showLabel;
        this.validatorMessage = validatorMessage;
        this.tooltipMessage = tooltipMessage;
        this.submitted = submitted;
        this.validatorAlert = validatorAlert;
    }
    getFormat() {
        return this.format;
    }
    getShowLabel() {
        return this.showLabel;
    }
    getValidatorMessage() {
        return this.validatorMessage;
    }
    getTooltipMessage() {
        return this.tooltipMessage;
    }
    getSubmitted() {
        return this.submitted;
    }
    getValidatorAlert() {
        return this.validatorAlert;
    }
}
TextAreaService.ɵprov = i0.ɵɵdefineInjectable({ factory: function TextAreaService_Factory() { return new TextAreaService(i0.ɵɵinject("TEXT_AREA_FORMAT"), i0.ɵɵinject("TEXT_AREA_SHOW_LABEL"), i0.ɵɵinject("TEXT_AREA_VALIDATOR_MESSAGE"), i0.ɵɵinject("TEXT_AREA_TOOLTIP_MESSAGE"), i0.ɵɵinject("TEXT_AREA_SUBMITTED"), i0.ɵɵinject("TEXT_AREA_VALIDATOR_ALERT")); }, token: TextAreaService, providedIn: "root" });
TextAreaService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root'
            },] }
];
TextAreaService.ctorParameters = () => [
    { type: String, decorators: [{ type: Inject, args: ['TEXT_AREA_FORMAT',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['TEXT_AREA_SHOW_LABEL',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['TEXT_AREA_VALIDATOR_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['TEXT_AREA_TOOLTIP_MESSAGE',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['TEXT_AREA_SUBMITTED',] }] },
    { type: Boolean, decorators: [{ type: Inject, args: ['TEXT_AREA_VALIDATOR_ALERT',] }] }
];

class TextAreaComponent {
    constructor(messageUtilService, textAreaService, _render) {
        this.messageUtilService = messageUtilService;
        this.textAreaService = textAreaService;
        this._render = _render;
        this.format = 'M';
        this.showLabel = true;
        this.label = null;
        this.maxLength = null;
        this.readonly = false;
        this.required = false;
        this.validatorMessage = false;
        this.validatorAlert = false;
        this.tooltipMessage = true;
        this.submitted = true;
        this.cols = null;
        this.rows = null;
        this.height = '';
        this.width = '';
        this.disabled = false;
        this.placeholder = '';
        this.labelInfo = false;
        this.textLabelInfo = '';
        this.change = new EventEmitter();
        this.onchange = new EventEmitter();
        this.blur = new EventEmitter();
        this.onfocus = new EventEmitter();
        this.onNext = new EventEmitter();
        this.onBack = new EventEmitter();
        this.sharedComponentsUtil = new SharedComponentsUtil();
        this._initValue = false;
        this.onChange = (_) => { };
        this.onValidationChange = () => { };
        this.onTouch = () => { };
        this.focus = () => {
            this.textArea.nativeElement.focus();
            this.textArea.nativeElement.select();
        };
        this.format = this.textAreaService.getFormat();
        this.showLabel = this.textAreaService.getShowLabel();
        this.validatorMessage = this.textAreaService.getValidatorMessage();
        this.tooltipMessage = this.textAreaService.getTooltipMessage();
        this.submitted = this.textAreaService.getSubmitted();
        this.validatorAlert = this.textAreaService.getValidatorAlert();
    }
    ngOnChanges(changes) {
        if (changes.submitted) {
            if (this.controls !== undefined && changes.submitted.currentValue) {
                this.controls.markAsDirty();
                this.controls.markAsTouched();
            }
        }
    }
    ngOnInit() { }
    ngAfterViewInit() { }
    onBlur(value) {
        // this.value = this.formatInput(value);
        this.onTouch();
        // this.onValidationChange();
        // this.onChange(this.value);
        this.blur.emit(this.formatInput(value));
    }
    onFocus(evt) {
        this.textArea.nativeElement.select();
        this.onfocus.emit(evt);
    }
    onInput(evt) {
        const value = this.formatInput(evt);
        this.onTouch();
        this.onChange(value);
        this.onValidationChange();
        this.change.emit(value);
        this.onchange.emit(value);
    }
    writeValue(value) {
        if (value) {
            this.value = this.formatInput(value);
            // this.onChange(this.value);
            if (this.controls) {
                this._render.setProperty(this.controls, 'value', this.value);
            }
        }
        else {
            this.value = null;
        }
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouch = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
    }
    validate(control) {
        this.controls = control;
        if (!this._initValue) {
            if (this.value) {
                this._render.setProperty(this.controls, 'value', this.value);
            }
            this._initValue = true;
        }
        return null;
    }
    registerOnValidatorChange(fn) {
        this.onValidationChange = fn;
    }
    formatInput(value) {
        if (value !== null && value.toString().trim() !== '') {
            const newValue = value.toString().trim();
            if (this.format === 'M')
                return newValue.toUpperCase();
            if (this.format === 'm')
                return newValue.toLowerCase();
        }
        return value;
    }
    ArrowRight(e) {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.next != undefined) {
            if (this.next.disabled || this.next.readonly) {
                if (this.nextIsDisable != undefined) {
                    this.nextIsDisable.focus();
                }
            }
            else {
                this.next.focus();
            }
        }
        else {
            if (this.nextIsDisable != undefined) {
                this.nextIsDisable.focus();
            }
            else {
                this.onNext.emit();
            }
        }
    }
    ArrowLeft(e) {
        if (!this.disabled) {
            let validator = this.sharedComponentsUtil.stopByValidator(this.controls, this.validatorAlert, this.label);
            if (validator.error) {
                this.messageUtilService.getMessageError('000046', 'Error', validator.message);
                return;
            }
        }
        if (this.back != undefined) {
            if (this.back.disabled || this.back.readonly) {
                if (this.backIsDisable != undefined) {
                    this.backIsDisable.focus();
                }
            }
            else {
                this.back.focus();
            }
        }
        else {
            if (this.backIsDisable != undefined) {
                this.backIsDisable.focus();
            }
            else {
                this.onBack.emit();
            }
        }
    }
}
TextAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'text-area',
                template: "<label\r\n  *ngIf=\"label != null && label != '' && showLabel\"\r\n  class=\"d-flex sumax-label mb-0 p-0\"\r\n  ><span [title]=\"label\" style=\"white-space: nowrap; overflow: hidden; text-overflow: ellipsis;\">{{label}}</span>\r\n\t<span *ngIf=\"required\" class=\"ml-1\"\r\n\t\t[class.text-danger]=\"controls?.errors != null\"> *</span>\r\n\t<span *ngIf=\"labelInfo\">\r\n\t\t<i class=\"fa fa-exclamation-circle text-info ml-2\" [matTooltip]=\"textLabelInfo\" matTooltipClass=\"bg-info\"></i>\r\n\t</span>\r\n  </label\r\n>\r\n<div [class.input-icon]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n        [class.right]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\">\r\n        <!-- tooltip-message es el icono de error -->\r\n        <tooltip-message [label]=\"label\" [controls]=\"controls\" [validatorMessage]=\"validatorMessage\"\r\n                [tooltipMessage]=\"tooltipMessage\" [submitted]=\"submitted\"></tooltip-message>\r\n\r\n        <textarea #textArea class=\"form-control\" [class.text-uppercase]=\"format === 'M'\"\r\n                [class.text-lowercase]=\"format === 'm'\" [placeholder]=\"placeholder\"\r\n                [class.is-invalid]=\"controls?.errors != null && (controls?.dirty || controls?.touched) && submitted\"\r\n                [(ngModel)]=\"value\" [readonly]=\"disabled || readonly\" (blur)=\"onBlur($any($event.target).value)\"\r\n                (input)=\"onInput($any($event.target).value)\" (focus)=\"onFocus($any($event.target).value)\"\r\n                (keydown.control.arrowleft)=\"ArrowLeft($event)\" [rows]=\"rows\" [cols]=\"cols\"\r\n                [ngStyle]=\"{'height': height, 'width': width}\"\r\n                (keydown.control.arrowright)=\"ArrowRight($event)\"></textarea>\r\n</div>\r\n\r\n<!-- error-message es el mansaje que aparece abajo del componente -->\r\n<error-message [label]=\"label\" [controls]=\"controls\" [validatorMessage]=\"validatorMessage\"\r\n        [tooltipMessage]=\"tooltipMessage\" [submitted]=\"submitted\"></error-message>",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => TextAreaComponent),
                        multi: true,
                    },
                    {
                        provide: NG_VALIDATORS,
                        useExisting: forwardRef(() => TextAreaComponent),
                        multi: true,
                    },
                ],
                styles: [".sumax-label{color:#646c9a!important}.input-icon{position:relative}.input-icon.right>tooltip-message{left:auto;right:8px;float:right}.input-icon>tooltip-message{color:#ccc;position:absolute;margin-top:.3rem;margin-right:1.5em;z-index:3;width:16px;font-size:16px;text-align:center;left:0}.input-icon.right>.form-control{padding-right:33px;padding-left:12px}.was-validated .form-control:invalid:focus,.form-control.is-invalid:focus{border-color:#dc3545;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.was-validated .form-control:invalid,.form-control.is-invalid{background-image:none;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #fde6e8!important}.form-control:focus,.form-control:active{border-color:#007eff;box-shadow:inset 0 1px 1px #00000013,0 0 0 3px #007eff1a!important}\n"]
            },] }
];
TextAreaComponent.ctorParameters = () => [
    { type: MessageUtilService },
    { type: TextAreaService },
    { type: Renderer2 }
];
TextAreaComponent.propDecorators = {
    format: [{ type: Input }],
    showLabel: [{ type: Input }],
    label: [{ type: Input }],
    maxLength: [{ type: Input }],
    readonly: [{ type: Input }],
    next: [{ type: Input }],
    nextIsDisable: [{ type: Input }],
    back: [{ type: Input }],
    backIsDisable: [{ type: Input }],
    required: [{ type: Input }],
    validatorMessage: [{ type: Input }],
    validatorAlert: [{ type: Input }],
    tooltipMessage: [{ type: Input }],
    submitted: [{ type: Input }],
    cols: [{ type: Input }],
    rows: [{ type: Input }],
    height: [{ type: Input }],
    width: [{ type: Input }],
    disabled: [{ type: Input }],
    placeholder: [{ type: Input }],
    labelInfo: [{ type: Input }],
    textLabelInfo: [{ type: Input }],
    change: [{ type: Output }],
    onchange: [{ type: Output }],
    blur: [{ type: Output }],
    onfocus: [{ type: Output }],
    onNext: [{ type: Output }],
    onBack: [{ type: Output }],
    textArea: [{ type: ViewChild, args: ['textArea',] }]
};

class TextArea {
}

class TextAreaModule {
    static forRoot(textArea = new TextArea()) {
        return {
            ngModule: TextAreaModule,
            providers: [
                { provide: 'TEXT_AREA_FORMAT', useValue: textArea.format },
                { provide: 'TEXT_AREA_SHOW_LABEL', useValue: textArea.showLabel },
                { provide: 'TEXT_AREA_VALIDATOR_MESSAGE', useValue: textArea.validatorMessage },
                { provide: 'TEXT_AREA_TOOLTIP_MESSAGE', useValue: textArea.tooltipMessage },
                { provide: 'TEXT_AREA_SUBMITTED', useValue: textArea.submitted },
                { provide: 'TEXT_AREA_VALIDATOR_ALERT', useValue: textArea.validatorAlert },
                TextAreaService
            ]
        };
    }
}
TextAreaModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TextAreaComponent],
                imports: [
                    CommonModule,
                    RouterModule,
                    FormsModule,
                    ReactiveFormsModule,
                    ErrorMessageModule,
                    TooltipMessageModule,
                    MatTooltipModule
                ],
                exports: [TextAreaComponent]
            },] }
];

class ScWizardBase {
    constructor() { }
    convertToStringLabel(index) {
        return JSON.stringify(this.labels[index]);
    }
}
ScWizardBase.decorators = [
    { type: Directive }
];
ScWizardBase.ctorParameters = () => [];

/*
 * Public API Surface of sumax-erp-components
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ColumnDefs, ContainerSharedComponent, DatePickerComponent, DatePickerModule, DatePickerService, DateTimePickerComponent, DateTimePickerEditableModule, DateTimePickerEditableService, DateTimePickerMaterialComponent, DateTimePickerModule, DateTimePickerService, DialogAgGridSearchComponent, EnumButtonType, InputNumberComponent, InputNumberModule, InputNumberService, InputSearchComponent, InputTextComponent, InputTextModule, InputTextService, NgSelectMultipleComponent, NgSelectMultipleModule, NgSelectMultipleService, NgSelectSimpleComponent, NgSelectSimpleModule, NgSelectSimpleService, NoRowsOverlayCustomComponent, NoRowsOverlayDefaultComponent, SC_AG_GRID_BUTTON_HEADER, ScAgGridButtonHeader, ScAgGridCustomizableComponent, ScAgGridModule, ScAgGridPaginationComponent, ScCellRenderButtonService, ScCellRenderCheckboxListComponent, ScCellRenderSelectComponent, ScCellRenderToggleComponent, ScCellRendererButtonComponent, ScMenuPanelComponent, ScWizardBase, ScWizardComponent, ScWizardModule, SearchParams, TextAreaComponent, TextAreaModule, TextAreaService, TypeControl, bodyContentCenter, bodyContentRight, isObjEmpty, setClassFlex, I18n as ɵa, CustomDatepickerI18n as ɵb, CustomDatepickerFormat as ɵc, MessageUtilService as ɵd, ErrorMessageModule as ɵe, errorMessageComponent as ɵf, TooltipMessageModule as ɵg, tooltipMessageComponent as ɵh, DatePicker as ɵi, DateTimePickerEditable as ɵk, DateTimePicker as ɵl, InputNumber as ɵm, InputText as ɵn, NgSelectMultiple as ɵo, NgSelectSimple as ɵp, TextArea as ɵq };
//# sourceMappingURL=sumax-erp-component.js.map
